Summary: DRAC Driver for all platforms
Name: DRAC-Driver
Version: 2.5.0
Release: 1
Copyright: AMI/GPL
Group: Utilities/System
Source: DRAC-Driver-2.5.tgz
URL: http://www.ami.com
Vendor: American Megatrends, Inc
Packager: AMI <megarac@ami.com>
provides: kernel-specific, Drac-RH71-kernel-specific, Drac-RH70-kernel-specific, Drac-RH62-kernel-specific

##################### Description of Package ####################
%description

Kernel specific software needed for the DRAC card.  This package contains 
the source code needed to build the DRAC driver for any kernel version 
2.2.x or greater, including 2.4.x kernels.  Install this RPM first, then the 
(binary only) DRAC-Common rpm (preferred), or one of the distribution specific 
rpms, such as DRAC-RH71-Common.

####################### Perparation Script ######################
%prep

%setup

########################## Build Script #########################
%build

cd ${RPM_BUILD_DIR}/DRAC-Driver-2.5.0/Driver
make clean

# Save the default kernel.h
cp /boot/kernel.h /tmp/kernel.h.original

# If we're running the SMP kernel...
if uname -r | grep smp; then
	# Turn off SMP define
	sed 's/#define __BOOT_KERNEL_SMP 1/#define __BOOT_KERNEL_SMP 0/' /boot/kernel.h > /tmp/kernel.h
# If we're running the Enterprise kernel...
elif uname -r | grep enterprise; then
	# Turn off Enterprise define
	sed 's/#define __BOOT_KERNEL_ENTERPRISE 1/#define __BOOT_KERNEL_ENTERPRISE 0/' /boot/kernel.h > /tmp/kernel.h
else
	# Already set for UP, just copy it.
	cp /boot/kernel.h /tmp/kernel.h
fi

# If we weren't doing either of those two kernels, we're running UP.
# Make sure UP is turned on.
sed 's/#define __BOOT_KERNEL_UP 0/#define __BOOT_KERNEL_UP 1/' /tmp/kernel.h > /boot/kernel.h

# Determine the version string for the UP kernel
KERNEL_VERSION=`uname -r | sed 's/smp//' | sed 's/enterprise//'`

# Where kernel headers should be included from
KERNEL_INCLUDE=-I/lib/modules/$KERNEL_VERSION/build/include

# Build the UP driver
make oem=1 ver=2.5 smp=no MODINCS=$KERNEL_INCLUDE

# Rename the rac object (So it will be intact after a "make clean" )
mv rac.o rac.up

# Turn off UP
sed 's/#define __BOOT_KERNEL_UP 1/#define __BOOT_KERNEL_UP 0/' /boot/kernel.h > /tmp/kernel.h

# Turn on SMP
sed 's/#define __BOOT_KERNEL_SMP 0/#define __BOOT_KERNEL_SMP 1/' /tmp/kernel.h > /boot/kernel.h

# Build the SMP driver
make oem=1 ver=2.5 smp=yes MODINCS=$KERNEL_INCLUDE

# Rename the rac object (So it will be intact after a "make clean" )
mv rac.o rac.smp

# Turn off SMP
sed 's/#define __BOOT_KERNEL_SMP 1/#define __BOOT_KERNEL_SMP 0/' /boot/kernel.h > /tmp/kernel.h

# Turn on Enterprise
sed 's/#define __BOOT_KERNEL_ENTERPRISE 0/#define __BOOT_KERNEL_ENTERPRISE 1/' /tmp/kernel.h > /boot/kernel.h

# Build the Enterprise driver
make oem=1 ver=2.5 smp=yes MODINCS=$KERNEL_INCLUDE

# Rename the rac object (So it will be intact after a "make clean" )
mv rac.o rac.enterprise

# Restore the original kernel.h
cp /tmp/kernel.h.original /boot/kernel.h


######################### Install Script ########################
%install

### Enter into the target directory
cd Driver


### Create a home for and create our wacky driver
rm -f /dev/rac0
mknod -m 644 /dev/rac0 c 170 0


### Install the UP driver

# Determine the version string for the UP kernel
KERNEL_VERSION=`uname -r | sed 's/smp//' | sed 's/enterprise//'`

# Figure out where to put the driver
if uname -r | grep "2\.4\.[[:digit:]]\+"; then
	# We have a 2.4 kernel running
	DRIVER_PATH=/lib/modules/${KERNEL_VERSION}/kernel/misc
else
	# We have a 2.2 kernel running
	DRIVER_PATH=/lib/modules/${KERNEL_VERSION}/misc
fi

install -Dm 0444 rac.up $DRIVER_PATH/rac.o
echo "%attr( 444, root, root ) " $DRIVER_PATH/rac.o > /tmp/drac-files


### Install the SMP driver

# Determine the version string for the smp kernel
KERNEL_VERSION=`uname -r | sed 's/smp//' | sed 's/enterprise//'`smp

# Figure out where to put the driver
if uname -r | grep "2\.4\.[[:digit:]]\+"; then
	# We have a 2.4 kernel running
	DRIVER_PATH=/lib/modules/${KERNEL_VERSION}/kernel/misc
else
	# We have a 2.2 kernel running
	DRIVER_PATH=/lib/modules/${KERNEL_VERSION}/misc
fi

install -Dm 0444 rac.smp $DRIVER_PATH/rac.o
echo "%attr( 444, root, root ) " $DRIVER_PATH/rac.o >> /tmp/drac-files


### Install the Enterprise driver

# Determine the version string for the enterprise kernel
KERNEL_VERSION=`uname -r | sed 's/smp//' | sed 's/enterprise//'`enterprise

# Figure out where to put the driver
if uname -r | grep "2\.4\.[[:digit:]]\+"; then
	# We have a 2.4 kernel running
	DRIVER_PATH=/lib/modules/${KERNEL_VERSION}/kernel/misc
else
	# We have a 2.2 kernel running
	DRIVER_PATH=/lib/modules/${KERNEL_VERSION}/misc
fi

install -Dm 0444 rac.enterprise $DRIVER_PATH/rac.o
echo "%attr( 444, root, root ) " $DRIVER_PATH/rac.o >> /tmp/drac-files


### Make RPM aware of the device file
echo "%attr( 644, root, root ) /dev/rac0" >> /tmp/drac-files


########################### File List ###########################
%files -f /tmp/drac-files


######################### Cleanup Script ########################
%clean

rm -f /tmp/drac-files


#################### Post installation scripts ##################
%post

# Don't exit on any error
set +e

# Get off of CDROM if there
cd /tmp

# Update the module listing
depmod -A > /dev/null 2>&1

RESTART_PENDING=0

if ps ax | grep DRACd | grep -v grep > /dev/null 2>&1; then
	/etc/rc.d/init.d/DRACd stop > /dev/null 2>&1
	RESTART_PENDING=1
fi

# See if we should unload an existing DRAC driver first
insmod -p rac > /dev/null 2>&1
if [ $? -ne 0 ]; then
	if rmmod rac > /dev/null 2>&1; then
		echo "Old DRAC driver unloaded"
	else
		echo "Error unloading old DRAC driver - Driver in use?"
	fi
fi

# If the driver can be loaded, load it
if insmod -p rac; then
	if insmod rac > /dev/null 2>&1; then
		echo "New DRAC driver loaded"
	else
		echo "Error loading new DRAC driver - is a DRAC card installed?"
	fi
else
	echo "Giving up trying to load DRAC driver"
fi

if [ $RESTART_PENDING -eq 1 ]; then
	/etc/rc.d/init.d/DRACd start > /dev/null 2>&1
fi


###################### Pre-uninstall scripts #####################
%preun

insmod -p rac > /dev/null 2>&1

# If the driver is loaded, unload it
if [ $? -ne 0 ]; then
	# ...then unload it if we can.
	if rmmod rac; then
		echo "DRAC driver unloaded"
	else
		echo "Cannot unload DRAC driver"
	fi
fi


##################### Post-uninstall scripts #####################
%postun


############################ Changelog ###########################
%changelog

* Tue Dec 18 2001 Andrew McCallum andrewm@ami.com
- Modified RPM spec and Makefile to build using standard
- module include directories

* Mon Oct 15 2001 Andrew McCallum andrewm@ami.com
- Modified RPM spec to build and install drivers for UP, SMP, and
- Enterprise kernels all at once.

* Mon Sep 18 2001 Andrew McCallum andrewm@ami.com
- Created generic source RPM for DRAC driver

* Wed Jun 20 2001 Andrew McCallum andrewm@ami.com
- Ported DRAC driver to 2.4.x kernel architecture
