
#Turn the DMA off only when reading from CD
FILE_SYSTEM_TYPE=`df -T  $0 | grep -v Filesystem |awk '{ print $2}'`

if [ "$FILE_SYSTEM_TYPE" == "iso9660" ] ; then
	echo "Turning off DMA on IDE CDROM drives."
	for i in /proc/ide/*; do
		if [ -e $i/media ]; then
    			if grep -q ^cdrom $i/media; then
      				drive=$( basename $i )
      				echo Disabling DMA for CDROM /dev/$drive
      				hdparm -d0 /dev/$drive > /dev/null 2>&1
    			fi
		fi
	done		
fi


###################################################
#
#   Syntax:   chk_Free_Space <mountname spacerequired spaceMsgstring>
#   Function: Check if the required amount of disk
#	      space is available onthe host system.
#
###################################################
function chk_Free_Space
{
	FREE_SPACE_FOUND=FALSE
	rm -f /tmp/dcspc.txt

	$(dirname $0)/app/dcaulxut -cs outfilename=/tmp/dcspc.txt mountname=$1
	RET_STATUS=$?

	chmod -f 755 /tmp/dcspc.txt

	if [ $RET_STATUS == 0 ] ; then
		if [ -f "/tmp/dcspc.txt" ] ; then
			FREE_SPACE_FOUND=TRUE
			FREE=`cat /tmp/dcspc.txt | awk '{ print $2 }'`
			#echo FREE $1 $FREE
		fi
	fi

	rm -f /tmp/dcspc.txt

	if [ "$FREE_SPACE_FOUND" == "FALSE" ] ; then
		echo "Install was unable to retrieve free space information in $1 folder. Install will exit now."
		exit -1
	fi

	if [ ${FREE:-0} -lt $2 ]; then
   		echo "Not enough space available in $1 folder. Please make sure you have atleast $3 of free space available in the $1 folder."
		echo "Install will exit now..."
   		exit -1
	fi
}

if [ ! -d "/tmp" ] ; then
	echo "error : Please make sure that /tmp directory is present as it is used by Install package..."
	echo "error : Install will exit now..."
	exit -1
fi

chk_Free_Space /usr 200000 200MB
chk_Free_Space /var 20000 20MB
chk_Free_Space /tmp 20000 20MB

#################################################
# This section is to display help for all
# supported parameters by this script file
#################################################
if [ $# -ge 1 ] ; then
	if [ $1 == "-?" -o $1 == "/?" -o $1 == --help ] ; then
		echo "Usage: start.sh [OPTION]..."
		echo "For installing and doing dependency checks for Server Administrator"
		echo

		echo "-license          to accept user license"
		echo "-silent           to do silent install"
		echo "  -license        to accept user license"
		echo "  -noweb          do not start Server Administrator after install"
		echo "  -sil            to specify the sil-filename for silent install"
		echo "  -log            to specify the log-filename"
		echo "  -nosnmpsets     to turn the snmp set capability off"
		echo "  -force          to install applications with a WARNING dependency also"
		echo "-dcheck           to do dependency check without actually installing components. Information is saved in file /tmp/ominstal_check.log"
		echo "  -sil            to specify the sil-filename for silent install"
		echo "  -log            to specify the log-filename"
		echo "-?, /?, --help    to display this help and exit"

		echo ""
		exit 0
	fi
fi
#################################################
# End section is to display help for all  
# supported parameters by this script file
#################################################

#################################################
# This section is to perform initial check for 
# all libraries on which java is dependent
#################################################

#################################################
#
#   Syntax:   chk_library_status <libName>
#   Function: Check if the libray is present on 
#	      the host sytem.
#
#################################################

function chk_library_status
{
	libCount=0

	while [ $# -ge 1 ]; do
		libCount=`whereis $1 / | grep -c $1`
		if [ "$libCount" -le "0" ] ; then
			echo "error:library '$1' required by 'libjvm.so' is missing. Install will now exit."
			exit -1
		fi
		shift
	done
}

chk_library_status `ldd $(dirname $0)/jre/linux/lib/i386/client/libjvm.so | awk '{print $1}'`

#################################################
# End section is to perform initial check for 
# all libraries on which java is dependent
#################################################

function cleanupPostInstall
{
	rm -f /tmp/prop.txt
	rm -f /tmp/linpci.txt
	rm -f /root/omsa_message.*
}
#################################################
# This section is for reading the Cmd Line params
# user can enter -noweb -sil and -log params
#################################################
#The following library must be present; otherwise OMSA web server will not work
RHOS=$(cat /etc/redhat-release | grep Taroon)
if [ ! -e "/usr/lib/libstdc++-libc6.1-1.so.2" -a -z "$RHOS" ]
then
   echo "Install the compat-libstdc++ package from your Linux CD"
   echo "before Installing Systems Management applications."
   cleanupPostInstall
   exit -1            
fi

#declare variables
AU_NO_WEB=FALSE
AU_SIL_FILE_OPTION=FALSE
AU_SIL_FILE_NAME=""
AU_LOG_FILE_OPTION=FALSE
AU_LOG_FILE_NAME=""
AU_NO_SNMP_SETS=FALSE
AU_LICENSE_ACCEPTED=TRUE
AU_SILENT_INSTALL=TRUE
AU_DEP_CHECK_MODE=FALSE
AU_FORCEINSTALL=FALSE

#################################################
# This section is for converting the LANG variable
# It converts the LANG from xx_XX.UTF-8 to xx_XX
# where xx_XX stands for a particular language. 
# e.g, en_EN.UTF-8 will be converted to en_EN
#################################################
TMP_LANG=$LANG
TMP_LANG=${TMP_LANG%.*}
export LANG=$TMP_LANG

while [ $# -ge 1 ]; do
	case "$1" in
	-noweb)
		AU_NO_WEB=TRUE
		;;
	-sil)
		if [ $# -gt 1 ] ; then
			shift
			if [ -e "$1" ] ; then
				AU_SIL_FILE_OPTION=TRUE
				AU_SIL_FILE_NAME=$1
			else
				echo "error : InValid sil file ($1) specified."
				exit -1
			fi
		else
			echo "error : sil file name not specified. Install will now exit."
			exit -1

		fi
		;;
	-log)
		if [ $# -gt 1 ] ; then
			AU_LOG_FILE_OPTION=TRUE
			shift
			case "$1" in
			-*)
				echo "error : log file name not specified. Install will now exit."
				exit -1
				;;
			*)
				AU_LOG_FILE_NAME=$1
				;;
			esac
		else
				echo "error : log file name not specified. Install will now exit."
				exit -1
		fi
	;;
	-nosnmpsets)
		AU_NO_SNMP_SETS=TRUE
		;;
	-license)
		AU_LICENSE_ACCEPTED=TRUE
		;;
	-silent)
		AU_SILENT_INSTALL=TRUE
                rm -rf /tmp/ominstal.log
                rm -rf /tmp/omstatus.log
		;;
	-dcheck)
		AU_DEP_CHECK_MODE=TRUE
                rm -rf /tmp/ominstal_check.log
                rm -rf /tmp/omstatus_check.log
		;;
	-force)
		AU_FORCEINSTALL=TRUE
                ;;
         *)
		echo "error : Option '$1' is not recognized. Install will now exit."
		exit -1
                ;;
	esac
shift
done

#################################################
# End section for reading the Cmd Line params
#################################################

cd $(dirname $0)
SRCDIR=$PWD

echo "Message: [Start] -> Please wait"

/sbin/lspci -n | awk '{print $4}' | sed "s/:000/:   /"| sed "s/:00/:  /" |sed "s/:0/: /" >/tmp/linpci.txt
app/detectsys > /tmp/prop.txt

if [ ! -e /usr/bin/cut ]
then
      ln -s /bin/cut /usr/bin/cut
fi

cd app/class

################################################
# This is fix for LX 30 before launching java  #
################################################
	IsVerLX30=`cat /etc/redhat-release | grep -c 2.9.5AS`

	if [ "$IsVerLX30" -ge "1" ] ; then
		export LD_ASSUME_KERNEL=2.4.19
	fi

if [ "$AU_SILENT_INSTALL" == "TRUE"  -o "x$DISPLAY" = x -o "$AU_DEP_CHECK_MODE" == "TRUE" ] ; then

	if [ "$AU_LICENSE_ACCEPTED" == "FALSE" -a "$AU_DEP_CHECK_MODE" == "FALSE" ] ; then
		echo "error : please accept user agreement license, see Server Administrator's user's guide for help"
		cleanupPostInstall
		exit -1
	fi

	AU_ARGS=''
	if [ "$AU_NO_WEB" == "TRUE" ] ; then
		AU_ARGS="$AU_ARGS noweb"
	fi
	if [ "$AU_SIL_FILE_OPTION" == "TRUE" ] ; then
		AU_ARGS="$AU_ARGS sil=$AU_SIL_FILE_NAME"
	fi
	if [ "$AU_LOG_FILE_OPTION" == "TRUE" ] ; then
		AU_ARGS="$AU_ARGS logfile=$AU_LOG_FILE_NAME"
	fi
	if [ "$AU_NO_SNMP_SETS" == "TRUE" ] ; then
		AU_ARGS="$AU_ARGS nosnmpwrite"
	fi
	if [ "$AU_FORCEINSTALL" == "TRUE" ] ; then
		AU_ARGS="$AU_ARGS forceinstall"
	fi


        #echo $AU_ARGS
	if [ "$AU_DEP_CHECK_MODE" == "TRUE" ] ; then
		../../jre/linux/bin/java -Djava.library.path=../ -jar setup.jar unattendcheckonly $AU_ARGS
        	echo "Finished Checking Dependencies."
	else
                rm -rf /tmp/ominstal.log
                rm -rf /tmp/omstatus.log
		../../jre/linux/bin/java -Djava.library.path=../ -jar setup.jar dsa $AU_ARGS
	fi

	if [ "$AU_DEP_CHECK_MODE" == "FALSE" ] ; 
        then
            if [ -d "/usr/lib/dell/openmanage/uninstall" ]; 
            then
	       cd /usr/lib/dell/openmanage/uninstall >/dev/null
	       if [ "$AU_NO_WEB" == "FALSE" ];
	       then
		   sleep 10
	    	   sh stserv.sh >/dev/null
	       else
		   sleep 10
	    	   sh stserv.sh noweb >/dev/null
	       fi
	    fi
        fi
else
	../../jre/linux/bin/java -Djava.library.path=../ -jar setup.jar
	if [ -d "/usr/lib/dell/openmanage/uninstall" ];
	then 
		cd /usr/lib/dell/openmanage/uninstall >/dev/null
		sleep 10
		sh stserv.sh >/dev/null
	fi
fi

########################################################
# Copy the uninstall.sh if there is any apps installed
########################################################

if [ '-f "/etc/ominstal.db"' -a  "$AU_DEP_CHECK_MODE" == "FALSE" ] ; then
	if [ -d "/usr/lib/dell/openmanage/uninstall" ];
	then
	   cp $SRCDIR/uninstall.sh /usr/lib/dell/openmanage
           rm -rf /usr/lib/dell/openmanage/uninstall/*.dll
           rm -rf /usr/lib/dell/openmanage/uninstall/*.exe
           rm -rf /usr/lib/dell/openmanage/uninstall/OMClean
        fi
fi

cleanupPostInstall
