#!/bin/sh
# Usage: AgentSetup.sh i/u cfg/nocfg
# Description: Installs and Upgrades kickstart rpm based on the cfg/nocfg option
#  	     : Installs and Upgrades nsagent only if the server is NOT for Solutions Deployment
#	       If the server is Solutions Deployment,then install nsagent only when Kickstart is done
#	     : Resets all network interfaces to DHCP
#	       If entries(cache,info) are present in /etc/dhcpc/, remove them.
#		Added $PATH to include the required directories in the folder
# Author : Anusha Ragunathan

LOG_FILE="/var/tmp/nsagents.log"
TMP_FILE="/var/tmp/nsagentrpm.tmp"

UPDB="./updatedb"

KSA=kickstart
KSRPMNAME="${KSA}-3.1-3"
KSRPM="${KSRPMNAME}.i686.rpm"

NSA=nsagent
NSRPMNAME="${NSA}-2.00-1"
NSRPM="${NSRPMNAME}.i686.rpm"

VALUE_PASS="pass"
VALUE_FAIL="fail"

INSTALLED_KS="null"

AGENT_UNINSTALL="./uninstri.sh"
TARGET_UNINSTALL_FILE="/usr/dell/uninstri.sh"

IF_CFG_PATH="/etc/sysconfig/network-scripts"

# This is to remove the lease files for cfg mode; so that the old leases dont take effect
DHCPC_PATH="/etc/dhcpc/*"
DHCLIENT_PATH="/var/lib/dhcp/*.leases"


# Set $PATH
PATH=.:/usr/sbin:/sbin:/usr/bin:/bin:${PATH}

#---------------------------------------------------
# Calls the update code to update the database entry 
# in SMCD
#---------------------------------------------------
function update_status
{
        ${UPDB} "$1"
}

function write_to_log
{
	echo `date`--"$1" >> ${LOG_FILE}
}


#---------------------------------------
# Perform Sanity checks
#---------------------------------------
# Make sure we have the RPMs
# TODO: where are the RPMS?
RPMDIR=${0%/AgentSetup.sh}
cd ${RPMDIR}

rm -rf ${TMP_FILE}
rm -rf ${LOG_FILE}

touch ${LOG_FILE}

if [ ! -f ${KSRPM} ];
then
        write_to_log "${KSRPM} not found"
        exit 1
fi

if [ ! -f ${NSRPM} ];
then
        write_to_log "${NSRPM} not found"
        exit 1
fi


#---------------------------------------------------
# Install the rpm and 
# Pass the install information to the update program
# update install pass/fail
#---------------------------------------------------
case $1
	in
	"i")
		case $2
		in
			"cfg") ;;
			"nocfg") ;;
			*) write_to_log "Error: Wrong Number of Arguments passed : Usage -> AgentSetup.sh i/u cfg|nocfg" 
			exit 1;;
		esac


		# Get list of currently installed RPMs
		rpm -qa >${TMP_FILE} 2>&1

		# Uninstall all kickstart agent installations in the system before an installtion
		VALUE_INST_VER=`grep ${KSA} ${TMP_FILE}`

		if [ "${VALUE_INST_VER}" != "" ]; then
			rpm -e --nodeps ${VALUE_INST_VER} >> ${LOG_FILE} 2>&1
		fi

		# Cleanup left over stuff
                if [ -d /usr/dell/kickstart ] ; then
                        rm -rf /usr/dell/kickstart
                fi


		#remove startup code from /etc/rc.d/rc.local
		awk '  BEGIN  { output=1; }
		       /Dell KSA-0-BEGIN/ { output=0; }
		         { if ( output ) print ; }
		       /Dell KSA-0-END/  { output=1; }
		         { next; } ' </etc/rc.d/rc.local >/tmp/rc.local
		cat /tmp/rc.local >/etc/rc.d/rc.local
		rm -f /tmp/rc.local


		#Uninstall nsagent rpm before an installation
		NS_INST=`grep ${NSA} ${TMP_FILE}`

		if [ "${NS_INST}" != "" ]; then
			rpm -e ${NS_INST} >> ${LOG_FILE} 2>&1
		fi

		rpm -i ${KSRPM} >>${LOG_FILE} 2>&1
                if [ $? != 0 ]; then
                        write_to_log "Error: Installing ${KSRPM}"
			update_status "${VALUE_FAIL}"
			exit 1
                else

                        write_to_log "Success: Installing ${KSRPM} "
                fi

		case $2
		in
			"cfg") ;;
			"nocfg") 
				touch /usr/dell/kickstart/cfg.txt;;
		esac

		# Install Netstart Agent and check on result only if it is not Solutions

		if [ ! -d /usr/dell/paw ];
		then # Not a Kabar box
			rpm -i ${NSRPM} >>${LOG_FILE} 2>&1
                	if [ $? != 0 ]; then
                        	write_to_log "Error: Installing ${NSRPM}"
				update_status "${VALUE_FAIL}"
				exit 1
                	else
                        	write_to_log "Success: Installing ${NSRPM} "
                	fi
		else # Itz a Kabar box; So copy rpm so that it can be used during ksdone time
			cp ${NSRPM} /usr/dell/kickstart/${NSRPM};
		fi

		# If Kickstart rpm installed successfully, then reset all interfaces to DHCP ONLY in the CFG option
		# And remove the dhcpc cache and info entries
		case $2
		in 
			"cfg")
				for IFACE in `ifconfig -a | awk -F" " '{if(($1 ~ /^[:lower:]/) && ($1 != "lo")) print $1}'`
				do
				if [ -e ${IF_CFG_PATH}/ifcfg-${IFACE} ]
				then
				#echo "Setting interface $IFACE to DHCP..." >> $LOGFILE
				write_to_log "Setting interface $IFACE to DHCP..."
				echo "DEVICE=${IFACE}" > ${IF_CFG_PATH}/ifcfg-${IFACE}
				echo "ONBOOT=yes" >> ${IF_CFG_PATH}/ifcfg-${IFACE}
				echo "BOOTPROTO=dhcp" >> ${IF_CFG_PATH}/ifcfg-${IFACE}

				rm -rf ${DHCPC_PATH}
				rm -rf ${DHCLIENT_PATH}
				fi
				done;;
			"nocfg");;
		esac

		update_status "${VALUE_PASS}"

		# Copy over the Agent Uninstallation script to the hard-disk to provide for 
		# SMCD uninstallation from the hard-disk
		cp ${AGENT_UNINSTALL} ${TARGET_UNINSTALL_FILE};;

    "u")
	        #Kill old ksagent if it's running
		PIDS=`ps -Af |grep ksagent |grep -v grep | sed -e 's/root//' -e 's/ *//' | cut -d' ' -f 1`
		if test "x${PIDS}" != "x"; then
			#Stop the service
        		/usr/dell/kickstart/ksd stop
		fi

		#erase old kickstart files
		# Get list of currently installed RPMs
		rpm -qa >${TMP_FILE} 2>&1

		# Uninstall all kickstart agent installations in the system before an installtion
		VALUE_INST_VER=`grep kickstart ${TMP_FILE}`

		if [ "${VALUE_INST_VER}" != "" ]; then
		        write_to_log "Uninstalling old version"
			rpm -e --nodeps ${VALUE_INST_VER} >> ${LOG_FILE} 2>&1
		fi


		# Don't remove startup code if it's there because we still
		# want the agent to run.
		# Don't uninstall the nsagent, Image server will do that.
		# Touch upgrade so install.sh won't do anything
		touch /var/tmp/upgrade
		
		# Install Kickstart rpm
		rpm -i ${KSRPM} >>${LOG_FILE} 2>&1
                if [ $? != 0 ]; then
                        write_to_log "Error: Installing ${KSRPM}"
			update_status "${VALUE_FAIL}"
			exit 1
                else

                        write_to_log "Success: Installing ${KSRPM} "
                fi

		update_status "${VALUE_PASS}"

		# Copy over the Agent Uninstallation script to the hard-disk to provide for 
		# SMCD uninstallation from the hard-disk
		cp ${AGENT_UNINSTALL} ${TARGET_UNINSTALL_FILE};;


    *)
                write_to_log "Error: Wrong Number of Parameters: Usage: AgentSetup.sh i/u cfg|nocfg";;
esac
exit 0
