#!/bin/sh
# Author: Anusha Ragunathan
# This shell script checks for the OS version to be RH7.2, RH 2.1 AS ,RH 7.3, RH 8.0
# based on the entry in /etc/issue
# Usage : depcheck.sh "Autry filename with status" 
# The dependency shouls also check and report the following messages:

# Added support for RH 8.0
# Changed agent installed version to 1.1

# Added support for Advanced Server 2.1

NS_MSG_WRONG_OS=1000 # This msg is diff from the Windows agent
NS_MSG_UNKNOWN_VERSION=1011 # Not checking
NS_MSG_OLDER_VERSION=1012
NS_MSG_THIS_VERSION=1013
NS_MSG_NEWER_VERSION=1014
 
# Need to create the log file

STATUS_PASS=0
STATUS_WARNING=1
STATUS_FAIL=2

STATUS_FILE="$1"
LOG_FILE="/var/tmp/nsagents.log"

#NSAGENTS_INSTALLED_VERSION=1.1
NSAGENTS_INSTALLED_VERSION=1.2
NSAGENTS_NUM_OF_MSGS=1

KSA=kickstart
TMPFILE="/var/tmp/nsagentrpm.tmp"
#STD_VERSION="kickstart-3.1-2"
STD_VERSION="kickstart-3.1-3"


function write_to_log
{
        echo `date` -- "$1" >> ${LOG_FILE}
}

function write_to_file
{	
	echo "NETSTARTAGENTS.status=$1" >> ${STATUS_FILE}
	echo "NETSTARTAGENTS.installedversion=$NSAGENTS_INSTALLED_VERSION" >> ${STATUS_FILE}

	if [ ! -z $2  ]; then
		echo "NETSTARTAGENTS.numofmsgs=$NSAGENTS_NUM_OF_MSGS" >> ${STATUS_FILE}
		echo "NETSTARTAGENTS.msgid.0=$2" >> ${STATUS_FILE}
	fi

	exit # Exit after finding out that the dependency is not satisfied
}

function cmpstr { for s; do echo "$s"; done |sort -c 2>/dev/null;}

rm -f ${LOG_FILE}
touch ${LOG_FILE}

#------------------------------
# Perform Sanity Checks
#------------------------------


# Make sure we have the Autry status file
if [ -z ${STATUS_FILE} ];
then
        write_to_log "Status file not specified"
        exit 1
fi

#------------------------------------------
# Dependency 1: Determine if wrong OS
#------------------------------------------
version1=`cat /etc/redhat-release |egrep "Red Hat Linux release 7.2"`
version2=`cat /etc/redhat-release |egrep "Red Hat Linux release 7.3"`
version3=`cat /etc/redhat-release |egrep "Red Hat Linux release 8.0"` # This string will let all the beta versions of Gin-Gin also
version4=`cat /etc/redhat-release |egrep "Red Hat Linux Advanced Server release 2.1AS"`
version5=`cat /etc/redhat-release |egrep "Red Hat Linux release 9"`

if [ -z "${version1}" ] ; then 
	if [ -z "${version2}" ]; then
		if [ -z "${version3}" ]; then
			if [ -z "${version4}" ]; then
				if [ -z "${version5}" ]; then
					write_to_file $STATUS_FAIL ${NS_MSG_WRONG_OS}
				fi
			fi
		fi
	fi
fi

rpm -qa >${TMPFILE}
#VALUE_INST_VER=`grep ${KSA} ${TMPFILE}`
# This line changed to grep only for rpms that start with kickstart. eliminating redhat-config-kickstart rpm

VALUE_INST_VER=`grep ^${KSA} ${TMPFILE}`

# Do depcheck 2,3 and 4 only if VALUE_INST_VER is not null
# if value is null then fresh install

if [ ! -z ${VALUE_INST_VER}  ]; then

	#------------------------------------------
	# Dependency 2: Determine if this version already exists
	#------------------------------------------

	if [ ${STD_VERSION} = ${VALUE_INST_VER} ] ; then
		write_to_file $STATUS_FAIL ${NS_MSG_THIS_VERSION}
	fi

	cmpstr ${VALUE_INST_VER} ${STD_VERSION} && inst_ver="less" || inst_ver="greater"

	#------------------------------------------
	# Dependency 3: Determine if an older version exists
	#------------------------------------------

	if [ ${inst_ver} = "less" ] ; then
		write_to_file $STATUS_PASS ${NS_MSG_OLDER_VERSION}
	fi

	#------------------------------------------
	# Dependency 4: Determine if a newer version exists
	#------------------------------------------

	if [ ${inst_ver} = "greater" ] ; then
		write_to_file $STATUS_FAIL ${NS_MSG_NEWER_VERSION}
	fi
fi

# Fresh Install
write_to_file $STATUS_PASS
exit;
