#!/bin/sh
# -----------------------------------------------------------------------------
#
#          DELL COMPUTER CORPORATION PROPRIETARY INFORMATION
#
# This software is supplied under the terms of a license agreement or
# nondisclosure agreement with Dell Computer Corporation and may not
# be copied or disclosed except in accordance with the terms of that
# agreement.
#
# Copyright (c) 2001-present Dell Computer Corporation. All Rights Reserved.
#
# Name:    installRac.sh
# 
# Purpose: install RAC software on RedHat Linux platform
#
# Returns: 0 on success, 1 on Warning, 2 on Error
# -----------------------------------------------------------------------------

cd $(dirname $0)
if [ ! -e ./installRacFuncs ]; then
	echo " missing support functions"
	exit 1
fi

. ./installRacFuncs

# ----- sanity check args, get target install environment

outFile="$1"										# arg = filename for status msgs

if [ ".$outFile" = "." ]; then
	say "Status file not specified."
	exit 1
fi

getKernelInfo

# ----- get the product packing list for this environment

getPackingList

# ----- install/update RPMs, write output messages

for i in racser-src $pkgList
{
	rpm -q $i >/dev/nul 2>&1
	cc=$?

	if [ $cc -eq 0 ]; then						# remove rpms already installed
		rpm -e --nodeps $i >/dev/nul 2>&1
	fi
}

oldRC=$rc
rpm -Uvh $rpmList >/dev/nul 2>&1
rc=$?

echo "" 															>> $outFile
if [ $rc -eq 0 ]; then
	instResult="pass"
	rc=0
elif [ $oldRC -eq 0 ]; then
	instResult="warn"
	rc=1
else
	instResult="fail"
	rc=2
fi
echo "$prodName.installationresult=$instResult"		>> $outFile
undoString="/usr/sbin/uninstallRac.sh"
echo "$prodName.uninstallstring=$undoString"			>> $outFile

if [ $rc -lt 2 ]; then
	# add the defined RAC user group to the system, if it doesn't exist yet..
	racGrp=`grep RACGROUP /etc/sysconfig/racsrvc|tr -d "\t "|cut -f1 -d'#'|cut -f2 -d'='`
	if [ ! -z "$racGrp" ]; then
		grep "^$racGrp:" /etc/group >/dev/null 2>&1
		if [ $? -ne 0 ]; then
			groupadd -f $racGrp >/dev/null 2>&1
		fi
	fi
	if [ -x /usr/sbin/installRac2OMDB ]; then
		# attempt to update the OMDB -- don't prevent sub-installs
		#  if errors updating OMDB.. ignore them -- don't back out
		racProj=36
		racName="rac_mn"
		omaName=`/usr/sbin/installRac2OMDB -ac -I $racProj`	
		omaStrg="Remote Access Controller Managed Node"
		if [ ".$omaName" = ".$racName" ]; then		# ensure correct project
			errs=0
			/usr/sbin/installRac2OMDB -au -I $racProj -i 1 -s "$instResult" 
			[ $? -ne 0 ] && errs=$((errs+1))
			/usr/sbin/installRac2OMDB -au -I $racProj -i 3 -s "$omaStrg"
			[ $? -ne 0 ] && errs=$((errs+1))
			/usr/sbin/installRac2OMDB -au -I $racProj -i 5 -s "$undoString"
			[ $? -ne 0 ] && errs=$((errs+1))
			/usr/sbin/installRac2OMDB -au -I $racProj -i 8 -s "${racVer%%-*}"
			[ $? -ne 0 ] && errs=$((errs+1))
			/usr/sbin/installRac2OMDB -au -I $racProj -i 9 -s "$omaStrg"
			[ $? -ne 0 ] && errs=$((errs+1))

			[ $errs -ne 0 ] && /usr/sbin/installrac2OMDB -ad -I $racProj
		fi
	fi
fi

exit $rc
