#!/bin/sh
# -----------------------------------------------------------------------------
#
#          DELL COMPUTER CORPORATION PROPRIETARY INFORMATION
#
# This software is supplied under the terms of a license agreement or
# nondisclosure agreement with Dell Computer Corporation and may not
# be copied or disclosed except in accordance with the terms of that
# agreement.
#
# Copyright (c) 2001-present Dell Computer Corporation. All Rights Reserved.
#
# Name:    installRacCheck.sh
# 
# Purpose: dependency check for RAC software on RedHat Linux platform
#
# Returns: 0 on success, 1 on Warning, 2 on Error
# -----------------------------------------------------------------------------

cd $(dirname $0)
if [ ! -e ./installRacFuncs ]; then
	echo " missing support functions"
	exit 1
fi

. ./installRacFuncs

# ----- sanity check argument, check target install environment

outFile="$1"										# arg = filename for status msgs

if [ ".$outFile" = "." ]; then
	say "Status file not specified."
	exit 1
fi

getKernelInfo 

# ----- get the product packing list for this environment

getPackingList

# ----- check individual packages, add warning messages if already installed

pkgInstalledCount=0

pkgNumericVersion=`echo $vncVer|cut -f1 -d'.'`
pkgNumericRelease=`echo $vncVer|cut -f2 -d'.'|cut -f1 -d'-'`
vncNumericValue=$(((100*pkgNumericVersion) + pkgNumericRelease))

for i in $vncList 
{
	pkgInstalledTest=`rpm -q $i 2>/dev/nul`
	cc=$?

	if [ $cc -eq 0 -a ! ".$pkgInstalledTest" = "." ]; then		# already installed

		savPkg="$pkgInstalled"
		pkgInstalled=`echo $pkgInstalledTest|cut -f2 -d'-'`

		pkgNumericVersion=`echo $pkgInstalled|cut -f1 -d'.'`
		pkgNumericRelease=`echo $pkgInstalled|cut -f2 -d'.'`
		pkgInstalledValue=$(((100*pkgNumericVersion) + pkgNumericRelease))

		pkgInstalledCount=$((pkgInstalledCount+1))

		if [ $pkgInstalledValue -gt $vncNumericValue ]; then
			depMsgAdd 2 $msgID_instimage_isnewer $i
		elif [ $pkgInstalledValue -eq $vncNumericValue ]; then
			depMsgAdd 1 $msgID_already_installed $i
		elif [ ! -z "$savPkg" ]; then
			pkgInstalled="$savPkg"
		fi
	fi
}

pkgNumericVersion=`echo $racVer|cut -f1 -d'.'`
pkgNumericRelease=`echo $racVer|cut -f2 -d'.'|cut -f1 -d'-'`
racNumericValue=$(((100*pkgNumericVersion) + pkgNumericRelease))

for i in $racList 
{
	pkgInstalledTest=`rpm -q $i 2>/dev/nul`
	cc=$?

	if [ $cc -eq 0 -a ! ".$pkgInstalledTest" = "." ]; then		# already installed

		savPkg="$pkgInstalled"
		pkgInstalled=`echo $pkgInstalledTest|cut -f2 -d'-'`

		pkgNumericVersion=`echo $pkgInstalled|cut -f1 -d'.'`
		pkgNumericRelease=`echo $pkgInstalled|cut -f2 -d'.'`
		pkgInstalledValue=$(((100*pkgNumericVersion) + pkgNumericRelease))

		pkgInstalledCount=$((pkgInstalledCount+1))

		if [ $pkgInstalledValue -gt $racNumericValue ]; then
			depMsgAdd 2 $msgID_instimage_isnewer $i
		elif [ $pkgInstalledValue -eq $racNumericValue ]; then
			depMsgAdd 1 $msgID_already_installed $i
		elif [ ! -z "$savPkg" ]; then
			pkgInstalled="$savPkg"
		fi
	fi
}

# ----- write output messages

echo "" 													>> $outFile
echo "$prodName.status=$rc" 						>> $outFile
echo "$prodName.numofmsgs=$depMsgCnt"			>> $outFile
i=0
while [ $i -lt $depMsgCnt ]
do
	echo "$prodName.msgid.$i=${depMsgTxt[i]}"	>> $outFile
	i=$((i+1))
done

if [ $pkgInstalledCount -eq 0 ]; then
	echo "$prodName.installedversion=null"	>> $outFile
else
	echo "$prodName.installedversion=${pkgInstalled}"	>> $outFile
fi

exit $rc
