#!/bin/sh
#################################################
## Determine if the application is launched from an xterm or from XWindows
case $TERM in
	xterm*)  # Do nothing
		;;
	screen*) # Do nothing
		;;
	linux*)
		tty --quiet
		[ $? == 0 ] || \
		{
			exec xterm +ls -e $0 launch $@
		}
		;;
	*) exec xterm +ls -e $0 launch $@
		;;
esac

#################################################
# This section is to display help for all
# supported parameters by this script file
bLaunch=false
while [ $# -ge 1 ] ; do
	if [ $1 == "launch" ]; then
		bLaunch=true
		shift
		continue
	fi
	if [ $1 == "-?" -o $1 == "/?" -o $1 == --help ] ; then
		echo "Usage: uninstall.sh [OPTION]..."
		echo "For uninstalling Server Administrator components"
		echo "-?, /?, --help 		to display this help and exit"
		echo "Administrator rights required to uninstall Systems Management Software"
		echo ""
		[ $bLaunch == true ] && sleep 3
		exit 0
	fi
done

if [ "$USER" != "root" ] ; then
	echo "You need to have administrator rights to install/upgrade/uninstall Systems Management software. Uninstall will exit now."
	[ $bLaunch == true ] && sleep 3
	exit -1
fi

DB_FILE="/etc/ominstal.db"
KEY_INST_UNIN_CMD="Instrumentation.uninstallstring"
KEY_INST_UNIN_CMD_RAC="rac_mn.uninstallstring"
KEY_INST_UNIN_CMD_NS="NETSTARTAGENTS.uninstallstring"

# Check for the DB file
if [ ! -f ${DB_FILE} ];
then
	echo
	echo Uninstall program detects that no components are 
	echo currently installed. Uninstall is aborting...
	echo
	[ $bLaunch == true ] && sleep 3
	exit 1
fi
echo ...Beginning the Uninstall Process
#export CURRENT_WORKING_DIR=`pwd`
JAVA=/usr/lib/dell/openmanage/jre/bin/java
JAR_DIR=/usr/lib/dell/openmanage/uninstall
export CLASSPATH_OLD=$CLASSPATH
export CLASSPATH=$JAR_DIR/install.jar:$JAR_DIR/omdbinst.jar:$JAR_DIR/javainst.jar:$JAR_DIR/omcinst.jar:$JAR_DIR/iwsinst.jar:$JAR_DIR/omhpinst.jar:$JAR_DIR/omdrinst.jar:$JAR_DIR/omdginst.jar:$CLASSPATH

if [ -e $JAR_DIR/omdginst.jar ]
then
	$JAVA tools.install.OLDiagsInstall -u 
fi
if [ -e $JAR_DIR/omdrinst.jar ]
then
	$JAVA tools.install.OMDRSCInstall -u
fi
if [ -e $JAR_DIR/omhpinst.jar ]
then
	echo ...removing OMHIP components
	$JAVA tools.install.OMHIPInstall -u
fi
if [ -e $JAR_DIR/omcinst.jar ]
then
	echo ...removing OMACORE
	$JAVA tools.install.OMACOREInstall -u
fi
if [ -e $JAR_DIR/iwsinst.jar ] 
then
	echo ...removing iws
	$JAVA tools.install.IWSInstall -u
fi
if [ -e $JAR_DIR/javainst.jar ]
then
	echo ...removing omajre components
	$JAVA tools.install.JavaInstall -u
fi

# Get the RAC uninstall command from the DB file
INST_UNIN_CMD_RAC=`grep -i ${KEY_INST_UNIN_CMD_RAC} ${DB_FILE} |
    sed s/${KEY_INST_UNIN_CMD_RAC}=//`
if [ ! -z "${INST_UNIN_CMD_RAC}" ];
then
	echo ${INST_UNIN_CMD_RAC}
	# uncomment the following line to run the command
	${INST_UNIN_CMD_RAC}
else
	echo 
	# echo "Key '${KEY_INST_UNIN_CMD_RAC}' not found in file '${DB_FILE}'"
fi

# Get the NS uninstall command from the DB file
INST_UNIN_CMD_NS=`grep -i ${KEY_INST_UNIN_CMD_NS} ${DB_FILE} |
    sed s/${KEY_INST_UNIN_CMD_NS}=//`
if [ ! -z "${INST_UNIN_CMD_NS}" ];
then
	echo ${INST_UNIN_CMD_NS}
	# uncomment the following line to run the command
	${INST_UNIN_CMD_NS}
else
	echo
	#echo "Key '${KEY_INST_UNIN_CMD_NS}' not found in file '${DB_FILE}'"
fi

# Get the Instrumentation uninstall command from the DB file
INST_UNIN_CMD=`grep -i ${KEY_INST_UNIN_CMD} ${DB_FILE} |
    sed s/${KEY_INST_UNIN_CMD}=//`
if [ ! -z "${INST_UNIN_CMD}" ];
then
	echo ${INST_UNIN_CMD}
	# uncomment the following line to run the command
	${INST_UNIN_CMD}
else
	echo
	#echo "Key '${KEY_INST_UNIN_CMD}' not found in file '${DB_FILE}'"
fi
# Remove the symbolic links files for database interface

# Code to remove DRAC 2 
rpm -e DRAC-Driver-2.5.0-1 dellomsa-omsasync-1.0-2918 DRAC-Common-2.5.0-1 DRAC-Common-2.5.0-2 DRAC-Common-2.5.0-4 >& /dev/null
#

rm -f /usr/lib/libdcomdb.so
rm -f /usr/lib/libdcomdb.so.1
rm -f /etc/ominstal.db
rm -f /etc/dellinst.cfg

export CLASSPATH=$CLASSPATH_OLD
exit 0
