#!/bin/sh
# Copyright (C) 2002, Dell Computer Corporation.
#
# syntax: setnic.sh LanguageCode text/html setnic.rcf NICIndex ipaddress subnetmask router

unset IFS
rs=0
# If not even enough args for sensible error log, then give usage.
if [ `expr $# \>= 3` = 0 ] 
then
  #echo "Usage setnic.sh LanguageCode text/html setnic.rcf NICIndex ipaddress subnetmask router"
  echo "12514"
  exit 1
fi

echo -n "" >$3
echo "Starting $0 with args '$1' '$2' '$3' '$4' '$5' '$6' '$7' " >>$3
if [ $# != 7 -a $# != 6 ]; then 
   #echo "Error: Wrong number of arguments passed, script FAILED." >> $3
   echo "12514" >> $3
   exit 1
fi

# Does this interface even exist?
if [ -n "$fDEBUG" ] 
then
    ifconfig $4             >>$3 2>&1
    rs=$?
else
    ifconfig $4             >>/dev/null 2>&1
    rs=$?
fi
if [ "$rs" != 0 ]
then
    #echo "Error: interface $4 not responding, script FAILED."   >>$3
    echo "12514;$4"   >>$3
    exit 1
fi

# Set the IP address and netmask for this interface.
if [ -n "$fDEBUG" ] 
then
    route -n    >>$3 2>&1
    echo "Do: 'ifconfig $4 $5 netmask $6'"       >>$3
else
    ifconfig $4 $5 netmask $6       >>$3 2>&1
    rs=$?
fi
#ifconfig $4 $5 netmask $6       >>$3 2>&1
if [ "$rs" != 0 ]; then
    #echo "Error: IP configuration, script was executed UNSUCCESSFULLY!" >> $3
    echo "12514;$4" >> $3
    #echo "       Please verify the configuration information you have provided is correct." >> $3
    #echo " " >> $3
    #echo "The following is the configuration information that you have provided:" >> $3
    #echo "Interface: " $4 >> $3
    #echo "IP address: " $5 >> $3
    #echo "Subnet Mask: " $6 >> $3
    exit 1
else
    echo "IP configuration, script was executed SUCCESSFULLY!" >> $3
    # Get hostname from file left by sethostname.sh.
    var=`sed s/host:\// /etc/hosttmp`
    # Add new hostname to the /etc/hosts file.
    echo "$5 $var" >> /etc/hosts
    # Completely replace the /etc/sysconfig/network-scripts file for this ifc.
    echo "DEVICE=$4" > /etc/sysconfig/network-scripts/ifcfg-$4
    echo "IPADDR=$5" >> /etc/sysconfig/network-scripts/ifcfg-$4
    echo "ONBOOT=yes" >> /etc/sysconfig/network-scripts/ifcfg-$4
    echo "NETMASK=$6" >> /etc/sysconfig/network-scripts/ifcfg-$4
    # And add a line to the ip.txt file for the agent to return to server.
    echo "$5" >> ip.txt
fi

# First, try to remove the default gw info, just in case it's the same.
#  Storing the same info that's already there is an error in Linux.
# Spec change: always remove it in case there is no replacement.
# Is there a default gway for this NIC?  If not, ignore.  
#  But there may be more than one!

listofgw=`route -n | grep "$4" | grep "UG" | awk ' {print $2}'`
for currgw in $listofgw
do
    if [ -n "$fDEBUG" ]
    then
        echo "Do: 'route del default gw $currgw $4'"    >>$3
        rs=$?
    else
        route del default gw $currgw $4  >>$3 2>&1
        rs=$?
    fi
    if [ "$rs" = 0 ]
    then
        # If ok, tell the user we removed the old (same) gw
        echo "Removed current or redundant default gw $currgw info from $4, continuing." >> $3
    else
        echo "Error removing default gw $currgw info from $4, continuing." >> $3
    fi 
done

# Now set the gw given, if any.  
if [ -n "$7" ]
then
    if [ -n "$fDEBUG" ] 
    then
        echo "Do: 'route add default gw $7 $4'"       >>$3 
    else
        route add default gw $7 $4     >>$3 2>&1
        rs=$?
    fi #debug
    #route add default gw $7 $4     >>$3 2>&1
    if [ "$rs" != 0 ]; then
        #echo " " >> $3
        #echo "Error: Default gateway configuration, script FAILED!" >> $3
	echo "12514;$4" >> $3
        #echo "       Please verify the configuration information you have provided is correct." >> $3
        #echo " " >> $3
        #echo "The following is the configuration information that you have provided:" >> $3
        #echo "Default Gateway: " $7 >> $3
        exit 1
    else
        echo "GATEWAY=$7" >> /etc/sysconfig/network-scripts/ifcfg-$4
        echo "GATEWAY=$7" >> /etc/sysconfig/network
        echo "Default gateway configuration, script was executed SUCCESSFULLY!" >> $3
    fi #success
fi #gw nonblank

exit 0

# Edits:
#           HP  Original.
# 20020423  RBL Add remove of gateway before set, so that leftover
#               settings do not crash the whole config.
#               Add usage print if nr args too small for rcf.
# 20020517  RBL Harden further. 
#               Send "Starting..." msg.
#               Embed $fDEBUG checks for most commands.
# 20020520  RBL Fix single-quote usage all over.  
#               Real bash requires 'IFS=""' empty string to assign.
#               Put quotes around things that might be null, such as
#                rs and fDEBUG.  
#                And all the echo strings, too, just for cleanliness.
#               Dear user, PLEASE remember to export fDEBUG
#                if you want it to work.  
# 20020611  RBL Make the gateway-addr argument optional. 
#               Move code so that if gw is absent or fails to route
#                then we don't add GATEWAY line to ifcfg-ethN file.
# 20020617  RBL Always remove current default gway info, if any.  
#                Then add default gway specified, if any.  
#                May have to remove multiple old default gways.  
#                Go thru extreme pain and probable bugs in bash to do this.
#                On Linux, must use 'unset IFS' instead of 'IFS=""'.
#               Check for existence of NIC before doing anything.
#               Add ifconfig and route info to log if debug on.  
#
#
