
//--------------------------------------------------------------------
//
//          DELL COMPUTER CORPORATION PROPRIETARY INFORMATION
// This software is supplied under the terms of a license agreement or
// nondisclosure agreement with Dell Computer Corporation and may not
// be copied or disclosed except in accordance with the terms of that
// agreement.
//
// Copyright (c) 1995-2000 Dell Computer Corporation. All Rights Reserved.
// 
// Module Name:
//
//      ESM Device Driver for Linux 
//
// Abstract/Purpose:
//
//   This module contains Linux interface routines for the 
//   device driver of the DELL Embedded Server Management Devices.
//
//
// Environment:
//
//      Linux Server Only
//
//
//--------------------------------------------------------------------
/*
 *  History:
 */

/*--------------------------------------------------------------------
 * Linux include files
 *--------------------------------------------------------------------*/
#include <linux/version.h>
#include <linux/module.h>

#include <linux/fs.h>
#include <linux/kernel.h>
#include <linux/slab.h>
#include <linux/sched.h>
#include <linux/string.h>
#include <linux/mm.h>
#include <linux/errno.h>
#include <linux/pci.h>
#include <linux/timer.h>
#include <linux/mtio.h>
#include <linux/ioctl.h>
#include <linux/fcntl.h>
#include <linux/poll.h>
#include <linux/delay.h>
#include <asm/io.h>
#include <asm/uaccess.h>
#include <asm/system.h>

#include <linux/blk.h>
// chl
#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,4,0)
#include <linux/vmalloc.h>
#include <linux/spinlock.h>
#include <linux/wait.h>
#endif

/*--------------------------------------------------------------------
 * Dell esm include files
 *--------------------------------------------------------------------*/
#ifdef SYSTEM_TYPE_LINUX_DKS_DRIVER
#include "dcesm.h"
#define DrvDbgMsg4(X)
#define DrvDbgMsg3(X)
#else
#include <linux_types.h>
#include <dcbasdef.h>
#include <dcapidef.h>
#include <esmtypes.h>
#include <drvsupt.h>
#include <devsupt.h>
#include <drvdebug.h>
#include <esmapi.h>
#include <biosintf.h>
#include "dcesm.h"
#endif // SYSTEM_TYPE_LINUX_DKS_DRIVER

#define ESM_WITH_INTERRUPTS

void esm_wd_thread(void *data);

/*--------------------------------------------------------------------
 * Local Variables used for this module
 *--------------------------------------------------------------------*/

EXPORT_NO_SYMBOLS;

typedef struct _dcd_thread_data
{
	// Thread ID #
	pid_t ID;
#if LINUX_VERSION_CODE > KERNEL_VERSION(2,4,7)
	// completion pointer
	struct completion compl;
#elif LINUX_VERSION_CODE >= KERNEL_VERSION(2,4,0)
	wait_queue_head_t compl;  // Sempahore for I/O completions
#else
	struct wait_queue *compl;  // Sempahore for watch dog thread signalling
#endif// #if LINUX_VERSION_CODE > KERNEL_VERSION(2,4,7)
	// Pointer to name
	void *pName;
}dcd_thread_data;



//--------------------------------------------------------------------
// Functions Prototypes
//--------------------------------------------------------------------

static int esm_init(void);
int init_device_driver(void);
int esm_init_card(PESM_DEVICE_EXTENSION pEsmCard, u8 MachineID, u32 SysPrdCls);
int esm_register_module(void * ptr);
void EsmUnload(PESM_DEVICE_EXTENSION pEsmCard);
s32 EsmInitDriver(_IN PESM_DEVICE_EXTENSION pEsmCard);
int EsmDeviceIoControl(struct inode * inode,
        struct file * filp,
        PESM_DEVICE_EXTENSION pEsmCard,
        unsigned int cmd_in,
        unsigned long arg,
        int *lpBytesReturned);
void esm_spin_lock(PESM_DEVICE_EXTENSION pEsmCard);
void esm_spin_unlock(PESM_DEVICE_EXTENSION pEsmCard);
void esm_spin_lock_bh(PESM_DEVICE_EXTENSION pEsmCard);
void esm_spin_unlock_bh(PESM_DEVICE_EXTENSION pEsmCard);
void esm_spin_lock_irq(PESM_DEVICE_EXTENSION pEsmCard);
void esm_spin_unlock_irq(PESM_DEVICE_EXTENSION pEsmCard);
unsigned long esm_spin_lock_irqsave(PESM_DEVICE_EXTENSION pEsmCard);
void esm_spin_unlock_irqrestore(PESM_DEVICE_EXTENSION pEsmCard, unsigned long esmflags);
s32 EsmStartDev(_INOUT PESM_DEVICE_EXTENSION pEsmCard);
void EsmStopDev(PESM_DEVICE_EXTENSION pEsmCard);
s32 EsmDDStart(_INOUT PESM_DEVICE_EXTENSION pEsmCard);
void EsmDDStop(_INOUT PESM_DEVICE_EXTENSION pEsmCard);
extern void EsmDD1SecTimerDpcRoutine(PESM_DEVICE_EXTENSION pEsmCard);
void esm_wake_up(void *QueuePtr);
void esm_sleep_on(void *QueuePtr);
void esm_init_timer(void *TimerPtr);
void esm_add_timer(void);

//--------------------------------------------------------------------
// Driver error messages
//--------------------------------------------------------------------

char EMsgDevNotFound[] = "\r\nDCESM driver could not find the device.\r\n";

int esm_major = 0;
int WDThreadExitingFlag = FALSE;


static int esm_open(struct inode * inode, struct file * filp)
{

    DrvDbgMsg4(("esm_open: entry\n"));

    return 0;
}

/* Following function was formerly called 'esm_close' */
static int esm_release(struct inode * inode, struct file * filp)
{

    DrvDbgMsg4(("esm_release: entry\n"));
    return 0;
}


static int esm_ioctl(struct inode * inode, struct file * filp,
                    unsigned int cmd_in, unsigned long arg)
{
    int	IoCmdStatus = 0; 
    u32 BytesReturned;
    ESM_DEVICE_EXTENSION *pEsmCard = &esm_card;

    DrvDbgMsg4(("esm_ioctl: entry\n"));

    IoCmdStatus = EsmDeviceIoControl( inode, filp, pEsmCard, cmd_in, arg,
		&BytesReturned);

    return (IoCmdStatus);
}

static struct file_operations esm_fops = {
#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,4,0)
	    owner: 		THIS_MODULE,
	    ioctl:		esm_ioctl,
	    open:		esm_open,
	    release:		esm_release,
#else
	    NULL,            /* lseek */
	    NULL,            /* read */
	    NULL,            /* write */
	    NULL,            /* readdir */
	    NULL,            /* poll */
	    esm_ioctl,       /* ioctl */
	    NULL,            /* mmap */
	    esm_open,        /* open */
	    NULL,            /* flush */
	    esm_release,     /* release, was formerly sg_close */
	    NULL,            /* fsync */
	    NULL,            /* fasync */
	    NULL,            /* check_media_change */
	    NULL,            /* revalidate */
	    NULL,            /* lock */
#endif
	};

/* Driver initialization */
static int esm_init()
{
	static int esm_registered = 0;
	int result, rc;

	if(!esm_registered) 
	{
		result = register_chrdev(esm_major,"esm",&esm_fops);
		if (result < 0)
		{
			printk("Unable to get major %d for Dell ESM device\n",esm_major);
			return 1;
		}
		if (esm_major == 0) esm_major = result; /* dynamic */
		{
			esm_registered++;
		}
	}

	rc = init_device_driver();
	if (rc) 
	{
		printk("Unable to initialize the ESM device driver, major number: %d\n",esm_major);
		unregister_chrdev(esm_major, "esm");
		return 1;
	}

	return 0;
}


#ifdef MODULE

int init_module(void) 
{
	if (esm_init())
	{
		return (ESM_STATUS_CMD_UNSUCCESSFUL);
	}
	return (ESM_STATUS_CMD_SUCCESS); 
}

void cleanup_module( void)
{
	EsmUnload(&esm_card);
}

#endif /* MODULE */


/* Inititialize the driver and ESM card */
int init_device_driver()
{
	PESM_DEVICE_EXTENSION pEsmCard;

	/*  return the input request packet as the output request packet with */

	/* clear the card structure first */
	memset(&esm_card, 0, sizeof(ESM_DEVICE_EXTENSION));

	// Point to ESM Driver Structure
	pEsmCard = &esm_card;

	esm_init_wd_thread_semaphore();

	pEsmCard->wd_thread_data = esm_kernel_thread(esm_wd_thread,
								(void *)pEsmCard,
								"esm_wd_thread");
	if(pEsmCard->wd_thread_data == NULL)
	{
		printk("kernel thread creation failed\n");
	}
	// initialize driver structure and device
	if (EsmInitDriver(pEsmCard) != ESM_STATUS_CMD_SUCCESS)
	{
		DrvDbgMsg3(("main: EsmInitDriver failed\n"));
		return ESM_STATUS_CMD_NO_SUCH_DEVICE;
	}

	return (ESM_STATUS_CMD_SUCCESS);
} /* init_device_driver */

//---------------------------------------------------------------------
// EsmUnload - stop processing ESM Commands; stop monitoring; stop watchdog
//---------------------------------------------------------------------
void EsmUnload(PESM_DEVICE_EXTENSION pEsmCard)
{

	DrvDbgMsg3(("EsmUnload: entry\n"));

	// stop device operation
	EsmStopDev(pEsmCard);

	//Stop watch dog thread
	WDThreadExitingFlag = TRUE;
	esm_wakeup_wd_thread_semaphore();
	esm_wait_for_thread_completion(pEsmCard->wd_thread_data);
	esm_kill_thread(pEsmCard->wd_thread_data);
	
	// stop device driver
	EsmDDStop(pEsmCard);

	// stop the timer
	del_timer(&EsmTimer);

	unregister_chrdev(esm_major, "esm");


} // EsmUnload 


//---------------------------------------------------------------------
// EsmInitDriver
//---------------------------------------------------------------------
s32 EsmInitDriver(_IN PESM_DEVICE_EXTENSION pEsmCard)
{
        s32 EsmStatus;

		pEsmCard->ZeroToVideoStartMapped = FALSE;
        pEsmCard->VideoEndTo1MBMemMapped = FALSE;
		pEsmCard->ICHSWDMapped = FALSE;

        // initialize driver structure
        if (EsmDDStart(pEsmCard) != ESM_STATUS_CMD_SUCCESS)
        {
                printk(EMsgDevNotFound);
                return ESM_STATUS_CMD_NO_SUCH_DEVICE;
        }
	/* Allocate Spin lock */
//	spin_lock_init(&pEsmCard->ControlLock);
	spin_lock_init(&ControlLock_bhlock);
	spin_lock_init(&ControlLock_irqlock);
	//ControlLock = SPIN_LOCK_UNLOCKED;

        // Initialize ESM Device if present
        if ((EsmStatus = EsmStartDev(pEsmCard))
                != ESM_STATUS_CMD_SUCCESS)
        {

                // stop driver
                EsmDDStop(pEsmCard);

                DrvDbgMsg3(("EsmInitDriver: EsmInitDevice failed\n"));

                return ESM_STATUS_CMD_NO_SUCH_DEVICE;
        } // init device


	pEsmCard->ImgUpdBufSize = 0;
	
	return ESM_STATUS_CMD_SUCCESS;
} // EsmInitDriver

void esm_wake_up_IO_semaphore(void)
{
	esm_wake_up(&IOIRPCompleteSemaphore);
}

void esm_wake_up_event_semaphore(void)
{
	esm_wake_up(&EventIRPCompleteSemaphore);
}

void esm_wakeup_wd_thread_semaphore()
{
	esm_wake_up(&wd_thread_semaphore);
}

void esm_init_wd_thread_semaphore(void)
{
#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,4,0)
        init_waitqueue_head(&wd_thread_semaphore);
#else
        // catch GPFs
        wd_thread_semaphore = NULL;
#endif
}

void esm_init_io_semaphore(void)
{
#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,4,0)
        init_waitqueue_head(&IOIRPCompleteSemaphore);
#else
        // catch GPFs
        IOIRPCompleteSemaphore = NULL;
#endif
}

void esm_sleep_on_io_semaphore(void)
{
         esm_sleep_on(&IOIRPCompleteSemaphore);
}

void esm_sleep_on_event_semaphore(void)
{
         esm_sleep_on(&EventIRPCompleteSemaphore);
}

void esm_sleep_on_wd_thread_semaphore(void)
{
         sleep_on(&wd_thread_semaphore);
}

void esm_init_event_semaphore(void)
{
#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,4,0)
        init_waitqueue_head(&EventIRPCompleteSemaphore);
#else
        // catch GPFs
        EventIRPCompleteSemaphore = NULL;
#endif
}

int esm_copy_from_user(void *target, void *source, int size)
{
	int result;

	result = copy_from_user(target, source, size);
	return result;
}

int esm_copy_to_user(void *target, void *source, int size)
{
	int result;

	result = copy_to_user(target, source, size);
	return result;
}

void esm_put_user(int value, int *esm_address)
{
	put_user(value, esm_address);
}

// Verify the argument

int esm_verify_area(int cmd_in, void *arg, int size)
{
	int result;
	result = verify_area(cmd_in, arg, size);
	return result;
}

// Lock the spinlock

unsigned long esm_spin_lock_irqsave(PESM_DEVICE_EXTENSION pEsmCard)
{
	unsigned long esmflags;
	spin_lock_irqsave(&ControlLock_irqlock, esmflags);
	return esmflags;
}

// Unlock the spinlock

void esm_spin_unlock_irqrestore(PESM_DEVICE_EXTENSION pEsmCard, unsigned long esmflags)
{
		spin_unlock_irqrestore(&ControlLock_irqlock, esmflags);
	
}

// Lock the spinlock

void esm_spin_lock_bh(PESM_DEVICE_EXTENSION pEsmCard)
{
	   spin_lock_bh(&ControlLock_bhlock);
}

// Unlock the spinlock

void esm_spin_unlock_bh(PESM_DEVICE_EXTENSION pEsmCard)
{
		spin_unlock_bh(&ControlLock_bhlock);
	
}

// Lock the spinlock

void esm_spin_lock(PESM_DEVICE_EXTENSION pEsmCard)
{
	   spin_lock(&ControlLock_bhlock);
}

// Unlock the spinlock

void esm_spin_unlock(PESM_DEVICE_EXTENSION pEsmCard)
{
	spin_unlock(&ControlLock_bhlock);
	
}

// Lock the spinlock

void esm_spin_lock_irq(PESM_DEVICE_EXTENSION pEsmCard)
{
	   spin_lock_irq(&ControlLock_irqlock);
}

// Unlock the spinlock

void esm_spin_unlock_irq(PESM_DEVICE_EXTENSION pEsmCard)
{
		spin_unlock_irq(&ControlLock_irqlock);
	
}

// Sleep on the queue

void esm_sleep_on(void *QueuePtr)
{
	
	sleep_on(QueuePtr);
	
}

// Wake up the wait queue

void esm_wake_up(void *QueuePtr)
{
	
	wake_up(QueuePtr);
	
}

// Setup interrupt handler

int esm_request_irq(int IrqLevel, void *EsmISRAddr, int ISR_flag, char *DriverName,
		PESM_DEVICE_EXTENSION pEsmCard)
{
	int Status;

	Status = request_irq(IrqLevel, EsmISRAddr,
                                ISR_flag, DriverName, pEsmCard);
 	return Status;	
}

// Free interrupt handler

void esm_free_irq(int IrqLevel, PESM_DEVICE_EXTENSION pEsmCard)
{
	free_irq(IrqLevel, pEsmCard);
}

s32 EsmLoadDD1SecTimer(PESM_DEVICE_EXTENSION pEsmCard)
{
        /* Initialize and start the timer */
        esm_init_timer(&EsmTimer);
        EsmTimer.function = (void *) EsmDD1SecTimerDpcRoutine;
        EsmTimer.data = (unsigned long) pEsmCard;
        EsmTimer.expires = (unsigned long) 1 * HZ;
        esm_add_timer();

        return ESM_STATUS_CMD_SUCCESS;
} // EsmLoadDD1SecTimer


// Initialize the timer

void esm_init_timer(void *TimerPtr)
{
	init_timer(TimerPtr);
}

// Add the timer

void esm_add_timer(void)
{
	add_timer(&EsmTimer);
}

// Delete the timer

void esm_del_timer(void)
{
	del_timer(&EsmTimer);
}

long *esm_kmalloc(int BufLen)
{
   void *BufPtr;

   BufPtr = (void *) kmalloc( BufLen, GFP_KERNEL);
   return BufPtr;
}

long *esm_vmalloc(int BufLen)
{
   void *BufPtr;

   BufPtr = (void *) vmalloc( BufLen);
   return BufPtr;
}

void esm_kfree(void *DataPtr)
{
   kfree((char *)DataPtr);
}

void esm_vfree(void *DataPtr)
{
   vfree((char *)DataPtr);
}

u32 GetAPMCmdBufPhysAddr(PESM_DEVICE_EXTENSION pEsmCard)
{
    LONG APMCmdPhysAddr;


	// get the physical address of the buffer
	APMCmdPhysAddr = virt_to_phys((LONG *)pEsmCard->pAPMDMABuf);


	return (u32)APMCmdPhysAddr;
} // GetAPMCmdBufPhysAddr

s32 MapPhysMem(MappedPhysMem *pMPM, u32 PhysAddress, u32 Length)
{

	pMPM->pVirtAddress = ioremap(PhysAddress, Length);
        pMPM->PhysAddress = PhysAddress;
        pMPM->Length = Length;

        return ESM_STATUS_CMD_SUCCESS;
} // MapPhysMem

void UnMapPhysMem(MappedPhysMem *pMPM)
{
	iounmap(pMPM->pVirtAddress);
} // UnMapPhysMem

u32 GetBIOSUpdImgBufPhysAddr(PESM_DEVICE_EXTENSION pEsmCard)
{
        LONG ImgBufPhysAddr;


        // get the physical address of the buffer
        ImgBufPhysAddr =  virt_to_phys((void *)pEsmCard->pImgUpdBuf);

        return (u32)ImgBufPhysAddr;
} // GetBIOSUpdImgBufPhysAddr

s32 ReadPhysMem(PESM_DEVICE_EXTENSION pEsmCard,
					MappedPhysMem *pMPM1, 
					void *pDest, 
					u32 *pDestSize, 
					u32 Address, 
					u32 NumUnits, 
					u32 UnitSize)
{
	u32 AccessLength;
	unchar *memaddr;
	MappedPhysMem *pMPM;


	//validate pMPM 
	if(pMPM1 == NULL)
	{
		//It means the MPM is not initialized
		//Ignore the MPM received and get a new one based on the Address 

		//Check if the address is in between 0-A0000  and C0000-100000
		if(Address < PHYSICAL_ADDRESS_VIDEO_START)
		{
			//Address between 0-0xA0000
			pMPM = &pEsmCard->ZeroToVideoStart;
				
		}
		else if((Address > PHYSICAL_ADDRESS_VIDEO_END) && 
				(Address < PHYSICAL_ADDRESS_1MB))
		{
			//Address between 0xC0000-0x100000
			pMPM = &pEsmCard->VideoEndTo1MBMem;
		}
		else
		{
		//	continue;
			//return ESM_STATUS_CMD_DEVICE_BAD; 
		}

	}
	else
	{
		pMPM = pMPM1;
	}


	// Compute length of memory to be read
	AccessLength = (NumUnits * UnitSize);

	// Perform range checks in a particular order
	if ((AccessLength == 0) || 
		((Address + AccessLength) > 
		(pMPM->PhysAddress + pMPM->Length)) || 
		(AccessLength > *pDestSize))
	{
		*pDestSize = 0;
		return ESM_STATUS_CMD_BAD;
	}

	memaddr = (unchar *)phys_to_virt(Address);
	memcpy ((void *) pDest, (void *) memaddr, AccessLength);

	*pDestSize = AccessLength;

	return ESM_STATUS_CMD_SUCCESS;
} // ReadPhysMem

booln PCIConfigRW(u8 BIOSReqType, u32 BusNumber, u32 SlotNumber, 
				  u32 Offset, void *pValue)
{
    struct pci_dev *pdev = NULL;
    u8 PCIDevFuncNum;
    u8 DevConfigByte;
    u16 DevConfigWord;
    u32 DevConfigDword;
	
    // if PCI BIOS not present punt
    PCIDevFuncNum = ( ((SlotNumber & 0x01F) << 3) | ((SlotNumber >> 5) & 0x07));
    // Find the PCI device
    pdev = pci_find_slot(BusNumber, PCIDevFuncNum);  	

    // if PCI BIOS not present punt
    if (pdev == NULL) 
    {
	return FALSE;
    }
    // strip unnecessary bits based on request type
    switch (BIOSReqType)
    {
		case PCI_CONFIG_READ_BYTE:
			if (pci_read_config_byte(pdev, Offset, &DevConfigByte)) 
				return FALSE;
			else
				*((u8 *)pValue) = DevConfigByte;
			break;
			
		case PCI_CONFIG_READ_WORD:
			if (pci_read_config_word(pdev, Offset, &DevConfigWord)) 
				return FALSE;
			else
				*((u16 *)pValue) = DevConfigWord;
			break;
			
		case PCI_CONFIG_READ_DWORD:
			if (pci_read_config_dword(pdev, Offset, &DevConfigDword)) 
				return FALSE;
			else
				*((u32 *)pValue) = DevConfigDword;
			break;
			
		case PCI_CONFIG_WRITE_BYTE:
			DevConfigByte = *((u8 *)pValue);

			if (pci_write_config_byte(pdev, Offset, DevConfigByte)) 
				return FALSE;
			break;
		case PCI_CONFIG_WRITE_WORD:
			DevConfigWord = *((u16 *)pValue);
			if (pci_write_config_word(pdev, Offset, DevConfigWord)) 
				return FALSE;
			break;
		case PCI_CONFIG_WRITE_DWORD:
			DevConfigDword = *((u32 *)pValue);
			if (pci_write_config_dword(pdev, Offset, DevConfigDword)) 
				return FALSE;
			break;
			
		default:
			return FALSE; // shame on you - unknown subfunction
    }
	
    return TRUE;
} // PCIConfigRW 

char *esm_get_free_pages (int OrderNumber)
{
	u8 *pImgUpdBuf;
        pImgUpdBuf = (u8 *) __get_free_pages(GFP_KERNEL, OrderNumber);
	
	return pImgUpdBuf;
}
void esm_free_pages(unsigned long BuffPtr, int OrderNumber)
{
       	free_pages(BuffPtr, OrderNumber);
}

void esm_setup_timer_struct(PESM_DEVICE_EXTENSION pEsmCard)
{
	EsmTimer.function = (void *) EsmDD1SecTimerDpcRoutine;
        EsmTimer.data = (unsigned long) pEsmCard;
        EsmTimer.expires = jiffies + (unsigned long) 1 * HZ;	
}

void esm_udelay(int seconds)
{
	udelay(seconds);
}

void esm_printk(char *String)
{
	printk("%s", String);
}

void esm_memmove(char *src, char *dest,  int cnt)
{
	memmove(src,dest,cnt);
}
int esm_memcmp(char *buf1, char *buf2, int cnt)
{
	return memcmp(buf1,buf2,cnt);
}
void esm_memcpy(char *src, char *dest,  int cnt)
{
	memcpy(src,dest,cnt);
}
void esm_memset(char *dest, int value,  int cnt)
{
	memset(dest, value ,cnt);
}

u8 ReadPortUChar(PVOID Port)
{
	u8 in_info;

	in_info = inb( (int)Port); 
        return (in_info);
}

void WritePortUChar(PVOID Port, u8 data)
{
	outb((u8) (data), (int) Port); 
}

u16 ReadPortUShort(PVOID Port)
{
	u16 in_info;

	in_info = inw((int)Port); 
        return (in_info);
}

void WritePortUShort(PVOID Port, u16 data)
{
	outw((u16) (data), (int)Port); 
}

u32 ReadPortULong(PVOID Port)
{
	u32 in_info;

	in_info = inl((int)Port); 
        return (in_info);
}

void WritePortULong(PVOID Port, u32 data)
{
	outl((u32) (data), (int)Port); 
}

void esm_wd_thread(void *data)
{
	unsigned long esmflags;
	PESM_DEVICE_EXTENSION pEsmCard = (PESM_DEVICE_EXTENSION)data;
	#if LINUX_VERSION_CODE > KERNEL_VERSION(2,5,0)
    	daemonize (
			"%s", 
			"esm_wd_thread"
			);
	#elif LINUX_VERSION_CODE > KERNEL_VERSION(2,4,7)
    	daemonize ();
		// need to do this to avoid zombi threads in kernel...
    	reparent_to_init ();
	#else
    	daemonize ();
	#endif// #if LINUX_VERSION_CODE > KERNEL_VERSION(2,5,0)

	strcpy (
		current->comm, 
		"esm_wd_thread"
		);

	while(WDThreadExitingFlag == FALSE)
	{
		pEsmCard->wd_thread_sleeping = TRUE;
		esm_sleep_on_wd_thread_semaphore();
		esm_spin_lock(pEsmCard);
		if (EsmIsDevIntUseAllowed(pEsmCard) == TRUE)
		{
			esmflags = esm_spin_lock_irqsave(pEsmCard);
		}
		
		EsmProcess1SecTimer(pEsmCard);
	
		if (EsmIsDevIntUseAllowed(pEsmCard) == TRUE)
		{
			esm_spin_unlock_irqrestore(pEsmCard, esmflags);
		}
		esm_spin_unlock(pEsmCard);
	}//while(ThreadExitingFlag == FALSE)
	esm_complete_thread(pEsmCard->wd_thread_data);
}

//--------------------------------------------------------------------
// esm_kernel_thread
//--------------------------------------------------------------------
void* esm_kernel_thread(int (*fn)(void *), 
						void *arg,
						void *pThreadName)
{

	dcd_thread_data* pThreadData;

	// Allocate thread data space...
	pThreadData = esm_vmalloc(
		sizeof(dcd_thread_data)
		);

	if (pThreadData == NULL )
	{
		// failed to allocate memory
		printk(
			"esm_kernel_thread: failed to allocate memory\n"
			);
		return NULL;
	}

#if LINUX_VERSION_CODE > KERNEL_VERSION(2,4,7)
	// Initialize the thread data...
	init_completion(
		&pThreadData->compl
		);
	
#elif LINUX_VERSION_CODE >= KERNEL_VERSION(2,4,0)
        init_waitqueue_head(
			&pThreadData->compl
			);
#else
        // catch GPFs
        pThreadData->compl = NULL;
#endif
	// create kernel thread...
	pThreadData->ID = kernel_thread(
		fn, 
		arg, 
		(CLONE_FS | CLONE_FILES | CLONE_SIGHAND)
		);

	if ( pThreadData->ID < 0)
	{
		// failed to create thread.
		// free the thread data.
		esm_vfree (
			pThreadData
			);

		printk(
			"esm_kernel_thread: failed to create thread\n"
			);

		return NULL;
	}

	// store kernel thread name...
	pThreadData->pName = pThreadName;

	// return pointer to the thread structure.
	return (void *)pThreadData;
}// esm_kernel_thread


//--------------------------------------------------------------------
// esm_kill_thread
//--------------------------------------------------------------------
int esm_kill_thread(void *pThreadData)
{
	int error;
	dcd_thread_data *pThread = (dcd_thread_data *)pThreadData;

	if (pThreadData == NULL )
	{
		// Null thread data pointer provided
		printk(
			"esm_kill_thread: Null thread data pointer received\n"
			);
		return 1;
	}

	// Kill thread...
	error = kill_proc(
		pThread->ID,
		SIGTERM, 
		1
		);

//	printk(
//		"esm_kill_thread: PID %d killed: error no %d\n",
//		pThread->ID, 
//		error 
//		);

	// free thread data memory
	esm_vfree (
		pThreadData
		);

	// success
	return 0;
}// esm_kill_thread


//--------------------------------------------------------------------
// esm_complete_thread
//--------------------------------------------------------------------
void esm_complete_thread(void* pThreadData)
{
	dcd_thread_data *pThread = (dcd_thread_data *)pThreadData;
#if LINUX_VERSION_CODE > KERNEL_VERSION(2,4,7)
	complete(
		&pThread->compl
		);
#else
		esm_wake_up(
			&pThread->compl
			);

#endif// #if LINUX_VERSION_CODE > KERNEL_VERSION(2,4,7)
}// esm_complete_thread


//--------------------------------------------------------------------
// esm_wait_for_thread_completion
//--------------------------------------------------------------------
void esm_wait_for_thread_completion(void* pThreadData)
{
	dcd_thread_data *pThread = (dcd_thread_data *)pThreadData;
#if LINUX_VERSION_CODE > KERNEL_VERSION(2,4,7)
	wait_for_completion(
		&pThread->compl
		);
#else
	esm_sleep_on(
		&pThread->compl
		);
#endif// #if LINUX_VERSION_CODE > KERNEL_VERSION(2,4,7)
}// esm_wait_for_thread_completion


//--------------------------------------------------------------------
// esm_daemonize_thread
//--------------------------------------------------------------------
void esm_daemonize_thread(void* pThreadData)
{
	dcd_thread_data *pThread = (dcd_thread_data *)pThreadData;
#if LINUX_VERSION_CODE > KERNEL_VERSION(2,5,0)
    daemonize (
		"%s", 
		pThread->pName
		);
#elif LINUX_VERSION_CODE > KERNEL_VERSION(2,4,7)
    daemonize ();
	// need to do this to avoid zombi threads in kernel...
    reparent_to_init ();

#else
    daemonize ();
#endif// #if LINUX_VERSION_CODE > KERNEL_VERSION(2,5,0)

	strcpy (
		current->comm, 
		pThread->pName
		);
}// esm_daemonize_thread


