
//--------------------------------------------------------------------
//
//          DELL Inc. PROPRIETARY INFORMATION
// This software is supplied under the terms of a license agreement or
// nondisclosure agreement with Dell Computer Corporation and may not
// be copied or disclosed except in accordance with the terms of that
// agreement.
//
// Copyright (c) 1995-2003 Dell Inc. All Rights Reserved.
// 
//
// Abstract/Purpose:
//
// Linux driver data structure definitions
//
//
// Environment:
//
// Linux kernel mode only
//
//--------------------------------------------------------------------


#ifndef __ESMTYPES_H_INCLUDED__
#define __ESMTYPES_H_INCLUDED__


#ifdef __cplusplus
extern "C" {
#endif

#pragma pack(1)

#include <linux/version.h>
#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,4,0)
#include <linux/spinlock.h>
#include <linux/wait.h>
#endif

//---------------------------------------------------------------------
// Data Types
//---------------------------------------------------------------------

typedef void VOID;

typedef signed char     SBYTE;      /* 1 byte, signed */
typedef unsigned char   UBYTE;      /* 1 byte, unsigned */
typedef unsigned char   UCHAR;      /* 1 byte, unsigned */
typedef unsigned char * PUCHAR;     /* 1 byte, unsigned */
typedef signed short    SWORD;      /* 2 bytes, signed */
typedef unsigned short  UWORD;      /* 2 bytes, unsigned */
typedef unsigned short  USHORT;     /* 2 bytes, unsigned */
typedef unsigned short *  PUSHORT;     /* 2 bytes, unsigned */
typedef unsigned int    UINT;       /* 4 bytes, unsigned */
typedef signed long     SLONG;      /* 4 bytes, signed */
typedef long     	LONG;      /* 4 bytes, signed */
typedef unsigned long   ULONG;      /* 4 bytes, unsigned */
typedef unsigned long * PULONG;     /* 4 bytes, unsigned */
typedef unsigned long   DWORD;      /* 4 bytes, unsigned */
typedef short		booln;
typedef short		BOOLEAN;
typedef void * PVOID;
typedef char		astring;
typedef short int 	ustring;  // the data type for unixcode string

#ifndef UNREFERENCED_PARAMETER
#define UNREFERENCED_PARAMETER(P)                                       \
    {                                                                                           \
        (P) = (P);                                                                      \
    }

#endif

#define MAX_PATH_SIZE	(256)
#define MAX_IPHOSTNAME_SIZE (64) // max size in bytes of host name
#define SMINTF
#define _cdecl
#define __cdecl
#ifndef ARGUMENT_PRESENT
// Determine if an argument is present by testing the value of the pointer
// to the argument value
#define ARGUMENT_PRESENT(ARGPTR)                    \
                ((u8 *)(ARGPTR) != (u8 *)(NULL))
#endif

//---------------------------------------------------------------------
// Data Direction Markers
//---------------------------------------------------------------------
#define _IN
#define _OUT
#define _INOUT
#define _PRIV
#define _USER

#ifndef FALSE
#define FALSE					(0)
#endif

#ifndef TRUE
#define TRUE					(1)
#endif

#ifndef BIT
#define BIT(x)					(1 << x)
#endif

#ifndef MIN
#define MIN(x,y)				((x < y) ? x : y)
#endif

#ifndef MAX
#define MAX(x,y)				((x > y) ? x : y)
#endif

#ifndef FIELD_OFFSET
// FIELD_OFFSET calculates the byte offset of FIELD within a structure STRUCT
#define FIELD_OFFSET(STRUCT, FIELD)		    \
		((s32)&(((STRUCT *)0)->FIELD))
#endif

#ifndef NUM_1D_ARR_ELEMENTS
// calculate the number of dimension size of a single dimension array
#define NUM_1D_ARR_ELEMENTS(ARRNAME)            (sizeof(ARRNAME)/sizeof(ARRNAME[0]))
#endif


#define INVALID_HANDLE_VALUE                (-1)

#define ESM_OK	0
#define ESM_ERROR -1

//---------------------------------------------------------------------
// Defines
//---------------------------------------------------------------------
#define MPS_NUM_FEATURE_INFO_BYTES				(5) // N umber of feature information bytes

// value for AL
#define PCI_BIOS_PRESENT                                        (0x01)
#define PCI_FIND_PCI_DEVICE                                     (0x02)
#define PCI_FIND_CLASS_CODE                                     (0x03)
#define PCI_GENERATE_CYCLE                                      (0x06)
#define PCI_CONFIG_READ_BYTE                            (0x08)
#define PCI_CONFIG_READ_U8                                      (0x08)
#define PCI_CONFIG_READ_WORD                            (0x09)
#define PCI_CONFIG_READ_U16                                     (0x09)
#define PCI_CONFIG_READ_DWORD                           (0x0A)
#define PCI_CONFIG_READ_U32                                     (0x0A)
#define PCI_CONFIG_WRITE_BYTE                           (0x0B)
#define PCI_CONFIG_WRITE_U8                                     (0x0B)
#define PCI_CONFIG_WRITE_WORD                           (0x0C)
#define PCI_CONFIG_WRITE_U16                            (0x0C)
#define PCI_CONFIG_WRITE_DWORD                          (0x0D)
#define PCI_CONFIG_WRITE_U32                            (0x0D)
#define PCI_GET_IRQ_ROUTING_TBL                         (0x0E)
#define PCI_SET_IRQ                                                     (0x0F)

#define ESM_STATUS_CMD_UNSUCCESSFUL             (-1)
#define ESM_STATUS_CMD_SUCCESS                  (0)
#define ESM_STATUS_CMD_NOT_IMPLEMENTED          (1)
#define ESM_STATUS_CMD_BAD                      (2)
#define ESM_STATUS_CMD_TIMEOUT                  (3)
#define ESM_STATUS_CMD_CANCELLED                (4) // Host initiated cancelled command
#define ESM_STATUS_CMD_ABORT                    (5) // ESM initiated cancelled command
#define ESM_STATUS_CMD_PENDING                  (6)
#define ESM_STATUS_CMD_NO_SUCH_DEVICE           (7)
#define ESM_STATUS_CMD_DEVICE_BUSY              (8)
#define ESM_STATUS_CMD_DEVICE_BAD               (9)
#define ESM_STATUS_CMD_DEVICE_SPURIOUS_INTR     (10)
#define ESM_STATUS_CMD_RESOURCE_LOCKED          (11)
#define ESM_STATUS_CMD_INVALID_INDEX            (12)
#define ESM_STATUS_CMD_SMB_ERROR                (13)

#define PHYSICAL_ADDRESS_1MB                            (0x100000L)
#define PHYSICAL_ADDRESS_VIDEO_START            (0xA0000L)
#define PHYSICAL_ADDRESS_VIDEO_END                      (0xC0000L)

//---------------------------------------------------------------------
// Common Data types
//---------------------------------------------------------------------
// mapped physical memory structure for all OS
typedef struct _MappedPhysMem
{
        void *pVirtAddress; // Virtual address memory mapped
        void *pCtx; // Context information for this map structure
        u32 PhysAddress; // starting physical address
        u32 Length; // length of memory mapped beginning at physical address
} MappedPhysMem;

// SMB state structure
typedef struct _SMBStateStruct
{
	u32 SMBProcessState; // keeps track of state machine for SMB perform command routine
	u32 SMBTransmittedCount; // count of number of bytes transmitted
	u32 SMBReceivedCount; // count of number of bytes received
	booln SMBLookingGood; // The SMB Bus is looking good
	booln SMBIsrDone; // Is the ISR done with all its processing
	u8 SMBI2CStatus; // keeps track of status of I2C bus
	u8 SMBChecksum; // Checksum counter for generating checksum
	u8 ReservedAlign[2]; // alignment for next data element
} SMBStateStruct;


// IPMI state structure
typedef struct _IPMIStateStruct
{
	u32 IOPBase; // Base address of the host interface
	u8 NumPorts; // Number of ports used by the interface
	u8 HostIntfType; // Host interface type IPMI_BMC_HOST_INTF_TYPE_XXX
	u8 SpecVer; // BMC IPMI specification revision in BCD format eg. 09h=v0.9 amd 10h=v1.0
	u8 BMCRsSA; // I2C Slave address of baseboard management controller (BMC)
	u8 NVStoreRsSA; // Bus ID of the NV storage device. If not storade device exists it is ffh
	u8 IrqPolarity; // Interrupt active polarity IPMI_IRQ_POLARITY_XXX
	u8 IrqTriggerMode; // Interrupt trigger mode IPMI_IRQ_TRIGMODE_XXX
	u8 IrqLevel; // Interrupt number for host interface. 00h = Unspecified
	u8 RqSeq; // IPMB Request Sequence number that will be used next
	u8 MaxRqSeq; // Maximum IPMB Request Sequence number that can be used
	u8 BTSeq; // BT Reqest Sequence number that will be used next
	u8 MaxBTSeq; // Maximum BT Request Sequence number that can be used
} IPMIStateStruct;







/*
 * The success status codes 0 - 63 are reserved for wait completion status.
 */
#define STATUS_SUCCESS                          0

/*
 * MessageId: STATUS_UNSUCCESSFUL
 *
 * MessageText:
 *
 * {Operation Failed}
 * The requested operation was unsuccessful.
 */

#define STATUS_UNSUCCESSFUL              0x00000001

/*
 * MessageId: STATUS_NO_SUCH_DEVICE
 *
 * MessageText:
 *
 *  A device which does not exist was specified.
 */
#define STATUS_NO_SUCH_DEVICE            0x0000000e

/*
 * MessageId: STATUS_INSUFFICIENT_RESOURCES
 *
 * MessageText:
 *
 *  Insufficient system resources exist to complete the API.
 */


#define STATUS_INSUFFICIENT_RESOURCES    0xC000009A

typedef struct _VersionInfo         // _VersionInfo defines the structure for version infor of HIP components
{
        _OUT s8 MajorVersion;           // Major version number of component can be -1
        _OUT s8 MinorVersion;           // Minor version number of component can be -1
} VersionInfo;


// _MachineData defines the structure
// for machine specific flags
typedef struct _MachineData
{
        _OUT booln IsDell; // TRUE if Host System on which driver is running is a Dell System
        _OUT u8 MachineID; // MachineID of Host System on which driver is running (valid only if IsDell is TRUE)
        _OUT booln IsServer; // TRUE if Host System on which driver is running is a Server
        _OUT booln IsWorkStation; // TRUE if Host System on which driver is running is a WorkStation
        _OUT booln IsDesktop; // TRUE if Host System on which driver is running is a Desktop
        _OUT booln IsPortable; // TRUE if Host System on which driver is running is a Portable
        _OUT booln IsNetPC; // TRUE if Host System on which driver is running is a NetPC
} MachineData;


// HostSysInfo defines the elements
// describing the Host System
typedef struct _HostSysInfo
{
        // One byte machine id
        _OUT u8 MachineId;
        // One byte BIOS Brand ID
        _OUT u8 BrandId;
        // Two byte System ID Extension
        _OUT u16 SysIdExt;
        // System Product Classification
        _OUT u32 SysPrdCls;
	_OUT u8 ESM4Present;
} HostSysInfo;

// _SMBIOSEPSTableInfo defines elements
// of SMBIOS Entry Point Structure Table
typedef struct _SMBIOSEPSTableInfo
{
        _OUT booln SMBIOSPresent; // TRUE if SMBIOS is present on this host
        _OUT VersionInfo Version; // Version of SMBIOS if found
        _OUT u32 TableStartAddress; // Physical addres of SMBIOS structure table base
        _OUT u16 TableLength; // Length of SMBIOS structure table
        _OUT u16 StructCount; // Total number of structures in structure table
        _OUT u16 MaxStructSize; // Size of the largest structure formatted section in the structure table
        _OUT u16 MaxStructTotalSize; // Size of the largest structure formatted and unformatted section in the structure table
        _OUT booln StructCorrupted; // TRUE if SMBIOS structures are present but corrupted on this host
        _OUT booln PIRTPresent; // TRUE if $PIR table is present on this host
        _OUT u32 PIRTStartAddress; // Physical address of $PIR table base
        _OUT u32 PIRTSize; // Size of $PIR Table
} SMBIOSEPSTableInfo;

// _MPSTableInfo defines elements
// of Multi Processor Specification
typedef struct _MPSTableInfoStruct
{
        _OUT booln MPSTablePresent; // TRUE if MPS table is present on this host
        _OUT VersionInfo Version; // Version of MPS table detected
        _OUT u32 MPSCTHdrAddress; // Base Physical Address of MPS configuration table header
        _OUT u32 MPSOEMTableAddress; // Base Physical Address of MPS OEM configuration table
        _OUT u16 MPSBCTableLength; // Length of MPS base configuration table (starts at MPSCTHdrAddress + 44)
        _OUT u16 MPSEXTableLength; // Length of MPS extended table (starts at MPSCTHdrAddress + 44 + MPSBCTableLength)
        _OUT u16 MPSOEMTableLength; // Length of MPS OEM table (starts at MPSOEMTableAddress)
        _OUT u16 MPSBCTEntryCount; // Number of BCT entries in the variable portion of the base config table
        _OUT u8 MPSFeatureInfo[MPS_NUM_FEATURE_INFO_BYTES]; // Feature Info Bytes found in the Floating Point Structure
        _PRIV u8 ReservedAlign[1]; // Alignment for next data element
} MPSTableInfoStruct;

#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,4,0)
        wait_queue_head_t IOIRPCompleteSemaphore;  // Sempahore for I/O completions
        wait_queue_head_t EventIRPCompleteSemaphore;  // Sempahore for Event IRP completions
        wait_queue_head_t wd_thread_semaphore;  // Sempahore for watch dog thread signalling
#else
        struct wait_queue *IOIRPCompleteSemaphore;  // Sempahore for I/O completions
        struct wait_queue *EventIRPCompleteSemaphore;  // Sempahore for Event IRP completions
        struct wait_queue *wd_thread_semaphore;  // Sempahore for watch dog thread signalling
#endif
struct timer_list EsmTimer; // The timer structure for Linux
spinlock_t    ControlLock_bhlock;  // Sempahore spin lock for submitting IO requests
spinlock_t    ControlLock_irqlock;  // Sempahore spin lock for submitting IO requests

typedef struct _ESM_DEVICE_EXTENSION
{
	// Driver state variables
	MappedPhysMem ZeroTo1MBMem;// Virtual address of first MB of physical address space (0-1MB) 
	MappedPhysMem ZeroToVideoStart; // Virtual address from 0x00000 to 0xA0000
        MappedPhysMem VideoEndTo1MBMem; // Virtual address form 0xC0000 to 0x100000
	MappedPhysMem SMBIOSTableMem; // Virtual address of SMBIOS Structure table
	MappedPhysMem MPSTableMem; // Virtual address of Multi Processor Specification table
	MappedPhysMem TVM5FPMem; // Virtual address of Flash in (FFF00000-FFFFFFFF)
	MappedPhysMem ICHSWDBase; // Virtual address of ICHS WD
	booln ICHSWDMapped;
	booln ZeroToVideoStartMapped;
        booln VideoEndTo1MBMemMapped;
	u8 *pNVTable; // Virtual address of NVRAM Table
	u8 *pImgUpdBuf; // Pointer to driver allocated contiguous memory region for BIOS Image Update
	u8 *pAPMDMABuf; // Pointer to driver allocated contiguous memory region for APM commands
	u32 BIOSImgSize; // actual size of BIOS Image update sent to driver 
	
	MachineData MCData; // Machine Data of Dell system driver is running on
	
	booln IsServer; // TRUE if machine driver running on is a server
	u32 DeviceBitmap; // Bitmap of devices found for the Host System
	
	booln ResourcesAllocated; // Indicates if any resources were allocated from the OS for the driver
	
	u32 ImgUpdBufSize; // size of driver allocated contiguous memory region for BIOS Image Update
	
	u32 APMDMABufSize; // Size of driver allocated contiguous memory region for APM commands
	u32 TVM5SELOffset; // Offset from TVM5FPMem for System Event Log
	
	ULONG InterruptCount; // Number of times we have received interrupts
	booln InterruptRequiresDpc; // If DPC for ISR should be invoked by ISR
	ULONG hDPCForISRCtxHook; // Context Hook Handler handle for ISR DPC proc
	
	ULONG hTimerCtxHook; // Context Hook Handler handle for DPC timer proc
	s32 HeartBeatInterval; // the number of timer seconds between HeartBeats sent to device
	s32 HBTimeOutSecondsCount; // counts number of timer seconds elapsed since last HeartBeat
	
	void *pBusyIrp; // pointer to device I/O IRP chain being processed
	ULONG pBusyIrpPhysAddress; // physical address to device I/O IRP chain being processed
	s32 IRPTimeOutSecondsCount; // counts number of timer seconds elapsed since IRP submitted to controller
	
	PVOID pEventIrp; // pointer to event IRP chain
	PVOID pTimeOutIrp; // pointer to IRP chain that needs to be retired due to timeout
	ULONG pEventIrpPhysAddress; // physical address to event IRP chain
	
	u8 HCActionBitmap; // host control action to be performed
	HostSysInfo HSI; // Host System Information
	s32 HCBeforeActionSeconds; // Number of seconds left to initiate host control action
	u32 SysPrdCls; // system product class
	
	u8 WDState; // The current state of the Watchdog (disabled/enabled etc.)
	u8 WDActionBitmap; // watchdog control action to be performed
	u16 WDTimeOutSeconds; // The current timeout value in seconds stored in the Watchdog
	
	// DRAC state variables
	ULONG DRAPortBase; // Base Address for ESM IO port
	ULONG DRAPortCount; // Count of ports from Base
	
	// the I2C driver tries to simulate an ESM using the 8584 chip
	ULONG I2CPortBase; // Base Address for I2C 8584 IO port
	
	// The SMBus driver using the PIIX4 SMBus master controller
	ULONG SMBusPortBase; // Base Address for I2C 8584 IO port
	ULONG Dev1PCIBusNum; // The PCI Bus number on which PCI device resides
	ULONG Dev1PCISlotNum; // The PCI Slot number on which PCI device reside
	ULONG Dev2PCIBusNum; // The PCI Bus number on which PCI device resides
	ULONG Dev2PCISlotNum; // The PCI Slot number on which PCI device reside
	
	// INCA chip state and location variables
	ULONG INCAPortBase; // Base Address for INCA PCI IO port
	ULONG INCAPCIBusNum; // The PCI Bus number on which INCA resides
	ULONG INCAPCISlotNum; // The PCI Slot number on which INCA resides
	
	// TVM chip state and location variables
	ULONG TVMPortBase; // Base Address for TVM IO port
	
	// CMOS Dallas Part state and location variables
	ULONG CMOSPortBase; // Base Address for CMOS IO port
	
	// Keyboard controller reset state
	ULONG ResetPortBase; // Base Address for Reset IO port
	
	// ESM2 chip state variables
	ULONG ESM2PortBase; // Base Address for ESM2 IO port
	u8 ESM2IrqLevel; // IRQ to be used for ESM2 interrupts
	ULONG PMPortBase; // PIIX4 Power Mgt Port Base
	
	// SMB state variables
	u8 SMBOwnAddress; // Own address for SMB Master protocol
	SMBStateStruct SMBState; // SMB State
	IPMIStateStruct IPMIState; // IPMI State
	SMBIOSEPSTableInfo STI; // SMBIOS EPS table info
	MPSTableInfoStruct MPSTIS; // Multi Processor Specification table information
        s32 SMBusLockTimeOutSecondsCount;
	ULONG ioctl_flags;
	u8 wd_thread_sleeping;
	void *wd_thread_data;
	
} ESM_DEVICE_EXTENSION, *PESM_DEVICE_EXTENSION;


//--------------------------------------------------------------------
// Defines and strucutures
//--------------------------------------------------------------------

ESM_DEVICE_EXTENSION esm_card; 


#pragma pack()

#ifdef __cplusplus
}
#endif


#endif  // __ESMTYPES_H_INCLUDED__ 


