<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
	<xsl:output method="xml" omit-xml-declaration="yes"/>
	<xsl:strip-space elements="*"/>
	<xsl:template match="/OMA">
		<Summary>
			<xsl:apply-templates/>
		</Summary>
	</xsl:template>

	<xsl:template match="System">
		<Section name="System">
			<xsl:attribute name="display"><xsl:value-of select="$strSystem"/></xsl:attribute>
			<ListData name="system">
				<xsl:attribute name="display"><xsl:value-of select="$strSystem1"/></xsl:attribute>
				<Data name="HostName">
					<xsl:attribute name="display"><xsl:value-of select="$strHostName"/></xsl:attribute>
					<xsl:attribute name="value"><xsl:value-of select="HostName"/></xsl:attribute>
				</Data>
				<Data name="SystemLocation">
					<xsl:attribute name="display"><xsl:value-of select="$strSystemLocation"/></xsl:attribute>
					<xsl:attribute name="value"><xsl:value-of select="SystemInfo/SystemLocation"/></xsl:attribute>
				</Data>
			</ListData>
		</Section>
	</xsl:template>
	<xsl:template match="ChassisList">
			<xsl:apply-templates/>
	</xsl:template>

	<xsl:template match="Chassis">
		<Section>
			<xsl:attribute name="name">chassis_<xsl:value-of select="@index" /></xsl:attribute>
			<xsl:attribute name="display">
				<xsl:choose>
					<xsl:when test="@display = 'Main System Chassis'"><xsl:value-of select="$strMainSystemChassis"/></xsl:when>
					<xsl:otherwise><xsl:value-of select="@display" /></xsl:otherwise>
				</xsl:choose>
			</xsl:attribute>
			<xsl:apply-templates select="ChassisInfo" />
			<xsl:apply-templates select="Hardware" />
		</Section>
		<xsl:apply-templates select="Network" />
		<xsl:apply-templates select="Software" />
	</xsl:template>
	<xsl:template match="ChassisInfo">
			<ListData name="ChassisInformation">
				<xsl:attribute name="display"><xsl:value-of select="$strChassisInformation"/></xsl:attribute>
				<Data name="ChassModel">
					<xsl:attribute name="display"><xsl:value-of select="$strChassisModel"/></xsl:attribute>
					<xsl:attribute name="value"><xsl:value-of select="ChassisProps1/ChassModel"/></xsl:attribute>
				</Data>
				<Data name="ServiceTag">
					<xsl:attribute name="display"><xsl:value-of select="$strChassisServiceTag"/></xsl:attribute>
					<xsl:call-template name="DispChasSrvcTag"/>
				</Data>
				<Data name="ChassLock">
					<xsl:attribute name="display"><xsl:value-of select="$strChassisLock"/></xsl:attribute>
					<xsl:attribute name="value">
						<xsl:choose>
							<xsl:when test="ChassisProps1/ChassLockPresent = 'true'"><xsl:value-of select="$strPresent"/></xsl:when>
							<xsl:otherwise><xsl:value-of select="$strNoValue"/></xsl:otherwise>
						</xsl:choose>
					</xsl:attribute>
				</Data>

				<Data name="AssetTag">
					<xsl:attribute name="display">
					<xsl:choose>
						<xsl:when test="ChassisProps1/ChassType = '25' "><xsl:value-of select="$strServerModuleAsset"/></xsl:when>
						<xsl:otherwise>
						<xsl:value-of select="$strChassisAssetTag"/>
						</xsl:otherwise>
						</xsl:choose>
					 </xsl:attribute>
						<xsl:call-template name="DispChasAssetTag"/>
				</Data>
				<xsl:choose>
					<xsl:when test="ChassisProps1/ChassType = '25' ">
						<xsl:call-template name="YellowStone"/>
					</xsl:when>
					
				</xsl:choose>
				
				<xsl:if test="ChassisProps1/ChassType = '25' ">
					<xsl:apply-templates select="/OMA/BaseBoardList"/>
				</xsl:if>
				</ListData>
	</xsl:template>
	
	<xsl:template name="YellowStone">
		<xsl:for-each select="/OMA/BaseBoardList/BaseBoard">
			<xsl:choose>
			  <xsl:when test="BaseBoardType = '11'">
				<Data>
				<xsl:attribute name="display"><xsl:value-of select="$strPMMAssetTag"/></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="AssetTag"/></xsl:attribute>					
				</Data>
				
				<Data>
				<xsl:attribute name="display"><xsl:value-of select="$strPMMserviceTag"/></xsl:attribute>
  			        <xsl:attribute name="value"><xsl:value-of select="ServiceTag"/></xsl:attribute>					
				</Data>
				
				<Data>
				<xsl:attribute name="display"><xsl:value-of select="$strPMMLocation"/></xsl:attribute>
   			        <xsl:attribute name="value"><xsl:value-of select="BoardLocation"/></xsl:attribute>					
				</Data>		
			 </xsl:when>

			<xsl:when test="BaseBoardType = '12'">
				<Data>
				   <xsl:attribute name="display"><xsl:value-of select="$strIOMAssetTag"/></xsl:attribute>
				   <xsl:attribute name="value"><xsl:value-of select="AssetTag"/></xsl:attribute>	
				</Data>
			
				<Data>
				  <xsl:attribute name="display"><xsl:value-of select="$strIOMserviceTag"/></xsl:attribute>
				  <xsl:attribute name="value"><xsl:value-of select="ServiceTag"/></xsl:attribute>
				 </Data>
				<Data>
				 <xsl:attribute name="display"><xsl:value-of select="$strIOMLocation"/></xsl:attribute>
				 <xsl:attribute name="value"><xsl:value-of select="BoardLocation"/></xsl:attribute>
				</Data>
			</xsl:when>
               	</xsl:choose>
	</xsl:for-each>
	
	<xsl:for-each select="/OMA/BaseBoardList/BaseBoard[BaseBoardType='2']">
    	   <xsl:choose>
	     <xsl:when test="position() = 1">

		<Data>
			<xsl:attribute name="name">dsmassetag</xsl:attribute>
			<xsl:attribute name="display"><xsl:value-of select="$strDSM0AssetTag"/></xsl:attribute>
			<xsl:attribute name="value"><xsl:value-of select="AssetTag"/></xsl:attribute>
			
		</Data>

		<Data>
			<xsl:attribute name="display"><xsl:value-of select="$strDSM0serviceTag"/></xsl:attribute>
			<xsl:attribute name="value"><xsl:value-of select="ServiceTag"/></xsl:attribute>
		</Data>

		<Data>
			<xsl:attribute name="display"><xsl:value-of select="$strDSM0Location"/></xsl:attribute>
			<xsl:attribute name="value"><xsl:value-of select="BoardLocation"/></xsl:attribute>
		</Data>
	    </xsl:when>

	<xsl:when test="position() = 2">

		<Data>
			<xsl:attribute name="name">dsmassetag</xsl:attribute>
			<xsl:attribute name="display"><xsl:value-of select="$strDSM1AssetTag"/></xsl:attribute>
			<xsl:attribute name="value"><xsl:value-of select="AssetTag"/></xsl:attribute>
			
		</Data>

		<Data>
			<xsl:attribute name="display"><xsl:value-of select="$strDSM1serviceTag"/></xsl:attribute>
			<xsl:attribute name="value"><xsl:value-of select="ServiceTag"/></xsl:attribute>
		</Data>

		<Data>
			<xsl:attribute name="display"><xsl:value-of select="$strDSM1Location"/></xsl:attribute>
			<xsl:attribute name="value"><xsl:value-of select="BoardLocation"/></xsl:attribute>
		</Data>
	    </xsl:when>
		
	<xsl:when test="position() = 3">

		<Data>
			<xsl:attribute name="name">dsmassetag</xsl:attribute>
			<xsl:attribute name="display"><xsl:value-of select="$strDSM2AssetTag"/></xsl:attribute>
			<xsl:attribute name="value"><xsl:value-of select="AssetTag"/></xsl:attribute>
			
		</Data>

		<Data>
			<xsl:attribute name="display"><xsl:value-of select="$strDSM2serviceTag"/></xsl:attribute>
			<xsl:attribute name="value"><xsl:value-of select="ServiceTag"/></xsl:attribute>
		</Data>

		<Data>
			<xsl:attribute name="display"><xsl:value-of select="$strDSM2Location"/></xsl:attribute>
			<xsl:attribute name="value"><xsl:value-of select="BoardLocation"/></xsl:attribute>
		</Data>
	    </xsl:when>
	</xsl:choose>

	</xsl:for-each>


	</xsl:template>

	<xsl:template name="DispChasSrvcTag">
		<xsl:attribute name="value">
		<!--check for shredder-->
		<xsl:choose>
			<!--Shredder-->
			<xsl:when test="ChassisProps1/ChassType = '25' ">
				<xsl:if test="/OMA/BaseBoardList/@count > 0">
					<xsl:for-each select="/OMA/BaseBoardList/BaseBoard">
						<xsl:if test="BaseBoardType = '13'">
							<xsl:value-of select="ServiceTag"/>
						</xsl:if>
					</xsl:for-each>
				</xsl:if>
			</xsl:when>
			<xsl:otherwise>
				<!--not shredder -->
				<xsl:value-of select="ChassisProps2/ServiceTag"/>
			</xsl:otherwise>
		</xsl:choose>
		</xsl:attribute>
	</xsl:template>

	<xsl:template name="DispChasAssetTag">
		<xsl:attribute name="value"><xsl:value-of select="ChassisProps2/AssetTag"/></xsl:attribute>
	</xsl:template>

	<xsl:template match="/OMA/BaseBoardList">
		<xsl:for-each select="BaseBoard">
			<xsl:if test="(BaseBoardType!='11') and (BaseBoardType!='2') and (BaseBoardType!='12')and (BaseBoardType!='13')">
				<Data name="BladeServiceTag" type="ustring">
					<xsl:attribute name="display"><xsl:value-of select="$strServerModuleService"/></xsl:attribute>
					<xsl:attribute name="value"><xsl:value-of select="ServiceTag"/></xsl:attribute>
				</Data>

			</xsl:if>
			<xsl:if test="(BaseBoardType!='3') and (BaseBoardType!='11') and (BaseBoardType!='2') and (BaseBoardType!='12')">
				<Data name="BladeLocation" type="ustring">
					<xsl:attribute name="display"><xsl:value-of select="$strServerModuleLocation"/></xsl:attribute>
					<xsl:attribute name="value"><xsl:value-of select="BoardLocation"/></xsl:attribute>
				</Data>
			</xsl:if>
		</xsl:for-each>
	</xsl:template>

	<xsl:template match="Hardware">
		<xsl:apply-templates/>
		<xsl:apply-templates select="parent::node()/FirmwareList" />
	</xsl:template>
	<xsl:template match="ProcessorList">
		<xsl:apply-templates/>
	</xsl:template>
	<xsl:template match="DevProcessor">
		<ListData name="processor">
			<xsl:attribute name="display"><xsl:value-of select="ExtName"/></xsl:attribute>
			<xsl:attribute name="display"><xsl:value-of select="$strProcessor"/> <xsl:value-of select="@index + 1"/></xsl:attribute>
			<Data name="ProcessorManufacturer">
				<xsl:attribute name="display"><xsl:value-of select="$strProcessorManufacturer"/></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="Manufacturer"/></xsl:attribute>
			</Data>
			<Data name="ProcessorFamily">
				<xsl:attribute name="display"><xsl:value-of select="$strProcessorFamily"/></xsl:attribute>
				<xsl:attribute name="value">
					<xsl:choose>
						<xsl:when test="Family='1'"><xsl:value-of select="$strOther"/></xsl:when>
						<xsl:when test="Family='3'"><xsl:value-of select="$str8086"/></xsl:when>
						<xsl:when test="Family='4'"><xsl:value-of select="$str286"/></xsl:when>
						<xsl:when test="Family='5'"><xsl:value-of select="$str386"/></xsl:when>
						<xsl:when test="Family='6'"><xsl:value-of select="$str486"/></xsl:when>
						<xsl:when test="Family='7'"><xsl:value-of select="$str8087"/></xsl:when>
						<xsl:when test="Family='8'"><xsl:value-of select="$str287"/></xsl:when>
						<xsl:when test="Family='9'"><xsl:value-of select="$str387"/></xsl:when>
						<xsl:when test="Family='10'"><xsl:value-of select="$str487"/></xsl:when>
						<xsl:when test="Family='11'"><xsl:value-of select="$strPentium"/></xsl:when>
						<xsl:when test="Family='12'"><xsl:value-of select="$strPentiumPro"/></xsl:when>
						<xsl:when test="Family='13'"><xsl:value-of select="$strPentiumII"/></xsl:when>
						<xsl:when test="Family='14'"><xsl:value-of select="$strPentiumWithMMX"/></xsl:when>
						<xsl:when test="Family='15'"><xsl:value-of select="$strCeleron"/></xsl:when>
						<xsl:when test="Family='16'"><xsl:value-of select="$strPentiumIIXeon"/></xsl:when>
						<xsl:when test="Family='17'"><xsl:value-of select="$strPentiumIII"/></xsl:when>
						<xsl:when test="Family='130'"><xsl:value-of select="$strItanium"/></xsl:when>
						<xsl:when test="Family='176'"><xsl:value-of select="$strPentiumIIIXeon"/></xsl:when>
						<xsl:when test="Family='177'"><xsl:value-of select="$strPentiumIIIWith"/></xsl:when>
						<xsl:when test="Family='178'"><xsl:value-of select="$strPentiumIV"/></xsl:when>
						<xsl:when test="Family='179'"><xsl:value-of select="$strXeon"/></xsl:when>
						<xsl:when test="Family='181'"><xsl:value-of select="$strXeonMP"/></xsl:when>
						<xsl:otherwise><xsl:value-of select="$strNoValue1"/></xsl:otherwise>
					</xsl:choose>
				</xsl:attribute>
			</Data>
			<Data name="ProcessorVersion">
				<xsl:attribute name="display"><xsl:value-of select="$strProcessorVersion"/></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="Version"/></xsl:attribute>
			</Data>
			<Data name="CurrentSpeed">
				<xsl:attribute name="display"><xsl:value-of select="$strCurrentSpeed"/></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="CurSpeed"/><xsl:text> </xsl:text>
					<xsl:call-template name="displayunits"><xsl:with-param name="unit"><xsl:value-of select="CurSpeed/@unit"/></xsl:with-param></xsl:call-template>
				</xsl:attribute>
			</Data>
			<Data name="MaximumSpeed">
				<xsl:attribute name="display"><xsl:value-of select="$strMaximumSpeed"/></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="MaxSpeed"/><xsl:text> </xsl:text>
					<xsl:call-template name="displayunits"><xsl:with-param name="unit"><xsl:value-of select="MaxSpeed/@unit"/></xsl:with-param></xsl:call-template>
				</xsl:attribute>
			</Data>
			<Data name="ExtClockSpeed">
				<xsl:attribute name="display"><xsl:value-of select="$strExternalClockSpeed"/></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="ExtClockSpeed"/><xsl:text> </xsl:text>
					<xsl:call-template name="displayunits"><xsl:with-param name="unit"><xsl:value-of select="ExtClockSpeed/@unit"/></xsl:with-param></xsl:call-template>
				</xsl:attribute>
			</Data>
			<Data name="Voltage">
				<xsl:attribute name="display"><xsl:value-of select="$strVoltage"/></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="Voltage"/><xsl:text> </xsl:text>
					<xsl:call-template name="displayunits"><xsl:with-param name="unit"><xsl:value-of select="Voltage/@unit"/></xsl:with-param></xsl:call-template>
				</xsl:attribute>
			</Data>
		</ListData>
	</xsl:template>
	<xsl:template match="MemoryArrayList">
		<ListData name="Memory">
			<xsl:attribute name="display"><xsl:value-of select="$strMemory"/></xsl:attribute>
			<Data name="InstalledSize">
				<xsl:attribute name="display"><xsl:value-of select="$strTotalInstalledCapacity"/></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="../MaxInstalledSizeMBCumulative"/><xsl:text> </xsl:text>
					<xsl:call-template name="displayunits"><xsl:with-param name="unit"><xsl:value-of select="../MaxInstalledSizeMBCumulative/@unit"/></xsl:with-param></xsl:call-template>
				</xsl:attribute>
			</Data>
			<Data name="OSInstalledSize">
				<xsl:attribute name="display"><xsl:value-of select="$strMemoryAvailableTo"/></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="../MemoryInfo/TotalPhysMemorySizeMB"/><xsl:text> </xsl:text>
					<xsl:call-template name="displayunits"><xsl:with-param name="unit"><xsl:value-of select="../MemoryInfo/TotalPhysMemorySizeMB/@unit"/></xsl:with-param></xsl:call-template>
				</xsl:attribute>
			</Data>
			<Data name="TotalSize">
				<xsl:attribute name="display"><xsl:value-of select="$strTotalMaximumCapacity"/></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="../MaxSizeMBCumulative"/><xsl:text> </xsl:text>
					<xsl:call-template name="displayunits"><xsl:with-param name="unit"><xsl:value-of select="../MaxSizeMBCumulative/@unit"/></xsl:with-param></xsl:call-template>
				</xsl:attribute>
			</Data>
			<Data name="MemoryArrays">
				<xsl:attribute name="display"><xsl:value-of select="$strMemoryArrayCount"/></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="@count"/></xsl:attribute>
			</Data>
		</ListData>
		<xsl:apply-templates/>
	</xsl:template>
	<xsl:template match="MemoryArray">
		<ListData name="MemoryArray">
			<xsl:attribute name="display"><xsl:value-of select="$strMemoryArray"/> <xsl:value-of select="@index + 1"/></xsl:attribute>
			<Data name="Location">
				<xsl:attribute name="display"><xsl:value-of select="$strLocation"/></xsl:attribute>
				<xsl:attribute name="value">
					<xsl:choose>
						<xsl:when test="Location='1'"><xsl:value-of select="$strOther1"/></xsl:when>
						<xsl:when test="Location='3'"><xsl:value-of select="$strSystemBoardOr"/></xsl:when>
						<xsl:when test="Location='4'"><xsl:value-of select="$strISAAddonCard"/></xsl:when>
						<xsl:when test="Location='5'"><xsl:value-of select="$strEISAAddonCard"/></xsl:when>
						<xsl:when test="Location='6'"><xsl:value-of select="$strPCIAddonCard"/></xsl:when>
						<xsl:when test="Location='7'"><xsl:value-of select="$strMCAAddonCard"/></xsl:when>
						<xsl:when test="Location='8'"><xsl:value-of select="$strPCMCIAAddonCard"/></xsl:when>
						<xsl:when test="Location='9'"><xsl:value-of select="$strProprietaryAddonCard"/></xsl:when>
						<xsl:when test="Location='16'"><xsl:value-of select="$strNuBus"/></xsl:when>
						<xsl:when test="Location='160'"><xsl:value-of select="$strPC98C20AddonCard"/></xsl:when>
						<xsl:when test="Location='161'"><xsl:value-of select="$strPC98C24AddonCard"/></xsl:when>
						<xsl:when test="Location='162'"><xsl:value-of select="$strPC98EAddonCard"/></xsl:when>
						<xsl:when test="Location='163'"><xsl:value-of select="$strPC98LocalBusAddon"/></xsl:when>
						<xsl:when test="Location='164'"><xsl:value-of select="$strPC98CardSlotAddon"/></xsl:when>
						<xsl:otherwise><xsl:value-of select="$strNoValue2"/></xsl:otherwise>
					</xsl:choose>
				</xsl:attribute>
			</Data>
			<Data name="Use">
				<xsl:attribute name="display"><xsl:value-of select="$strUse"/></xsl:attribute>
				<xsl:attribute name="value">
					<xsl:choose>
						<xsl:when test="Location='1'"><xsl:value-of select="$strOther2"/></xsl:when>
						<xsl:when test="Location='3'"><xsl:value-of select="$strSystemMemory"/></xsl:when>
						<xsl:when test="Location='4'"><xsl:value-of select="$strVideoMemory"/></xsl:when>
						<xsl:when test="Location='5'"><xsl:value-of select="$strFlashMemory"/></xsl:when>
						<xsl:when test="Location='6'"><xsl:value-of select="$strNonVolatileRAM"/></xsl:when>
						<xsl:when test="Location='7'"><xsl:value-of select="$strCacheMemory"/></xsl:when>
						<xsl:otherwise><xsl:value-of select="$strNoValue3"/></xsl:otherwise>
					</xsl:choose>
				</xsl:attribute>
			</Data>
			<Data name="InstalledSize">
				<xsl:attribute name="display"><xsl:value-of select="$strInstalledCapacity"/></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="InstalledSizeMBCumulative"/><xsl:text> </xsl:text>
					<xsl:call-template name="displayunits"><xsl:with-param name="unit"><xsl:value-of select="InstalledSizeMBCumulative/@unit"/></xsl:with-param></xsl:call-template>
				</xsl:attribute>
			</Data>
			<Data name="MaximumCapacity">
				<xsl:attribute name="display"><xsl:value-of select="$strMaximumCapacity"/></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="MaxSizeMB"/><xsl:text> </xsl:text>
					<xsl:call-template name="displayunits"><xsl:with-param name="unit"><xsl:value-of select="MaxSizeMB/@unit"/></xsl:with-param></xsl:call-template>
				</xsl:attribute>
			</Data>
			<Data name="NumSocketsTotal">
				<xsl:attribute name="display"><xsl:value-of select="$strSlotsAvailable"/></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="NumSocketsTotal"/></xsl:attribute>
			</Data>
			<Data name="NumSocketsInUse">
				<xsl:attribute name="display"><xsl:value-of select="$strSlotsUsed"/></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="NumSocketsInUse"/></xsl:attribute>
			</Data>
			<Data name="ErrCorrType">
				<xsl:attribute name="display"><xsl:value-of select="$strECCType"/></xsl:attribute>
				<xsl:attribute name="value">
					<xsl:choose>
						<xsl:when test="ErrCorrType='1'"><xsl:value-of select="$strOther3"/></xsl:when>
						<xsl:when test="ErrCorrType='3'"><xsl:value-of select="$strNone"/></xsl:when>
						<xsl:when test="ErrCorrType='4'"><xsl:value-of select="$strParity"/></xsl:when>
						<xsl:when test="ErrCorrType='5'"><xsl:value-of select="$strSingleBitECC"/></xsl:when>
						<xsl:when test="ErrCorrType='6'"><xsl:value-of select="$strMultibitECC"/></xsl:when>
						<xsl:when test="ErrCorrType='7'"><xsl:value-of select="$strCRC"/></xsl:when>
						<xsl:otherwise><xsl:value-of select="$strNoValue4"/></xsl:otherwise>
					</xsl:choose>
				</xsl:attribute>
			</Data>
		</ListData>
	</xsl:template>
	<xsl:template match="SlotsList">
		<xsl:apply-templates/>
	</xsl:template>
	<xsl:template match="Slot">
		<xsl:if test="ExtName != 'Embedded'">
			<ListData>
				<xsl:attribute name="name">slot<xsl:value-of select="@index"/></xsl:attribute>
				<xsl:attribute name="display"><xsl:value-of select="$strSlot"/> <xsl:value-of select="ExtName"/></xsl:attribute>
				<Data name="adapter">
					<xsl:attribute name="display"><xsl:value-of select="$strAdapter"/></xsl:attribute>
					<xsl:attribute name="value">
						<xsl:choose>
							<xsl:when test="SlotDevice"><xsl:value-of select="SlotDevice/DeviceDesc" /></xsl:when>
							<xsl:otherwise><xsl:value-of select="$strNotOccupied"/></xsl:otherwise>
						</xsl:choose>
					</xsl:attribute>
				</Data>
				<Data name="Type"  editable="false" type="ustring">
					<xsl:attribute name="display"><xsl:value-of select="$strType"/></xsl:attribute>
					<xsl:attribute name="value">
						<xsl:choose>
							<xsl:when test="Type='1'"><xsl:value-of select="$strOther4"/></xsl:when>
							<xsl:when test="Type='3'"><xsl:value-of select="$strISA"/></xsl:when>
							<xsl:when test="Type='4'"><xsl:value-of select="$strMCA"/></xsl:when>
							<xsl:when test="Type='5'"><xsl:value-of select="$strEISA"/></xsl:when>
							<xsl:when test="Type='6'"><xsl:value-of select="$strPCI"/></xsl:when>
							<xsl:when test="Type='7'"><xsl:value-of select="$strPCMCIA"/></xsl:when>
							<xsl:when test="Type='8'"><xsl:value-of select="$strVLVESA"/></xsl:when>
							<xsl:when test="Type='9'"><xsl:value-of select="$strProprietary"/></xsl:when>
							<xsl:when test="Type='10'"><xsl:value-of select="$strProcessorCard"/></xsl:when>
							<xsl:when test="Type='11'"><xsl:value-of select="$strProprietaryMemoryCard"/></xsl:when>
							<xsl:when test="Type='12'"><xsl:value-of select="$strIORiserCard"/></xsl:when>
							<xsl:when test="Type='13'"><xsl:value-of select="$strNuBus1"/></xsl:when>
							<xsl:when test="Type='14'"><xsl:value-of select="$strPCI66MHz"/></xsl:when>
							<xsl:when test="Type='15'"><xsl:value-of select="$strAGP"/></xsl:when>
							<xsl:when test="Type='16'"><xsl:value-of select="$strAGP2X"/></xsl:when>
							<xsl:when test="Type='17'"><xsl:value-of select="$strAGP4X"/></xsl:when>
							<xsl:when test="Type='18'"><xsl:value-of select="$strPCIX"/></xsl:when>
							<xsl:when test="Type='160'"><xsl:value-of select="$strPC98C20"/></xsl:when>
							<xsl:when test="Type='161'"><xsl:value-of select="$strPC98C24"/></xsl:when>
							<xsl:when test="Type='162'"><xsl:value-of select="$strPC98E"/></xsl:when>
							<xsl:when test="Type='163'"><xsl:value-of select="$strPC98LocalBus"/></xsl:when>
							<xsl:when test="Type='164'"><xsl:value-of select="$strPC98Card"/></xsl:when>
							<xsl:otherwise><xsl:value-of select="$strNoValue5"/></xsl:otherwise>
						</xsl:choose>
					</xsl:attribute>
				</Data>
				<Data name="DataBusWidth">
					<xsl:attribute name="display"><xsl:value-of select="$strDataBusWidth"/></xsl:attribute>
					<xsl:attribute name="value">
						<xsl:choose>
							<xsl:when test="HotPlugSystemSlot/DataBusWidth='1'"><xsl:value-of select="$strOther5"/></xsl:when>
							<xsl:when test="HotPlugSystemSlot/DataBusWidth='3'"><xsl:value-of select="$str8Bits"/></xsl:when>
							<xsl:when test="HotPlugSystemSlot/DataBusWidth='4'"><xsl:value-of select="$str16Bits"/></xsl:when>
							<xsl:when test="HotPlugSystemSlot/DataBusWidth='5'"><xsl:value-of select="$str32Bits"/></xsl:when>
							<xsl:when test="HotPlugSystemSlot/DataBusWidth='6'"><xsl:value-of select="$str64Bits"/></xsl:when>
							<xsl:when test="HotPlugSystemSlot/DataBusWidth='7'"><xsl:value-of select="$str128Bits"/></xsl:when>
							<xsl:otherwise><xsl:value-of select="$strNoValue6"/></xsl:otherwise>
						</xsl:choose>
					</xsl:attribute>
				</Data>
				<Data name="Speed"  editable="false" type="ustring">
					<xsl:attribute name="display"><xsl:value-of select="$strSpeed"/></xsl:attribute>
					<xsl:attribute name="value">
						<xsl:choose>
							<xsl:when test="HotPlugSystemSlot/SlotSpeed='0'"><xsl:value-of select="$strNoValue7"/></xsl:when>
							<xsl:otherwise><xsl:value-of select="HotPlugSystemSlot/SlotSpeed"/><xsl:text> </xsl:text>
								<xsl:call-template name="displayunits"><xsl:with-param name="unit"><xsl:value-of select="HotPlugSystemSlot/SlotSpeed/@unit"/></xsl:with-param></xsl:call-template>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:attribute>
				</Data>
				<Data name="SlotLength">
					<xsl:attribute name="display"><xsl:value-of select="$strSlotLength"/></xsl:attribute>
					<xsl:attribute name="value">
						<xsl:choose>
							<xsl:when test="Length='1'"><xsl:value-of select="$strOther6"/></xsl:when>
							<xsl:when test="Length='3'"><xsl:value-of select="$strShort"/></xsl:when>
							<xsl:when test="Length='4'"><xsl:value-of select="$strLong"/></xsl:when>
							<xsl:otherwise><xsl:value-of select="$strNoValue8"/></xsl:otherwise>
						</xsl:choose>
					</xsl:attribute>
				</Data>
				<Data name="VoltSupply"  editable="false" type="ustring">
					<xsl:attribute name="display"><xsl:value-of select="$strVoltageSupply"/></xsl:attribute>
					<xsl:attribute name="value">
						<xsl:if test="IsVolt33='true'"><xsl:value-of select="$str33Volts"/><xsl:if test="IsVolt5='true'">, </xsl:if></xsl:if>
						<xsl:if test="IsVolt5='true'"><xsl:value-of select="$str5Volts"/></xsl:if>
					</xsl:attribute>
				</Data>
			</ListData>
		</xsl:if>
	</xsl:template>
	<xsl:template match="SystemBIOS">
		<ListData name="SystemBIOS">
			<xsl:attribute name="display"><xsl:value-of select="$strBIOSInformation"/></xsl:attribute>
			<Data name="Manufacturer">
				<xsl:attribute name="display"><xsl:value-of select="$strManufacturer"/></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="Manufacturer"/></xsl:attribute>
			</Data>
			<Data name="Version">
				<xsl:attribute name="display"><xsl:value-of select="$strVersion"/></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="Version"/></xsl:attribute>
			</Data>
			<Data name="ReleaseDate">
				<xsl:attribute name="display"><xsl:value-of select="$strReleaseDate"/></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="ReleaseDate"/></xsl:attribute>
			</Data>
		</ListData>
	</xsl:template>
	<xsl:template match="Network">
		<Section name="Network">
			<xsl:attribute name="display"><xsl:value-of select="$strNetworkData"/></xsl:attribute>
			<xsl:choose>
				<xsl:when test="NICList">
					<xsl:apply-templates select="NICList" />
				</xsl:when>
				<xsl:otherwise>
					<xsl:apply-templates/>
				</xsl:otherwise>
			</xsl:choose>
		</Section>
	</xsl:template>
	<xsl:template match="NICList">
			<xsl:apply-templates/>
	</xsl:template>
	<xsl:template match="NICCard">
		<ListData>
			<xsl:attribute name="name">NICList<xsl:value-of select="@index"/></xsl:attribute>
			<xsl:attribute name="display"><xsl:value-of select="$strNetworkInterfaceCard"/><xsl:value-of select="@index"/></xsl:attribute>
			<Data>
				<xsl:attribute name="name">IPAddr<xsl:value-of select="@index"/></xsl:attribute>
				<xsl:attribute name="display"><xsl:value-of select="$strIPAddress"/></xsl:attribute>
				<xsl:attribute name="value">
					<xsl:choose>
						<xsl:when test="IPAddress = ''"><xsl:value-of select="$strNoValue9"/></xsl:when>
						<xsl:otherwise><xsl:value-of select="IPAddress"/></xsl:otherwise>
					</xsl:choose>
				</xsl:attribute>
			</Data>
			<Data>
				<xsl:attribute name="name">SubnetMask<xsl:value-of select="@index"/></xsl:attribute>
				<xsl:attribute name="display"><xsl:value-of select="$strSubnetMask"/></xsl:attribute>
				<xsl:attribute name="value">
					<xsl:choose>
						<xsl:when test="SubnetMask = ''"><xsl:value-of select="$strNoValue10"/></xsl:when>
						<xsl:otherwise><xsl:value-of select="SubnetMask"/></xsl:otherwise>
					</xsl:choose>
				</xsl:attribute>
			</Data>
			<Data>
				<xsl:attribute name="name">DefaultGateway<xsl:value-of select="@index"/></xsl:attribute>
				<xsl:attribute name="display"><xsl:value-of select="$strDefaultGateway"/></xsl:attribute>
				<xsl:attribute name="value">
					<xsl:choose>
						<xsl:when test="DefaultGateway = ''"><xsl:value-of select="$strNoValue11"/></xsl:when>
						<xsl:otherwise><xsl:value-of select="DefaultGateway"/></xsl:otherwise>
					</xsl:choose>
				</xsl:attribute>
			</Data>
			<Data>
				<xsl:attribute name="name">MacAddr<xsl:value-of select="@index"/></xsl:attribute>
				<xsl:attribute name="display"><xsl:value-of select="$strMACAddress"/></xsl:attribute>
				<xsl:attribute name="value">
					<xsl:choose>
						<xsl:when test="CurrentMACAddr = ''"><xsl:value-of select="$strNoValue12"/></xsl:when>
						<xsl:otherwise><xsl:value-of select="CurrentMACAddr"/></xsl:otherwise>
					</xsl:choose>
				</xsl:attribute>
			</Data>
		</ListData>
	</xsl:template>
	<xsl:template match="IPAddrList">
		<ListData name="IPAddrList">
			<xsl:attribute name="display"><xsl:value-of select="$strIPAddressData"/></xsl:attribute>
			<xsl:apply-templates/>
		</ListData>
	</xsl:template>
	<xsl:template match="IPAddr">
		<Data name="IPAddr">
			<xsl:attribute name="name">IPAddr<xsl:value-of select="@index"/></xsl:attribute>
			<xsl:attribute name="display"><xsl:value-of select="$strIPAddress1"/><xsl:value-of select="@index"/></xsl:attribute>
			<xsl:attribute name="value"><xsl:value-of select="."/></xsl:attribute>
		</Data>
	</xsl:template>
	<xsl:template match="Software">
		<Section name="Software">
			<xsl:attribute name="display"><xsl:value-of select="$strSoftwareProfile"/></xsl:attribute>
			<xsl:apply-templates/>
		</Section>
	</xsl:template>
	<xsl:template match="OSInfo">
		<ListData name="OSInfo">
			<xsl:attribute name="display"><xsl:value-of select="$strOperatingSystem"/></xsl:attribute>
			<Data name="OSName">
				<xsl:attribute name="display"><xsl:value-of select="$strName"/></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="OSName"/></xsl:attribute>
			</Data>
			<Data name="OSVersion">
				<xsl:attribute name="display"><xsl:value-of select="$strVersion1"/></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="OSVersion"/></xsl:attribute>
			</Data>
			<Data name="SystemTime">
				<xsl:attribute name="display"><xsl:value-of select="$strSystemTime"/></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="//System/SystemInfo/SystemTime"/></xsl:attribute>
			</Data>
			<Data name="SystemBootupTime">
				<xsl:attribute name="display"><xsl:value-of select="$strSystemBootupTime"/></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="//System/SystemInfo/SystemBootupTime"/></xsl:attribute>
			</Data>
		</ListData>
	</xsl:template>
	<xsl:template match="FirmwareList">
		<xsl:apply-templates />
	</xsl:template>
	<xsl:template match="Firmware">
		<ListData>
			<xsl:attribute name="name">Firmware_<xsl:value-of select="@index"/></xsl:attribute>
			<xsl:attribute name="display"><xsl:value-of select="$strFirmwareInformation"/></xsl:attribute>
			<Data name="Name">
				<xsl:attribute name="display"><xsl:value-of select="$strName1"/></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="FWText"/></xsl:attribute>
			</Data>
			<Data name="Version">
				<xsl:attribute name="display"><xsl:value-of select="$strVersion2"/></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="FWVersion"/></xsl:attribute>
			</Data>
		</ListData>
	</xsl:template>

	<xsl:template match="ClusterInfo">
		<Section name="ClusterInfo">
			<xsl:attribute name="display"><xsl:value-of select="$strClusterInformation"/></xsl:attribute>
			<ListData name="Information">
				<xsl:attribute name="display"><xsl:value-of select="$strClusterInformation1"/></xsl:attribute>
				<Data name="ClusterName">
					<xsl:attribute name="display"><xsl:value-of select="$strClusterName"/></xsl:attribute>
					<xsl:attribute name="value"><xsl:value-of select="ClusterName"/></xsl:attribute>
				</Data>
				<Data name="TypeDescription">
					<xsl:attribute name="display"><xsl:value-of select="$strClusterDescription"/></xsl:attribute>
					<xsl:attribute name="value"><xsl:value-of select="TypeDescription"/></xsl:attribute>
				</Data>
				<Data name="ClusterType">
					<xsl:attribute name="display"><xsl:value-of select="$strClusterType"/></xsl:attribute>
					<xsl:attribute name="value">
						<xsl:choose>
							<xsl:when test="ClusterType='2'"><xsl:value-of select="$strMicrosoftClusterServer"/></xsl:when>
							<xsl:otherwise><xsl:value-of select="$strNoValue13"/></xsl:otherwise>
						</xsl:choose>
					</xsl:attribute>
				</Data>
			</ListData>
		</Section>
	</xsl:template>
	
	<xsl:template name="displayunits">
	<xsl:param name="unit"/>
	<xsl:choose>
		<xsl:when test="$unit='MB'"><xsl:value-of select="$strMB"/></xsl:when>
		<xsl:when test="$unit='KB'"><xsl:value-of select="$strKB"/></xsl:when>
		<xsl:otherwise><xsl:value-of select="$unit"/></xsl:otherwise>
	</xsl:choose>
</xsl:template>

	<xsl:template match="*"/>

</xsl:stylesheet>
