<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<xsl:output method="text" indent="no"/>
	<xsl:strip-space elements="*"/>
	<xsl:template match="/OMA">
		<xsl:call-template name="CLISubCommand">
			<xsl:with-param name="command"><xsl:value-of select="CLISubCommand"/></xsl:with-param>
		</xsl:call-template>
		<xsl:call-template name="CLIMsgID">
			<xsl:with-param name="id"><xsl:value-of select="CLIMsgID"/></xsl:with-param>
			<xsl:with-param name="shownvpairs"><xsl:value-of select="CLIShowNVPairs"/></xsl:with-param>
			<xsl:with-param name="nametxt">
				<xsl:value-of select="CLIParseName"/>
			</xsl:with-param>
			<xsl:with-param name="paramtxt">
				<xsl:value-of select="CLIParamName"/>
			</xsl:with-param>
			<xsl:with-param name="parsetxt">
				<xsl:value-of select="CLIParseTxt"/>
			</xsl:with-param>
			<xsl:with-param name="parsetxt2">
				<xsl:value-of select="CLIParseTxt2"/>
			</xsl:with-param>
			<xsl:with-param name="hipstat">
				<xsl:value-of select="CustomStat"/>
			</xsl:with-param>
		</xsl:call-template>
	</xsl:template>

	<xsl:template match="/leds">
		<xsl:call-template name="CLISubCommand">
			<xsl:with-param name="command">leds</xsl:with-param>
		</xsl:call-template>
		<!--XLATESTART-->LED configuration.<!--XLATESTOP-->
		<xsl:call-template name="NewLine"/>	
		<xsl:apply-templates select="ChassisInfo">
		</xsl:apply-templates>
	</xsl:template>
	<xsl:template match="ChassisInfo">	
		<!--XLATESTART-->Valid parameters are:<!--XLATESTOP-->
		<xsl:call-template name="NewLine"/>
		<xsl:text>index=&lt;number&gt;   </xsl:text><!--XLATESTART-->Chassis index (defaults to 0, main system chassis).<!--XLATESTOP-->
		<xsl:call-template name="NewLine"/>
  		    <xsl:text>led=fault        severity=&lt;warning|critical&gt; Flash on failure level.</xsl:text>
		    <xsl:call-template name="NewLine"/>
			<xsl:text>led=hdfault      action=clear                Clear hard disk fault LED.</xsl:text>
		     <xsl:call-template name="NewLine"/>
		    <xsl:text>led=identify     flash=&lt;off|on&gt;              Flash chassis identify LED.</xsl:text>
		    <xsl:call-template name="NewLine"/>
    		    <xsl:text>                 timeout=&lt;number&gt;            Flash timeout value ( &gt;0 seconds).</xsl:text>
     		<xsl:call-template name="NewLine"/>
	</xsl:template>

	<xsl:template match="/ChassisData">	
			<xsl:call-template name="CLISubCommand">
				<xsl:with-param name="command">info</xsl:with-param>
			</xsl:call-template>
			<!--XLATESTART-->Set chassis information.<!--XLATESTOP-->
			<xsl:call-template name="NewLine"/>	
			<!--XLATESTART-->Valid parameters are:<!--XLATESTOP-->
			<xsl:call-template name="NewLine"/>
			<xsl:text>index=&lt;number&gt;   </xsl:text><!--XLATESTART-->Chassis index (defaults to 0, main system chassis).<!--XLATESTOP-->
			<xsl:call-template name="NewLine"/>
               <xsl:text>tag=&lt;text&gt;       </xsl:text><!--XLATESTART-->Asset tag value (up to 10 chars, alphanumeric text only). <!--XLATESTOP-->
               <xsl:call-template name="NewLine"/>
			<xsl:for-each select="ChassisList/Chassis/ChassisInfo/BaseBoardList/BaseBoard">
			    <xsl:choose>
		            	<xsl:when test="BaseBoardType='11'">
		                	<xsl:text>pmmtag=&lt;text&gt;    </xsl:text><!--XLATESTART-->Processor Memory Module tag value.<!--XLATESTOP-->
		                	<xsl:call-template name="NewLine"/>		
				   	</xsl:when>
		            	<xsl:when test="BaseBoardType='12'">
		               	<xsl:text>iomtag=&lt;text&gt;    </xsl:text><!--XLATESTART-->Processor I/O Module tag value.<!--XLATESTOP-->
		               	<xsl:call-template name="NewLine"/>
				   	</xsl:when>
		         </xsl:choose>	
			</xsl:for-each>
			<xsl:for-each select="ChassisList/Chassis/ChassisInfo/BaseBoardList/BaseBoard[BaseBoardType='2'] ">
		     	<xsl:choose>
	            		<xsl:when test="position() = 1">
	               		<xsl:text>dsm0tag=&lt;text&gt;   </xsl:text><!--XLATESTART-->Data Storage Module 0 tag value.<!--XLATESTOP-->
	               		<xsl:call-template name="NewLine"/>
			   		</xsl:when>
	            		<xsl:when test="position() = 2">
	               		<xsl:text>dsm1tag=&lt;text&gt;   </xsl:text><!--XLATESTART-->Data Storage Module 1 tag value.<!--XLATESTOP-->
	               		<xsl:call-template name="NewLine"/>
			   		</xsl:when>	
	            		<xsl:when test="position() = 3">
		               	<xsl:text>dsm2tag=&lt;text&gt;   </xsl:text><!--XLATESTART-->Data Storage Module 2 tag value.<!--XLATESTOP-->
		               	<xsl:call-template name="NewLine"/>
			   		</xsl:when>
	         		</xsl:choose>
			</xsl:for-each>
			<xsl:text>name=&lt;text&gt;      </xsl:text><!--XLATESTART-->Set chassis name.<!--XLATESTOP-->
		     <xsl:call-template name="NewLine"/>	
	</xsl:template>

	<xsl:template match="/biossetup">
	     <xsl:if test="BIOSSetupListCount != '0'">
			<xsl:call-template name="CLISubCommand">
				<xsl:with-param name="command">biossetup</xsl:with-param>
			</xsl:call-template>
			<!--XLATESTART-->Configure BIOS setup.<!--XLATESTOP-->
			<xsl:call-template name="NewLine"/>	
			<!--XLATESTART-->NOTE: Changing onboardraid or primaryscsi or ide attributes can make your<!--XLATESTOP--><xsl:call-template name="NewLine"/>
<!--XLATESTART-->      system inoperable or require an operating system reinstall<!--XLATESTOP-->
			<xsl:call-template name="NewLine"/>
			<!--XLATESTART-->Valid parameters are:<!--XLATESTOP-->
			<xsl:call-template name="NewLine"/>
			<xsl:for-each select="BIOSSetupList/BIOSSetup">
				<xsl:choose>
					<xsl:when test="@objtype = '240'">
						<xsl:text>attribute=numlock        setting=&lt;on|off&gt;</xsl:text>
						<xsl:call-template name="NewLine"/>
					</xsl:when>
			           	<xsl:when test="@objtype = '241'">
			        		<xsl:text>attribute=diskette       setting=&lt;off|auto|writeprotect&gt;</xsl:text>
				 		<xsl:call-template name="NewLine"/>
				     </xsl:when>
			          <xsl:when test="@objtype = '242'">
						<xsl:text>attribute=</xsl:text>
						<xsl:choose>
                     			<xsl:when test="ObjName = 'NIC'">
								<xsl:text>nic </xsl:text>
							</xsl:when>
							<xsl:otherwise>
								<xsl:text>nic2</xsl:text>
							</xsl:otherwise>
                  			</xsl:choose>
						<xsl:text>           setting=&lt;enabled|disabled|enablednonepxe&gt;</xsl:text>
				 		<xsl:call-template name="NewLine"/>
					</xsl:when>
			           <xsl:when test="@objtype = '243'">
						<xsl:text>attribute=mouse          setting=&lt;on|off&gt;</xsl:text>
						<xsl:call-template name="NewLine"/>	
					</xsl:when>
		        	   	<xsl:when test="@objtype = '244'">
						<xsl:text>attribute=usb            setting=&lt;enabled|disabled&gt;</xsl:text>
						<xsl:call-template name="NewLine"/>
					</xsl:when>
			           <xsl:when test="@objtype = '260'">
						<xsl:text>attribute=usbb           setting=&lt;enabled|enabledwithbios|disabled&gt;</xsl:text>
						<xsl:call-template name="NewLine"/>
					</xsl:when>
		           	<xsl:when test="@objtype = '245'">
						<xsl:text>attribute=ide            setting=&lt;on|off&gt;  force=&lt;true&gt;</xsl:text>
						<xsl:call-template name="NewLine"/>
					</xsl:when>
			          <xsl:when test="@objtype = '246'">
						<xsl:choose>
				         	    	<!--xsl:when test="ObjName='OnBoard RAID'">
						    		<xsl:text>attribute=onboardraid    setting=&lt;raid|off|scsi&gt;  force=&lt;true&gt;</xsl:text>
								<xsl:call-template name="NewLine"/>
							</xsl:when-->
						     <xsl:when test="ObjName='Primary SCSI'">
							    	  <xsl:text>attribute=primaryscsi    setting=&lt;on|off&gt;  force=&lt;true&gt;</xsl:text>
								<xsl:call-template name="NewLine"/>
							</xsl:when>
						     <xsl:when test="ObjName='Secondary SCSI'">
								<xsl:text>attribute=secondaryscsi  setting=&lt;on|off&gt;</xsl:text>
								<xsl:call-template name="NewLine"/>
							</xsl:when>
						</xsl:choose>
					</xsl:when>
			           <xsl:when test="@objtype = '247'">
						<xsl:text>attribute=bootsequence   setting=&lt;</xsl:text>
						<xsl:if test="Capabilities/DisketteFirst='true' ">
							<xsl:text>diskettefirst</xsl:text>
						</xsl:if>
						<xsl:if test="Capabilities/HDOnly='true'">
							<xsl:if test="Capabilities/DisketteFirst='true' "><!--XLATESTART-->|<!--XLATESTOP-->
							</xsl:if>
							<xsl:text>hdonly</xsl:text>
						</xsl:if>
						<xsl:if test="Capabilities/DeviceList='true'">
							<xsl:if test="(Capabilities/DisketteFirst='true') or  (Capabilities/HDOnly='true')"><!--XLATESTART-->|<!--XLATESTOP-->
							</xsl:if>
							<xsl:text>devicelist</xsl:text>
						</xsl:if>
						<xsl:if test="Capabilities/CDRomFirst='true'">
							<xsl:if test="(Capabilities/DisketteFirst='true') or  (Capabilities/HDOnly='true') or (Capabilities/DeviceList='true')"><!--XLATESTART-->|<!--XLATESTOP-->
    							</xsl:if>
							<xsl:text>cdromfirst</xsl:text>
						</xsl:if>
						<xsl:text>&gt;</xsl:text>
						<xsl:call-template name="NewLine"/>
					</xsl:when>
		           		<xsl:when test="@objtype = '249'">
						<xsl:text>attribute=ppaddress      setting=&lt;off|lpt1|lpt2|lpt3&gt;</xsl:text>
						<xsl:call-template name="NewLine"/>
					</xsl:when>
			           	<xsl:when test="@objtype = '250'">
						<xsl:text>attribute=ppmode         setting=&lt;</xsl:text>
						<xsl:if test="Capabilities/AT='true' ">
							<xsl:text>at</xsl:text>
						</xsl:if>
						<xsl:if test="Capabilities/PS2='true' ">
							<xsl:text>|ps2</xsl:text>
						</xsl:if>
						<xsl:if test="Capabilities/ECP='true' ">
							<xsl:text>|ecp</xsl:text>
						</xsl:if>
						<xsl:if test="Capabilities/EPP='true' ">
							<xsl:text>|epp</xsl:text>
						</xsl:if>
						<xsl:text>&gt;</xsl:text>
					      <xsl:call-template name="NewLine"/>
					</xsl:when>
		        	   	<xsl:when test="@objtype = '251'">
						<xsl:choose>
				           	<xsl:when test="ObjName='Serial Port 1'">
								<xsl:text>attribute=serialport1    setting=&lt;off|auto|com1|com3&gt;</xsl:text>
								<xsl:call-template name="NewLine"/>
							</xsl:when>
				           	<xsl:when test="ObjName='Serial Port 2'">
								<xsl:text>attribute=serialport2    setting=&lt;off|auto|com2|com4&gt;</xsl:text>
								<xsl:call-template name="NewLine"/>
							</xsl:when>
						</xsl:choose>
					</xsl:when>
		           	<xsl:when test="@objtype = '252'">
						<xsl:text>attribute=speaker        setting=&lt;on|off&gt;</xsl:text>
						<xsl:call-template name="NewLine"/>
					</xsl:when>
		           	<xsl:when test="@objtype = '253'">
						<xsl:text>attribute=wakeonlan      setting=&lt;disable|expansion|onboard|addin&gt;</xsl:text>
						<xsl:call-template name="NewLine"/>
					</xsl:when>
               		<xsl:when test="@objtype = '261'">
						<xsl:text>attribute=intrusion      setting=&lt;disable|enable&gt;</xsl:text>
						<xsl:call-template name="NewLine"/>
					</xsl:when>
               		<xsl:when test="@objtype = '262'">
						<xsl:text>attribute=bezel          setting=&lt;disable|enable&gt;</xsl:text>
						<xsl:call-template name="NewLine"/>
					</xsl:when>
		           	<xsl:when test="@objtype = '263'">
						 <xsl:text>attribute=romb           setting=&lt;off|raid|scsi&gt;  force=&lt;true&gt;</xsl:text>
						<xsl:call-template name="NewLine"/>
					</xsl:when>
		           	<xsl:when test="@objtype = '264'">
						<xsl:choose>
				           	<xsl:when test="ObjName='RAID Channel A' and Capabilities/Rdonly='false'">
						 		<xsl:text>attribute=romba          setting=&lt;raid|scsi&gt;  force=&lt;true&gt;</xsl:text>
								<xsl:call-template name="NewLine"/>						
					     	</xsl:when>
				           	<xsl:when test="ObjName='RAID Channel B' and Capabilities/Rdonly='false'">
						 		<xsl:text>attribute=rombb          setting=&lt;raid|scsi&gt;  force=&lt;true&gt;</xsl:text>
								<xsl:call-template name="NewLine"/>
					     	</xsl:when>
						</xsl:choose>
					</xsl:when>

				</xsl:choose>
			</xsl:for-each>
		</xsl:if>
	     <xsl:if test="BIOSSetupListCount = '0'">
			<xsl:text>Error! BIOS setup feature unavailable on this system.</xsl:text>
			<xsl:call-template name="NewLine"/>
		</xsl:if>
	</xsl:template>
	
	<xsl:template name="CLIMsgID">
		<xsl:param name="id"/>
		<xsl:param name="shownvpairs"/>
		<xsl:param name="paramtxt"/>
		<xsl:param name="nametxt"/>
		<xsl:param name="parsetxt"/>
		<xsl:param name="parsetxt2"/>
		<xsl:param name="hipstat"/>
		<xsl:choose>
			<xsl:when test="$id = '1'">
				<!--XLATESTART-->AC switch settings.<!--XLATESTOP-->
			</xsl:when>
			<xsl:when test="$id = '2'">
				<!--XLATESTART-->BIOS properties.<!--XLATESTOP-->
			</xsl:when>
			<xsl:when test="$id = '3'">
				<!--XLATESTART-->BIOS setup configuration.<!--XLATESTOP-->
			</xsl:when>
			<xsl:when test="$id = '4'">
				<!--XLATESTART-->Chassis properties.<!--XLATESTOP-->
			</xsl:when>
			<xsl:when test="$id = '5'">
				<!--XLATESTART-->Current probe(s) properties.<!--XLATESTOP-->
				<xsl:if test="$shownvpairs = 'true'">
					<xsl:call-template name="NewLine"/>
					<!--XLATESTART-->Valid parameters are:<!--XLATESTOP-->
					<xsl:call-template name="NewLine"/>
					<xsl:text>index=&lt;number&gt;	 </xsl:text><!--XLATESTART-->Displays properties for a particular current probe.<!--XLATESTOP-->
				</xsl:if>
			</xsl:when>
			<xsl:when test="$id = '6'">
				<!--XLATESTART-->Fan probe(s) properties.<!--XLATESTOP-->
				<xsl:if test="$shownvpairs = 'true'">
					<xsl:call-template name="NewLine"/>
					<!--XLATESTART-->Valid parameters are:<!--XLATESTOP-->
					<xsl:call-template name="NewLine"/>
					<xsl:text>index=&lt;number&gt;	 </xsl:text><!--XLATESTART-->Displays properties for a particular fan probe.<!--XLATESTOP-->
				</xsl:if>
			</xsl:when>
			<xsl:when test="$id = '7'">
				<!--XLATESTART-->Firmware properties.<!--XLATESTOP-->
			</xsl:when>
			<xsl:when test="$id = '8'">
				<!--XLATESTART-->Chassis intrusion status.<!--XLATESTOP-->
			</xsl:when>
			<xsl:when test="$id = '9'">
				<!--XLATESTART-->System memory configuration.<!--XLATESTOP-->
				<xsl:if test="$shownvpairs = 'true'">
					<xsl:call-template name="NewLine"/>
					<!--XLATESTART-->Valid parameters are:<!--XLATESTOP-->
					<xsl:call-template name="NewLine"/>
					<xsl:text>index=&lt;number&gt;	 </xsl:text><!--XLATESTART-->Displays memory device properties for a particular connector.<!--XLATESTOP-->
				</xsl:if>
			</xsl:when>
			<xsl:when test="$id = '10'">
				<!--XLATESTART-->Network interace card(s) properties.<!--XLATESTOP-->
				<xsl:if test="$shownvpairs = 'true'">
					<xsl:call-template name="NewLine"/>
					<!--XLATESTART-->Valid parameters are:<!--XLATESTOP-->
					<xsl:call-template name="NewLine"/>
					<xsl:text>index=&lt;number&gt;	 </xsl:text><!--XLATESTART-->Displays network card details for a particular card.<!--XLATESTOP-->
				</xsl:if>
			</xsl:when>
			<xsl:when test="$id = '11'">
				<!--XLATESTART-->Port(s) properties.<!--XLATESTOP-->
			</xsl:when>
			<xsl:when test="$id = '12'">
				<!--XLATESTART-->Processor(s) properties.<!--XLATESTOP-->
				<xsl:if test="$shownvpairs = 'true'">
					<xsl:call-template name="NewLine"/>
					<!--XLATESTART-->Valid parameters are:<!--XLATESTOP-->
					<xsl:call-template name="NewLine"/>
					<xsl:text>index=&lt;number&gt;	 </xsl:text><!--XLATESTART-->Displays cache details for a particular processor.<!--XLATESTOP-->
				</xsl:if>
			</xsl:when>
			<xsl:when test="$id = '13'">
				<!--XLATESTART-->Power supply(s) properties.<!--XLATESTOP-->
			</xsl:when>
			<xsl:when test="$id = '14'">
				<!--XLATESTART-->Slot(s) properties.<!--XLATESTOP-->
				<xsl:if test="$shownvpairs = 'true'">
					<xsl:call-template name="NewLine"/>
					<!--XLATESTART-->Valid parameters are:<!--XLATESTOP-->
					<xsl:call-template name="NewLine"/>
					<xsl:text>index=&lt;number&gt;	 </xsl:text><!--XLATESTART-->Displays adapter details for a particular slot.<!--XLATESTOP-->
				</xsl:if>
			</xsl:when>
			<xsl:when test="$id = '15'">
				<!--XLATESTART-->Chassis properties summary.<!--XLATESTOP-->
			</xsl:when>
			<xsl:when test="$id = '16'">
				<!--XLATESTART-->Temperature probe(s) properties.<!--XLATESTOP-->
				<xsl:if test="$shownvpairs = 'true'">
					<xsl:call-template name="NewLine"/>
					<!--XLATESTART-->Valid parameters are:<!--XLATESTOP-->
					<xsl:call-template name="NewLine"/>
					<xsl:text>index=&lt;number&gt;	 </xsl:text><!--XLATESTART-->Displays properties for a particular temperature probe.<!--XLATESTOP-->
				</xsl:if>
			</xsl:when>
			<xsl:when test="$id = '17'">
				<!--XLATESTART-->Voltage probe(s) properties.<!--XLATESTOP-->
				<xsl:if test="$shownvpairs = 'true'">
					<xsl:call-template name="NewLine"/>
					<!--XLATESTART-->Valid parameters are:<!--XLATESTOP-->
					<xsl:call-template name="NewLine"/>
					<xsl:text>index=&lt;number&gt;	 </xsl:text><!--XLATESTART-->Displays properties for a particular voltage probe.<!--XLATESTOP-->
				</xsl:if>
			</xsl:when>
			<xsl:when test="$id = '18'">
				<!--XLATESTART-->Port(s) properties.<!--XLATESTOP-->
			</xsl:when>
			<xsl:when test="$id = '19'">
				<!--XLATESTART-->Slot(s) properties.<!--XLATESTOP-->
				<xsl:if test="$shownvpairs = 'true'">
					<xsl:call-template name="NewLine"/>
					<!--XLATESTART-->Valid parameters are:<!--XLATESTOP-->
					<xsl:call-template name="NewLine"/>
					<xsl:text>index=&lt;number&gt;	 </xsl:text><!--XLATESTART-->Displays slot details for a particular slot.<!--XLATESTOP-->
				</xsl:if>
			</xsl:when>
			<xsl:when test="$id = '20'">
				<!--XLATESTART-->Chassis component properties.<!--XLATESTOP-->
			</xsl:when>
			<xsl:when test="$id = '21'">
				<!--XLATESTART-->Chassis asset tag value.<!--XLATESTOP-->
			</xsl:when>
			<xsl:when test="$id = '22'">
				<!--XLATESTART-->Fan control settings.<!--XLATESTOP-->
			</xsl:when>
			<xsl:when test="$id = '23'">
				<!--XLATESTART-->Power button control settings.<!--XLATESTOP-->
			</xsl:when>
			<xsl:when test="$id = '24'">
				<!--XLATESTART-->Chassis component properties.<!--XLATESTOP-->
			</xsl:when>
			<xsl:when test="$id = '25'">
				<!--XLATESTART-->Chassis LED settings.<!--XLATESTOP-->
				<xsl:if test="$shownvpairs = 'true'">
					<xsl:call-template name="NewLine"/>
					<!--XLATESTART-->Valid parameters are:<!--XLATESTOP-->
					<xsl:call-template name="NewLine"/>
					<xsl:text>index=&lt;number&gt;	 </xsl:text><!--XLATESTART-->Chassis index (defaults to 0).<!--XLATESTOP-->
				</xsl:if>
			</xsl:when>
			<xsl:when test="$id = '26'">
				<!--XLATESTART-->Chassis information.<!--XLATESTOP-->
				<xsl:if test="$shownvpairs = 'true'">
					<xsl:call-template name="NewLine"/>
					<!--XLATESTART-->Valid parameters are:<!--XLATESTOP-->
					<xsl:call-template name="NewLine"/>
					<xsl:text>index=&lt;number&gt;	 </xsl:text><!--XLATESTART-->Displays properties for a particular chassis.<!--XLATESTOP-->
				</xsl:if>
			</xsl:when>
			<xsl:when test="$id = '999'">
				<!--XLATETHIS-->For further help, type the command followed by -?<!--XLATETHIS-->
				<xsl:call-template name="NewLine"/>
			</xsl:when>
			<xsl:when test="$id = '1000'">
                          <xsl:call-template name="ConfigSuccess"><xsl:with-param name="subCom"><xsl:value-of select="$nametxt"/></xsl:with-param> 
			      </xsl:call-template>
			</xsl:when>
			<xsl:when test="$id = '1001'">
				<!--XLATETHIS-->Error! Signed number expected, read: <!--XLATETHIS-->
				<xsl:value-of select="$parsetxt"/>
			</xsl:when>
			<xsl:when test="$id = '1002'">
				<!--XLATETHIS-->Error! unsigned, whole number expected, read: <!--XLATETHIS-->
				<xsl:value-of select="$parsetxt"/>
			</xsl:when>
			<xsl:when test="$id = '1003'">
				<!--XLATETHIS-->Error! true or false expected, read: <!--XLATETHIS-->
				<xsl:value-of select="$parsetxt"/>
			</xsl:when>
			<xsl:when test="$id = '1004'">
				<!--XLATETHIS-->Error! alphanumeric or symbol expected, read: <!--XLATETHIS-->
				<xsl:value-of select="$parsetxt"/>
			</xsl:when>
			<xsl:when test="$id = '1005'">
				<!--XLATETHIS-->Error! Required parameter missing: <!--XLATETHIS-->
				<xsl:value-of select="$parsetxt"/><xsl:text>=</xsl:text>
			      <xsl:call-template name="CLIParamFormat"><xsl:with-param name="format"><xsl:value-of select="$parsetxt2"/></xsl:with-param> 
			      </xsl:call-template>
			</xsl:when>
			<xsl:when test="$id = '1006'">
				<!--XLATETHIS-->Error! At least one optional parameter must be specified.<!--XLATETHIS-->
			</xsl:when>
			<xsl:when test="$id = '1007'">
				<!--XLATETHIS-->Error! Command incomplete <!--XLATETHIS-->
				<xsl:value-of select="$parsetxt"/>
			</xsl:when>
			<xsl:when test="$id = '1008'">
			      <xsl:call-template name="CLIObjNotFound">
					<xsl:with-param name="subCom"><xsl:value-of select="$nametxt"/></xsl:with-param>
		               <xsl:with-param name="paramNam"><xsl:value-of select="$paramtxt"/></xsl:with-param>
			      </xsl:call-template>
			</xsl:when>

			<xsl:when test="$id = '9999'">
			      <!--XLATESTART-->Error! No <!--XLATESTOP--><xsl:call-template name="CLIObjName"><xsl:with-param name="subCom"><xsl:value-of select="$nametxt"/></xsl:with-param></xsl:call-template><!--XLATETHIS--> found on this system.<!--XLATETHIS-->
			</xsl:when>
			<xsl:when test="$id = '1009'">
				<!--XLATETHIS-->Error! cannot load data accessor: <!--XLATETHIS-->
			</xsl:when>
			<xsl:when test="$id = '1010'">
			      <xsl:call-template name="CLIIndexRange">
					<xsl:with-param name="subCom"><xsl:value-of select="$nametxt"/></xsl:with-param>
					<xsl:with-param name="index"><xsl:value-of select="$parsetxt"/></xsl:with-param>
			      </xsl:call-template>
			</xsl:when>
			<xsl:when test="$id = '1011'">
			      <xsl:call-template name="CLICommandFailed">
					<xsl:with-param name="subCom"><xsl:value-of select="$nametxt"/></xsl:with-param>
		               <xsl:with-param name="paramNam"><xsl:value-of select="$paramtxt"/></xsl:with-param>
					<xsl:with-param name="stat"><xsl:value-of select="$hipstat"/></xsl:with-param>
				</xsl:call-template>
			</xsl:when>
			<xsl:when test="$id = '1012'">
				<!--XLATETHIS-->Error! Unrecognized parameter value: <!--XLATETHIS-->
				<xsl:value-of select="$parsetxt"/>
			</xsl:when>
			<xsl:when test="$id = '1013'">
				<!--XLATESTART-->Error! Text too long: <!--XLATESTOP-->
				<xsl:value-of select="$parsetxt2"/>
				 <!--XLATESTART-->. Maximum number of characters is: <!--XLATESTOP-->
				<xsl:value-of select="$parsetxt"/>
			</xsl:when>
			<xsl:when test="$id = '1014'">
				<!--XLATETHIS-->Error! Value incorrect for parameter: <!--XLATETHIS-->
				<xsl:value-of select="$parsetxt"/><xsl:text>=</xsl:text>
				<xsl:value-of select="$parsetxt2"/>
			</xsl:when>
			<xsl:when test="$id = '1015'">
				<!--XLATETHIS-->Error! Number expected, read: <!--XLATETHIS-->
				<xsl:value-of select="$parsetxt"/>
			</xsl:when>
			<xsl:when test="$id = '1016'">
				<!--XLATETHIS-->Error! Date in form mmddyy expected, read: <!--XLATETHIS-->
				<xsl:value-of select="$parsetxt"/>
			</xsl:when>		
			<xsl:when test="$id = '1017'">
				<!--XLATETHIS-->Error! Percent (0-100) expected, read: <!--XLATETHIS-->
				<xsl:value-of select="$parsetxt"/>
			</xsl:when>	
			<xsl:when test="$id = '1018'">
				<!--XLATETHIS-->Error! Number with up to 1 digit after decimal point expected, read: <!--XLATETHIS-->
				<xsl:value-of select="$parsetxt"/>
			</xsl:when>			
			<xsl:when test="$id = '1019'">
				<!--XLATETHIS-->Error! Number with up to 2 digits after decimal point expected, read: <!--XLATETHIS-->
				<xsl:value-of select="$parsetxt"/>
			</xsl:when>			
			<xsl:when test="$id = '1020'">
				<!--XLATETHIS-->Error! Number with up to 3 digits after decimal point expected, read: <!--XLATETHIS-->
				<xsl:value-of select="$parsetxt"/>
			</xsl:when>	
			<xsl:when test="$id = '1021'">
				<!--XLATETHIS-->Error! Month is invalid: <!--XLATETHIS-->
				<xsl:value-of select="$parsetxt"/>
			</xsl:when>
			<xsl:when test="$id = '1022'">
				<!--XLATETHIS-->Error! Day is invalid: <!--XLATETHIS-->
				<xsl:value-of select="$parsetxt"/>
			</xsl:when>
			<xsl:when test="$id = '1023'">
				<!--XLATETHIS-->Error! Not a leap year: <!--XLATETHIS-->
				<xsl:value-of select="$parsetxt"/>
			</xsl:when>
			<xsl:when test="$id = '1024'">
				<!--XLATETHIS-->Error! Alphanumeric text expected. <!--XLATETHIS-->
			</xsl:when>	
			<xsl:when test="$id = '1025'">
				<!--XLATETHIS-->Error! Unrecognized parameter: <!--XLATETHIS-->
				<xsl:value-of select="$parsetxt"/>
			</xsl:when>
			<xsl:when test="$id = '1026'">
				<!--XLATETHIS-->Error! Cannot make date with this mmddyy on 32 bit operating system: <!--XLATETHIS-->
				<xsl:value-of select="$parsetxt"/>
			</xsl:when>
			<xsl:when test="$id = '1027'">
				<!--XLATETHIS-->Error! IP Address (ddd.ddd.ddd.ddd) expected, read: <!--XLATETHIS-->
				<xsl:value-of select="$parsetxt"/>
			</xsl:when>
			<xsl:when test="$id = '1028'">
				<!--XLATETHIS-->Error! Required parameter missing: <!--XLATETHIS-->
				<xsl:value-of select="$parsetxt"/><xsl:text>=</xsl:text>
				<xsl:value-of select="$parsetxt2"/>
			</xsl:when>
			<xsl:when test="$id = '1029'">
				<!--XLATETHIS-->Error! First char alpha folowed by alphanumeric expected, read: <!--XLATETHIS-->
				<xsl:value-of select="$parsetxt"/>
			</xsl:when>	

			<xsl:when test="$id = '1033'">
				<!--XLATETHIS-->Error! Text with at least one character expected.<!--XLATETHIS-->
				<xsl:value-of select="$parsetxt"/>
			</xsl:when>
			
			<xsl:when test="$id = '1034'">
				<!--XLATETHIS-->Error! Year must be greater than or equal to 1970. Read: <!--XLATETHIS-->
				<xsl:value-of select="$parsetxt"/>
			</xsl:when>
			
			<xsl:when test="$id = '1035'">
			      <xsl:call-template name="CLIPromptCanceled">
					<xsl:with-param name="subCom"><xsl:value-of select="$nametxt"/></xsl:with-param>
     				<xsl:with-param name="paramNam"><xsl:value-of select="$paramtxt"/></xsl:with-param>
     				<xsl:with-param name="parseTxt"><xsl:value-of select="$parsetxt"/></xsl:with-param> 
					<xsl:with-param name="stat"><xsl:value-of select="$hipstat"/></xsl:with-param>
				</xsl:call-template>
			</xsl:when>
			
			<xsl:when test="$id = '1036'">
			      <xsl:call-template name="CLIPromptInvalid">
					<xsl:with-param name="subCom"><xsl:value-of select="$nametxt"/></xsl:with-param>
     				<xsl:with-param name="paramNam"><xsl:value-of select="$paramtxt"/></xsl:with-param>
     				<xsl:with-param name="parseTxt"><xsl:value-of select="$parsetxt"/></xsl:with-param> 
					<xsl:with-param name="stat"><xsl:value-of select="$hipstat"/></xsl:with-param>
				</xsl:call-template>
			</xsl:when>
			
			<xsl:when test="$id = '1037'">
				<!--XLATETHIS-->Error! Whole numbers seperated by colon(s) expected. Read: <!--XLATETHIS-->
				<xsl:value-of select="$parsetxt"/>
			</xsl:when>
			
			<xsl:when test="$id = '1038'">
				<!--XLATETHIS-->Error! Whole numbers seperated by colon range error. Max is: <!--XLATETHIS-->
				<xsl:value-of select="$parsetxt"/>
			</xsl:when>
			
			<xsl:when test="$id = '1039'">
				<!--XLATETHIS-->Error! Multiple values not unique:  <!--XLATETHIS-->
				<xsl:value-of select="$parsetxt"/>
			</xsl:when>
					
			<xsl:when test="$id = '1040'">
				<!--XLATETHIS-->Error! Illegal combination of parameters.<!--XLATETHIS-->
			</xsl:when>

			<xsl:when test="$id = '1101'">
				<!--XLATETHIS-->Error! Signed number or "default" expected, read: <!--XLATETHIS-->
				<xsl:value-of select="$parsetxt"/>
			</xsl:when>
			<xsl:when test="$id = '1102'">
				<!--XLATETHIS-->Error! unsigned number or "default" expected, read: <!--XLATETHIS-->
				<xsl:value-of select="$parsetxt"/>
			</xsl:when>
			<xsl:when test="$id = '1103'">
				<!--XLATETHIS-->Error! true or false or "default" expected, read: <!--XLATETHIS-->
				<xsl:value-of select="$parsetxt"/>
			</xsl:when>
			<xsl:when test="$id = '1104'">
				<!--XLATETHIS-->Error! alphanumeric or symbol or "default" expected, read: <!--XLATETHIS-->
				<xsl:value-of select="$parsetxt"/>
			</xsl:when>
			<xsl:when test="$id = '1200'">
				<xsl:text>Error! This current probe </xsl:text>
				<xsl:value-of select="$paramtxt"/>
				 <xsl:text> warning threshold must be between </xsl:text>
                     <xsl:call-template name="prnVolt">
					<xsl:with-param name="volt"><xsl:value-of select="$parsetxt"/></xsl:with-param>
				</xsl:call-template>
			      <xsl:text> and </xsl:text>
				<xsl:call-template name="prnVolt">
				    <xsl:with-param name="volt"><xsl:value-of select="$parsetxt2"/>
				</xsl:with-param></xsl:call-template>
			</xsl:when>	
			<xsl:when test="$id = '1201'">
				<xsl:text>Error! This fan probe </xsl:text>
				<xsl:value-of select="$paramtxt"/>
				 <xsl:text> warning threshold must be between </xsl:text>
                     <xsl:value-of select="$parsetxt"/>
			       <xsl:text> and </xsl:text>
				<xsl:value-of select="$parsetxt2"/>
			</xsl:when>					
			<xsl:when test="$id = '1202'">
				<xsl:text>Error! This temp probe </xsl:text>
				<xsl:value-of select="$paramtxt"/>
				 <xsl:text> warning threshold must be between </xsl:text>
                         <xsl:call-template name="prnTemp">
					<xsl:with-param name="temp"><xsl:value-of select="$parsetxt"/></xsl:with-param>
				</xsl:call-template>
			      <xsl:text> and </xsl:text>
				<xsl:call-template name="prnTemp">
				    <xsl:with-param name="temp"><xsl:value-of select="$parsetxt2"/>
				</xsl:with-param></xsl:call-template>
			</xsl:when>
			<xsl:when test="$id = '1203'">
				<xsl:text>Error! This voltage probe </xsl:text>
				<xsl:value-of select="$paramtxt"/>
				 <xsl:text> warning threshold must be between </xsl:text>
                         <xsl:call-template name="prnVolt">
					<xsl:with-param name="volt"><xsl:value-of select="$parsetxt"/></xsl:with-param>
				</xsl:call-template>
			      <xsl:text> and </xsl:text>
				<xsl:call-template name="prnVolt">
				    <xsl:with-param name="volt"><xsl:value-of select="$parsetxt2"/>
				</xsl:with-param></xsl:call-template>
			</xsl:when>
			<xsl:when test="$id = '1204'">
				<xsl:text>Error! Current min warning threshold (</xsl:text>
				<xsl:call-template name="prnVolt">
					<xsl:with-param name="volt"><xsl:value-of select="$parsetxt"/></xsl:with-param></xsl:call-template>
				<xsl:text>) must be less than max (</xsl:text>
				<xsl:call-template name="prnVolt">
					<xsl:with-param name="volt"><xsl:value-of select="$parsetxt2"/></xsl:with-param>
				</xsl:call-template>
				<xsl:text>)</xsl:text>
			</xsl:when>		
			<xsl:when test="$id = '1205'">
				<xsl:text>Error! Fan min warning threshold (</xsl:text>
				<xsl:value-of select="$parsetxt"/>
				<xsl:text>) must be less than max (</xsl:text>
				<xsl:value-of select="$parsetxt2"/>
				<xsl:text>)</xsl:text>
			</xsl:when>			
			<xsl:when test="$id = '1206'">
				<xsl:text>Error! Temp min warning threshold (</xsl:text>
				<xsl:call-template name="prnTemp">
					<xsl:with-param name="temp"><xsl:value-of select="$parsetxt"/></xsl:with-param></xsl:call-template>
				<xsl:text>) must be less than max (</xsl:text>
				<xsl:call-template name="prnTemp">
					<xsl:with-param name="temp"><xsl:value-of select="$parsetxt2"/></xsl:with-param>
				</xsl:call-template>
				<xsl:text>)</xsl:text>
			</xsl:when>
			<xsl:when test="$id = '1207'">
				<xsl:text>Error! Voltage min warning threshold (</xsl:text>
				<xsl:call-template name="prnVolt">
					<xsl:with-param name="volt"><xsl:value-of select="$parsetxt"/></xsl:with-param></xsl:call-template>
				<xsl:text>) must be less than max (</xsl:text>
				<xsl:call-template name="prnVolt">
					<xsl:with-param name="volt"><xsl:value-of select="$parsetxt2"/></xsl:with-param>
				</xsl:call-template>
				<xsl:text>)</xsl:text>
			</xsl:when>	
			<xsl:when test="$id = '1208'">
				 <xsl:call-template name="CLIProbeInvalid">
				      <xsl:with-param name="subCom"><xsl:value-of select="$nametxt"/></xsl:with-param> 
					<xsl:with-param name="probeindex"><xsl:value-of select="$parsetxt"/></xsl:with-param>
				</xsl:call-template>
			</xsl:when>
			<xsl:when test="$id = '1209'">
			      <xsl:call-template name="CLIWarnThresh"><xsl:with-param name="subCom"><xsl:value-of select="$nametxt"/></xsl:with-param> 
			      </xsl:call-template>
			</xsl:when>
			<xsl:when test="$id = '1210'">
			      <xsl:call-template name="CLIWarnUnavailable"><xsl:with-param name="subCom"><xsl:value-of select="$nametxt"/></xsl:with-param> 
			      </xsl:call-template>
			</xsl:when>	
			<xsl:when test="$id = '1211'">
				<!--XLATETHIS-->Error! Flash timeout value should be less than 3600 seconds.<!--XLATETHIS-->
			</xsl:when>
			<xsl:when test="$id = '1910'">
				<xsl:call-template name="CLISubCommand">
					<xsl:with-param name="command">chassis</xsl:with-param>
				</xsl:call-template>
				<!--XLATESTART-->Set chassis component properties.<!--XLATESTOP-->
			</xsl:when>
			<xsl:when test="$id = '1911'">
				<!--XLATETHIS-->Error! Flash timeout value should be greater than 0 seconds.<!--XLATETHIS-->
			</xsl:when>
			<xsl:when test="$id = '3001'">
				<xsl:call-template name="CLISubCommand">
					<xsl:with-param name="command">currents</xsl:with-param>
				</xsl:call-template>
				<!--XLATESTART-->Set current probe threshold(s).<!--XLATESTOP-->
			</xsl:when>			
			<xsl:when test="$id = '3002'">
				<xsl:call-template name="CLISubCommand">
					<xsl:with-param name="command">currents</xsl:with-param>
				</xsl:call-template>
				<!--XLATESTART-->Set current probe threshold(s).<!--XLATESTOP-->
				<xsl:call-template name="NewLine"/>	
				<!--XLATESTART-->Valid parameters are:<!--XLATESTOP-->
                <xsl:call-template name="NewLine"/>
				<xsl:text>index=&lt;number&gt;          </xsl:text><!--XLATESTART-->Probe index (must be specified).<!--XLATESTOP-->
                <xsl:call-template name="NewLine"/>
				<xsl:text>minwarnthresh=&lt;number&gt;  </xsl:text><!--XLATESTART-->Minimum warning threshold (3 decimal places).<!--XLATESTOP-->
				<xsl:call-template name="NewLine"/>
				<xsl:text>maxwarnthresh=&lt;number&gt;  </xsl:text><!--XLATESTART-->Maximum warning threshold (3 decimal places).<!--XLATESTOP-->
				<xsl:call-template name="NewLine"/>
				<xsl:text>warnthresh=default      </xsl:text><!--XLATESTART-->Set minimum and maximum warning thresholds to default.<!--XLATESTOP-->
			</xsl:when>
			<xsl:when test="$id = '3011'">
				<xsl:call-template name="CLISubCommand">
					<xsl:with-param name="command">fans</xsl:with-param>
				</xsl:call-template>
				<!--XLATESTART-->Set fan probe threshold(s).<!--XLATESTOP-->
			</xsl:when>
			<xsl:when test="$id = '3012'">
				<xsl:call-template name="CLISubCommand">
					<xsl:with-param name="command">fans</xsl:with-param>
				</xsl:call-template>
				<!--XLATESTART-->Set fan probe threshold(s).<!--XLATESTOP-->
				<xsl:call-template name="NewLine"/>	
				<!--XLATESTART-->Valid parameters are:<!--XLATESTOP-->
				<xsl:call-template name="NewLine"/>
				<xsl:text>index=&lt;number&gt;          </xsl:text><!--XLATESTART-->Probe index (must be specified).<!--XLATESTOP-->
				<xsl:call-template name="NewLine"/>
				<xsl:text>minwarnthresh=&lt;number&gt;  </xsl:text><!--XLATESTART-->Minimum warning threshold.<!--XLATESTOP-->
				<xsl:call-template name="NewLine"/>
				<xsl:text>maxwarnthresh=&lt;number&gt;  </xsl:text><!--XLATESTART-->Maximum warning threshold.<!--XLATESTOP-->
				<xsl:call-template name="NewLine"/>
				<xsl:text>warnthresh=default      </xsl:text><!--XLATESTART-->Set minimum and maximum warning thresholds to default.<!--XLATESTOP-->
			</xsl:when>
			<xsl:when test="$id = '3021'">
				<xsl:call-template name="CLISubCommand">
					<xsl:with-param name="command">temps</xsl:with-param>
				</xsl:call-template>
				<!--XLATESTART-->Set temperature probe threshold(s).<!--XLATESTOP-->
			</xsl:when>			
			<xsl:when test="$id = '3022'">
				<xsl:call-template name="CLISubCommand">
					<xsl:with-param name="command">temps</xsl:with-param>
				</xsl:call-template>
				<!--XLATESTART-->Set temperature probe threshold(s).<!--XLATESTOP-->
				<xsl:call-template name="NewLine"/>	
				<!--XLATESTART-->Valid parameters are:<!--XLATESTOP-->
				<xsl:call-template name="NewLine"/>
				<xsl:text>index=&lt;number&gt;          </xsl:text><!--XLATESTART-->Probe index (must be specified).<!--XLATESTOP-->
				<xsl:call-template name="NewLine"/>
				<xsl:text>minwarnthresh=&lt;number&gt;  </xsl:text><!--XLATESTART-->Minimum warning threshold (1 decimal place).<!--XLATESTOP-->
				<xsl:call-template name="NewLine"/>
				<xsl:text>maxwarnthresh=&lt;number&gt;  </xsl:text><!--XLATESTART-->Maximum warning threshold (1 decimal place).<!--XLATESTOP-->
				<xsl:call-template name="NewLine"/>
				<xsl:text>warnthresh=default      </xsl:text><!--XLATESTART-->Set minimum and maximum warning thresholds to default.<!--XLATESTOP-->
			</xsl:when>
			<xsl:when test="$id = '3031'">
				<xsl:call-template name="CLISubCommand">
					<xsl:with-param name="command">volts</xsl:with-param>
				</xsl:call-template>
				<xsl:text>Set voltage probe threshold(s).</xsl:text>
			</xsl:when>	
			<xsl:when test="$id = '3032'">
				<xsl:call-template name="CLISubCommand">
					<xsl:with-param name="command">volts</xsl:with-param>
				</xsl:call-template>
				<xsl:text>Set voltage probe threshold(s).</xsl:text>
				<xsl:call-template name="NewLine"/>	
				<!--XLATESTART-->Valid parameters are:<!--XLATESTOP-->
				<xsl:call-template name="NewLine"/>
				<xsl:text>index=&lt;number&gt;          </xsl:text><!--XLATESTART-->Probe index (must be specified).<!--XLATESTOP-->
				<xsl:call-template name="NewLine"/>
				<xsl:text>minwarnthresh=&lt;number&gt;  </xsl:text><!--XLATESTART-->Minimum warning threshold (3 decimal places).<!--XLATESTOP-->
				<xsl:call-template name="NewLine"/>
				<xsl:text>maxwarnthresh=&lt;number&gt;  </xsl:text><!--XLATESTART-->Maximum warning threshold (3 decimal places).<!--XLATESTOP-->
				<xsl:call-template name="NewLine"/>
				<xsl:text>warnthresh=default      </xsl:text><!--XLATESTART-->Set minimum and maximum warning thresholds to default.<!--XLATESTOP-->
			</xsl:when>
			<xsl:when test="$id = '3041'">
				<xsl:call-template name="CLISubCommand">
					<xsl:with-param name="command">fancontrol</xsl:with-param>
				</xsl:call-template>
				<!--XLATESTART-->Set fan control to quiet or max cooling.<!--XLATESTOP-->
			</xsl:when>
			<xsl:when test="$id = '3042'">
				<xsl:call-template name="CLISubCommand">
					<xsl:with-param name="command">fancontrol</xsl:with-param>
				</xsl:call-template>
				<!--XLATESTART-->Set fan control to quiet or max cooling.<!--XLATESTOP-->
				<xsl:call-template name="NewLine"/>	
				<!--XLATESTART-->Valid parameters are:<!--XLATESTOP-->
				<xsl:call-template name="NewLine"/>
				<xsl:text>speed=quiet      </xsl:text><!--XLATESTART-->Set fan speed to quiet mode.<!--XLATESTOP-->
				<xsl:call-template name="NewLine"/>
				<xsl:text>speed=maxcool    </xsl:text><!--XLATESTART-->Set fan speed to max cooling mode.<!--XLATESTOP-->
			</xsl:when>			
			<xsl:when test="$id = '3051'">
				<xsl:call-template name="CLISubCommand">
					<xsl:with-param name="command">acswitch</xsl:with-param>
				</xsl:call-template>
				<!--XLATESTART-->Set AC switch parameters.<!--XLATESTOP-->
			</xsl:when>
			<xsl:when test="$id = '3052'">
				<xsl:call-template name="CLISubCommand">
					<xsl:with-param name="command">acswitch</xsl:with-param>
				</xsl:call-template>
				<!--XLATESTART-->Set AC switch parameters.<!--XLATESTOP-->
				<xsl:call-template name="NewLine"/>	
				<!--XLATESTART-->Valid parameters are:<!--XLATESTOP-->
                    <xsl:if test="substring($parsetxt, 8, 1) = '1'">
					<xsl:call-template name="NewLine"/>
					<xsl:text>mode=source1              Input source Line 1, on restoration, remain on Line 2</xsl:text>
				</xsl:if>
                    <xsl:if test="substring($parsetxt, 7, 1) = '1'">
					<xsl:call-template name="NewLine"/>	
					<xsl:text>mode=source1return        Input source Line 1, on restoration, return to Line 1</xsl:text>
				</xsl:if>
                    <xsl:if test="substring($parsetxt, 6, 1) = '1'">
					<xsl:call-template name="NewLine"/>
					<xsl:text>mode=source2              Input source Line 2, on restoration, remain on Line 1</xsl:text>
				</xsl:if>
                    <xsl:if test="substring($parsetxt, 5, 1) = '1'">
					<xsl:call-template name="NewLine"/>
				     <xsl:text>mode=sourcebreturn        Input source Line 2, on restoration, return to Line 2</xsl:text>
				</xsl:if>
                    <xsl:if test="substring($parsetxt, 4, 1) = '1'">
					<xsl:call-template name="NewLine"/>
					<xsl:text>mode=sourceshare            Shared input mode</xsl:text>
				</xsl:if>
					
				<xsl:choose>
	                    <xsl:when test="($parsetxt2 != '4') or ( paramtxt = '1')">
						<xsl:call-template name="NewLine"/>
					     <xsl:text>redunexpected=&lt;true|false&gt;</xsl:text>
					</xsl:when>
					<xsl:otherwise>
						<xsl:choose>
							<xsl:when test="substring($parsetxt, 4, 5) = '00000'">
								<xsl:call-template name="NewLine"/>
								<xsl:text>No valid parameters.</xsl:text>
							</xsl:when>
							<xsl:otherwise></xsl:otherwise>
						</xsl:choose>
					</xsl:otherwise>
				 </xsl:choose>
			</xsl:when>
			
			<xsl:when test="$id = '3061'">
				<xsl:call-template name="CLISubCommand">
					<xsl:with-param name="command">biossetup</xsl:with-param>
				</xsl:call-template>
				<!--XLATESTART-->Configure BIOS setup.<!--XLATESTOP-->
			</xsl:when>
			<xsl:when test="$id = '3062'">
				<xsl:call-template name="CLISubCommand">
					<xsl:with-param name="command">biossetup</xsl:with-param>
				</xsl:call-template>
				<!--XLATESTART-->Configure BIOS setup.<!--XLATESTOP-->
				<xsl:call-template name="NewLine"/>	
				<!--XLATESTART-->Valid parameters are:<!--XLATESTOP-->
				<xsl:call-template name="NewLine"/>
				<xsl:text>attribute=numlock        setting=&lt;on|off&gt;</xsl:text>
				<xsl:call-template name="NewLine"/>
				<xsl:text>attribute=diskette       setting=&lt;off|auto|writeprotect&gt;</xsl:text>
				<xsl:call-template name="NewLine"/>
				<xsl:text>attribute=NIC            setting=&lt;enabled|disabled|enablednonepxe&gt;</xsl:text>
				<xsl:call-template name="NewLine"/>
				<xsl:text>attribute=mouse          setting=&lt;on|off&gt;</xsl:text>
				<xsl:call-template name="NewLine"/>
				<xsl:text>attribute=usb            setting=&lt;enabled|disabled&gt;</xsl:text>
				<xsl:call-template name="NewLine"/>
				<xsl:text>attribute=usbb           setting=&lt;enabled|enabledwithbios|disabled&gt;</xsl:text>
				<xsl:call-template name="NewLine"/>
				<xsl:text>attribute=ide            setting=&lt;on|off&gt;</xsl:text>
				<xsl:call-template name="NewLine"/>
				<xsl:text>attribute=onboardscsi    setting=&lt;on|off&gt;</xsl:text>
				<xsl:call-template name="NewLine"/>	
				<xsl:text>attribute=secondaryscsi  setting=&lt;on|off&gt;</xsl:text>
				<xsl:call-template name="NewLine"/>							
				<xsl:text>attribute=bootsequence   setting=&lt;diskettefirst|hdonly|devicelist|cdromfirst&gt;</xsl:text>
				<xsl:call-template name="NewLine"/>
				<xsl:text>attribute=ppaddress      setting=&lt;off|lpt1|lpt2|lpt3&gt;</xsl:text>
				<xsl:call-template name="NewLine"/>
				<xsl:text>attribute=ppmode         setting=&lt;at|ps2|ecp|epp&gt;</xsl:text>
				<xsl:call-template name="NewLine"/>
				<xsl:text>attribute=serialport1    setting=&lt;off|auto|com1|com3&gt;</xsl:text>
				<xsl:call-template name="NewLine"/>
				<xsl:text>attribute=serialport2    setting=&lt;off|auto|com2|com4&gt;</xsl:text>
				<xsl:call-template name="NewLine"/>
				<xsl:text>attribute=speaker        setting=&lt;on|of&gt;</xsl:text>
				<xsl:call-template name="NewLine"/>
				<xsl:text>attribute=wakeonlan      setting=&lt;disable|expansion|onboard|addin&gt;</xsl:text>
			</xsl:when>
			<xsl:when test="$id = '3071'">
				<xsl:call-template name="CLISubCommand">
					<xsl:with-param name="command">leds</xsl:with-param>
				</xsl:call-template>
				<!--XLATESTART-->LED configuration.<!--XLATESTOP-->
			</xsl:when>
			<xsl:when test="$id = '3072'">
				<xsl:call-template name="CLISubCommand">
					<xsl:with-param name="command">leds</xsl:with-param>
				</xsl:call-template>
				<!--XLATESTART-->LED configuration.<!--XLATESTOP-->
				<xsl:call-template name="NewLine"/>	
				<!--XLATESTART-->Valid parameters are:<!--XLATESTOP-->
				<xsl:call-template name="NewLine"/>
				<xsl:text>led=fault        severity=&lt;warning|critical&gt; Flash on failure level.</xsl:text>
				<xsl:call-template name="NewLine"/>
				<xsl:text>led=hdfault      action=clear                Clear hard disk fault LED.</xsl:text>
				<xsl:call-template name="NewLine"/>
				<xsl:text>led=identify     flash=&lt;off|on&gt;              Flash chassis identify LED.</xsl:text>
				<xsl:call-template name="NewLine"/>
    		    <xsl:text>                 timeout=&lt;number&gt;            Flash timeout value ( &gt;0 seconds).</xsl:text>
			</xsl:when>			
			<xsl:when test="$id = '3081'">
				<xsl:call-template name="CLISubCommand">
					<xsl:with-param name="command">powerbutton</xsl:with-param>
				</xsl:call-template>
				<!--XLATESTART-->Enable or disable power button.<!--XLATESTOP-->
			</xsl:when>
			<xsl:when test="$id = '3082'">
				<xsl:call-template name="CLISubCommand">
					<xsl:with-param name="command">powerbutton</xsl:with-param>
				</xsl:call-template>
				<!--XLATESTART-->Enable or disable power button.<!--XLATESTOP-->
				<xsl:call-template name="NewLine"/>	
				<!--XLATESTART-->Valid parameters are:<!--XLATESTOP-->
				<xsl:call-template name="NewLine"/>
				<xsl:text>enable=&lt;true|false&gt;          </xsl:text><!--XLATESTART-->Enable/disable power button.<!--XLATESTOP-->
			</xsl:when>
			<xsl:when test="$id = '3091'">
				<xsl:call-template name="CLISubCommand">
					<xsl:with-param name="command">memory</xsl:with-param>
				</xsl:call-template>
				<!--XLATESTART-->Clear memory error count.<!--XLATESTOP-->
			</xsl:when>
			<xsl:when test="$id = '3092'">
				<xsl:call-template name="CLISubCommand">
					<xsl:with-param name="command">memory</xsl:with-param>
				</xsl:call-template>
				<!--XLATESTART-->Clear memory error count.<!--XLATESTOP-->
				<xsl:call-template name="NewLine"/>	
				<!--XLATESTART-->Valid parameters are:<!--XLATESTOP-->
				<xsl:call-template name="NewLine"/>
				<xsl:text>index=&lt;number&gt;      </xsl:text><!--XLATESTART-->Memory device index (must be specified).<!--XLATESTOP-->
                <xsl:call-template name="NewLine"/>
				<xsl:text>errorcount=clear    </xsl:text><!--XLATESTART-->Clear memory error count.<!--XLATESTOP-->
			</xsl:when>
			<xsl:when test="$id = '3101'">
				<xsl:call-template name="CLISubCommand">
					<xsl:with-param name="command">assettag</xsl:with-param>
				</xsl:call-template>
				<!--XLATESTART-->Set chassis asset tag.<!--XLATESTOP-->
			</xsl:when>
			<xsl:when test="$id = '3102'">
				<xsl:call-template name="CLISubCommand">
					<xsl:with-param name="command">assettag</xsl:with-param>
				</xsl:call-template>
				<!--XLATESTART-->Set chassis asset tag.<!--XLATESTOP-->
				<xsl:call-template name="NewLine"/>	
				<!--XLATESTART-->Valid parameters are:<!--XLATESTOP-->
				<xsl:call-template name="NewLine"/>
				<xsl:text>tag=&lt;text&gt;        </xsl:text><!--XLATESTART-->Asset tag value (up to 10 chars, alphanumeric text only). <!--XLATESTOP-->
			</xsl:when>
			<xsl:when test="$id = '3121'">
				<xsl:call-template name="CLISubCommand">
					<xsl:with-param name="command">info</xsl:with-param>
				</xsl:call-template>
				<!--XLATESTART-->Set chassis information.<!--XLATESTOP-->
			</xsl:when>
			<xsl:when test="$id = '3122'">
				<xsl:call-template name="CLISubCommand">
					<xsl:with-param name="command">info</xsl:with-param>
				</xsl:call-template>
				<!--XLATESTART-->Set chassis information.<!--XLATESTOP-->
				<xsl:call-template name="NewLine"/>	
				<!--XLATESTART-->Valid parameters are:<!--XLATESTOP-->
				<xsl:call-template name="NewLine"/>
				<xsl:text>index=&lt;number&gt;   </xsl:text><!--XLATESTART-->Chassis index (defaults to 0, main system chassis).<!--XLATESTOP-->
				<xsl:call-template name="NewLine"/>
	               <xsl:text>tag=&lt;text&gt;       </xsl:text><!--XLATESTART-->Asset tag value (up to 10 chars, alphanumeric text only). <!--XLATESTOP-->
                    <xsl:call-template name="NewLine"/>
				<xsl:text>name=&lt;text&gt;      </xsl:text><!--XLATESTART-->Set chassis name.<!--XLATESTOP-->
			</xsl:when>
			
			<xsl:when test="$id = '3131'">
				<xsl:call-template name="CLISubCommand">
					<xsl:with-param name="command">memorymode</xsl:with-param>
				</xsl:call-template>
				<!--XLATESTART-->Set memory redundancy mode.<!--XLATESTOP-->
			</xsl:when>
			<xsl:when test="$id = '3132'">
				<xsl:call-template name="CLISubCommand">
					<xsl:with-param name="command">memorymode</xsl:with-param>
				</xsl:call-template>
				<!--XLATESTART-->Set memory redundancy mode.<!--XLATESTOP-->
				<xsl:call-template name="NewLine"/>	
				<!--XLATESTART-->Valid parameters are:<!--XLATESTOP-->
				<xsl:call-template name="NewLine"/>
				<xsl:text>index=&lt;number&gt;                       </xsl:text><!--XLATESTART-->Chassis index (defaults to 0).<!--XLATESTOP-->
                <xsl:call-template name="NewLine"/>
				<xsl:text>redundancy=&lt;spare|mirror|disabled&gt;   </xsl:text><!--XLATESTART-->Memory redundancy mode.<!--XLATESTOP-->
			</xsl:when>

			<xsl:otherwise></xsl:otherwise>
		</xsl:choose>
		<xsl:call-template name="NewLine"/>
	</xsl:template>
	<xsl:template name="CLISubCommand">
		<xsl:param name="command"/>
		<xsl:if test="$command != ''">
			<xsl:value-of select="$command"/>
			<xsl:call-template name="Spaces">
				<xsl:with-param name="num"><xsl:value-of select="(17) - string-length($command)"/></xsl:with-param>
			</xsl:call-template>
		</xsl:if>
	</xsl:template>
	<xsl:template name="CLIObjName">
		<xsl:param name="subCom"/>
		<xsl:choose>
			<xsl:when test="$subCom = 'fans'"><xsl:text>fan probes</xsl:text></xsl:when>
			<xsl:when test="$subCom = 'temps'">
				<!--XLATESTART-->temperature probes<!--XLATESTOP-->
			</xsl:when>
			<xsl:when test="$subCom = 'volts'">
				<!--XLATESTART-->voltage probes<!--XLATESTOP-->
			</xsl:when>
			<xsl:when test="$subCom = 'currents'">
				<!--XLATESTART-->current probes<!--XLATESTOP-->
			</xsl:when>
			<xsl:otherwise></xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="CLIParamFormat">
		<xsl:param name="format"/>
		<xsl:choose>
			<xsl:when test="$format = '1'">
			     <xsl:text>text</xsl:text>
			</xsl:when>
			<xsl:when test="$format = '2'">
			     <xsl:text>text</xsl:text>
			</xsl:when>			
			<xsl:when test="$format = '3'">
			     <xsl:text>text (alphanumeric only)</xsl:text>
			</xsl:when>
			<xsl:when test="$format = '4'">
			     <xsl:text>number</xsl:text>
			</xsl:when>	
			<xsl:when test="$format = '5'">
			     <xsl:text>&lt;true|false&gt;</xsl:text>
			</xsl:when>			
			<xsl:when test="$format = '6'">
			     <xsl:text>number</xsl:text>
			</xsl:when>				
			<xsl:when test="$format = '7'">
			     <xsl:text>number</xsl:text>
			</xsl:when>
			<xsl:when test="$format = '8'">
			     <xsl:text>d.d</xsl:text>
			</xsl:when>			
			<xsl:when test="$format = '9'">
			     <xsl:text>number</xsl:text>
			</xsl:when>
			<xsl:when test="$format = '10'">
			     <xsl:text>date</xsl:text>
			</xsl:when>
			<xsl:when test="$format = '19'">
			     <xsl:text>percent (0-100)</xsl:text>
			</xsl:when>
			<xsl:when test="$format = '26'">
			     <xsl:text>&lt;text&gt; (alphanumeric only)</xsl:text>
			</xsl:when>			
			<xsl:otherwise>
				<!--XLATESTART-->value<!--XLATESTOP-->			
                    </xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="CLIObjNotFound">
		<xsl:param name="subCom"/>
		<xsl:param name="paramNam"/>
		<xsl:param name="param1"/>
		<xsl:choose>
			<xsl:when test="$subCom = 'fans'">
			     <xsl:text>Error! No fan probes found on this system.</xsl:text>
			</xsl:when>
			<xsl:when test="$subCom = 'temps'">
				<!--XLATESTART-->Error! No temperature probes found on this system.<!--XLATESTOP-->
			</xsl:when>
			<xsl:when test="$subCom = 'volts'">
				<!--XLATESTART-->Error! No voltage probes found on this system.<!--XLATESTOP-->
			</xsl:when>
			<xsl:when test="$subCom = 'currents'">
				<!--XLATESTART-->Error! No current probes found on this system.<!--XLATESTOP-->
			</xsl:when>
			<xsl:when test="$subCom = 'acswitch'">
			     <xsl:text>Error! No AC Switch feature found on this system.</xsl:text>
			</xsl:when>
			<xsl:when test="$subCom = 'assettag'">
			     <xsl:text>Error! No Asset tag feature found on this system.</xsl:text>
			</xsl:when>
			<xsl:when test="$subCom = 'biossetup'">
			     <xsl:text>Error! No BIOS setup feature found on this system.</xsl:text>
			</xsl:when>
			<xsl:when test="$subCom = 'fancontrol'">
			     <xsl:text>Error! No Fan control feature found on this system.</xsl:text>
			</xsl:when>
			<xsl:when test="$subCom = 'memory'">
			     <xsl:text>Error! No memory feature found on this system.</xsl:text>
			</xsl:when>

			
			<xsl:when test="$subCom = 'memorymode'">
		          <xsl:choose>
					<xsl:when test="$param1 = '0'">
 			               <xsl:text>Error! Specified memory mode not available on this chassis.</xsl:text>
					</xsl:when>
					<xsl:when test="$param1 = '1'">
 			               <xsl:text>Error! Spare bank memory mode not available on this chassis.</xsl:text>
					</xsl:when>
					<xsl:when test="$param1 = '2'">
 			               <xsl:text>Error! Mirror memory mode not available on this chassis.</xsl:text>
					</xsl:when>
  			 	     <xsl:otherwise>
                                <xsl:text>Error! Specified memory mode not available on this chassis.</xsl:text>
                         </xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			
			<xsl:when test="$subCom = 'pwrsupplies'">
			     <xsl:text>Error! No instrumented power supplies found on this system.</xsl:text>
			</xsl:when>
			<xsl:when test="$subCom = 'powerbutton'">
			     <xsl:text>Error! No power button control feature found on this system.</xsl:text>
			</xsl:when>
			<xsl:when test="$subCom = 'nics'">
			     <xsl:text>Error! No Network Interface Card found on this system.</xsl:text>
			</xsl:when>
			<xsl:when test="$subCom = 'leds'">
			     <xsl:text>Error! This LED setting is not supported on this system.</xsl:text>
			</xsl:when>
			<xsl:when test="$subCom = 'intrusion'">
			     <xsl:text>Error! Intrusion information is not found for this system.</xsl:text>
			</xsl:when>
			<xsl:when test="$subCom = 'info'">
				<xsl:choose>
					<xsl:when test="$paramNam = 'pmmtag'">
			     		<xsl:text>Error! PMM tag setting unavailable on this system.</xsl:text>
  			          </xsl:when>
					<xsl:when test="$paramNam = 'iomtag'">
			     		<xsl:text>Error! IOM tag setting unavailable on this system.</xsl:text>
  			          </xsl:when>
					<xsl:when test="$paramNam = 'dsm0tag'">
			     		<xsl:text>Error! DSM0 tag setting unavailable on this system.</xsl:text>
  			          </xsl:when>
					<xsl:when test="$paramNam = 'dsm1tag'">
			     		<xsl:text>Error! DSM1 tag setting unavailable on this system.</xsl:text>
  			          </xsl:when>
					<xsl:when test="$paramNam = 'dsm2tag'">
			     		<xsl:text>Error! DSM2 tag setting unavailable on this system.</xsl:text>
  			          </xsl:when>
					<xsl:otherwise>
			     		<xsl:text>Error! Chassis info setting unavailable on this system.</xsl:text>					
					</xsl:otherwise>
                    </xsl:choose>
			</xsl:when>
			<xsl:otherwise><!--XLATESTART-->Error! Hardware or feature not present.<!--XLATESTOP--></xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="CLIProbeInvalid">
		<xsl:param name="subCom"/>
		<xsl:param name="probeindex"/>
		<xsl:choose>
			<xsl:when test="$subCom = 'fans'">
			     <xsl:text>Error! Fan probe warning thresholds unavailable for index value:</xsl:text>
					<xsl:value-of select="$probeindex"/>
			</xsl:when>
			<xsl:when test="$subCom = 'temps'">
				<!--XLATESTART-->Error! Temperature probe warning thresholds unavailable for index: <!--XLATESTOP-->
       				<xsl:value-of select="$probeindex"/>
			</xsl:when>
			<xsl:when test="$subCom = 'volts'">
				<!--XLATESTART-->Error! Voltage probe warning thresholds unavailable for index: <!--XLATESTOP-->
       				<xsl:value-of select="$probeindex"/>
			</xsl:when>
			<xsl:when test="$subCom = 'currents'">
				<!--XLATESTART-->Error! Current probe warning thresholds unavailable for index: <!--XLATESTOP-->
       				<xsl:value-of select="$probeindex"/>
			</xsl:when>
			<xsl:otherwise><!--XLATESTART-->Error! Hardware or feature not present.<!--XLATESTOP--></xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
<xsl:template name="CLIWarnThresh">
		<xsl:param name="subCom"/>
		<xsl:choose>
			<xsl:when test="$subCom = 'fans'">
			     <xsl:text>Error! Cannot set default value and specific value at the same time.</xsl:text>
			</xsl:when>
			<xsl:when test="$subCom = 'temps'">
			     <xsl:text>Error! Cannot set default value and specific value at the same time.</xsl:text>
			</xsl:when>
			<xsl:when test="$subCom = 'volts'">
			     <xsl:text>Error! Cannot set default value and specific value at the same time.</xsl:text>
			</xsl:when>
			<xsl:when test="$subCom = 'currents'">
			     <xsl:text>Error! Cannot set default value and specific value at the same time.</xsl:text>
			</xsl:when>
			<xsl:otherwise><!--XLATESTART-->Error! Hardware or feature not present.<!--XLATESTOP--></xsl:otherwise>
		</xsl:choose>
	</xsl:template>

<xsl:template name="CLIWarnUnavailable">
		<xsl:param name="subCom"/>
		<xsl:choose>
			<xsl:when test="$subCom = 'fans'">
			     <xsl:text>Error! Default fan threshold setting unavailable on this system.</xsl:text>
			</xsl:when>
			<xsl:when test="$subCom = 'temps'">
			     <xsl:text>Error! Default temperature threshold setting unavailable on this system.</xsl:text>
			</xsl:when>
			<xsl:when test="$subCom = 'volts'">
			     <xsl:text>Error! Default voltage threshold setting unavailable on this system.</xsl:text>
			</xsl:when>
			<xsl:when test="$subCom = 'currents'">
			     <xsl:text>Error! Default current threshold setting unavailable on this system.</xsl:text>
			</xsl:when>
			<xsl:otherwise><!--XLATESTART-->Error! Hardware or feature not present.<!--XLATESTOP--></xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template name="CLICommandFailed">
		<xsl:param name="subCom"/>
		<xsl:param name="paramNam"/>
		<xsl:choose>
			<xsl:when test="$subCom = 'leds'">
			     <xsl:text>Error! This LED setting is not supported on this system.</xsl:text>
			</xsl:when>
			<xsl:when test="$subCom = 'info'">
			
			<!--MOH></MOH-->
			
			
			     <xsl:text>Error! Chassis name cannot be changed on this chassis.</xsl:text>
			</xsl:when>
			<xsl:when test="$subCom = 'biossetup'">
				<xsl:choose>
					<xsl:when test="$stat = '256'">
			            		<xsl:text>Error! BIOS setting unavailable.</xsl:text>
				      </xsl:when>
					<xsl:otherwise>
			            		<xsl:text>Error! BIOS setting failed.</xsl:text>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:when test="$subCom = 'fancontrol'">
				<xsl:choose>
					<xsl:when test="$stat = '256'">
			            		<xsl:text>Error! Fan control setting unavailable on this system.</xsl:text>
				      </xsl:when>
					<xsl:otherwise>
			            		<xsl:text>Error! BIOS setting failed.</xsl:text>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			
			<xsl:when test="$subCom = 'memorymode'">
			     <xsl:text>Error! Hardware subsystem reports memory mode setting failed.</xsl:text>
			</xsl:when>
			
			<xsl:otherwise><!--XLATETHIS-->Error! Hardware subsystem reports command failed. <!--XLATETHIS--></xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="ConfigSuccess">
		<xsl:param name="subCom"/>
		<xsl:choose>
			<xsl:when test="$subCom = 'fans'">
			     <xsl:text>Fan probe warning threshold(s) set successfully.</xsl:text>
			</xsl:when>

			<xsl:when test="$subCom = 'temps'">
				 <xsl:text>Temperature probe warning threshold(s) set successfully.</xsl:text>
			</xsl:when>
			<xsl:when test="$subCom = 'volts'">
				<xsl:text>Voltage probe warning threshold(s) set successfully.</xsl:text>
			</xsl:when>
			<xsl:when test="$subCom = 'currents'">
				<xsl:text>Current probe warning threshold(s) set successfully.</xsl:text>
			</xsl:when>
			<xsl:when test="$subCom = 'acswitch'">
			     <xsl:text>AC Switch configured successfully.</xsl:text>
			</xsl:when>
			<xsl:when test="$subCom = 'info'">
			     <xsl:text>Chassis info set successfully.</xsl:text>
			</xsl:when>
			<xsl:when test="$subCom = 'assettag'">
			     <xsl:text>Asset tag set successfully.</xsl:text>
			</xsl:when>
			<xsl:when test="$subCom = 'biossetup'">
			     <xsl:text>BIOS setup configured successfully.</xsl:text>
			</xsl:when>
			<xsl:when test="$subCom = 'fancontrol'">
			     <xsl:text>Fan control configured successfully.</xsl:text>
			</xsl:when>
			<xsl:when test="$subCom = 'memory'">
			     <xsl:text>Memory error count cleared successfully.</xsl:text>
			</xsl:when>
			
			<xsl:when test="$subCom = 'memorymode'">
			     <xsl:text>Memory mode set successfully.</xsl:text>
			</xsl:when>
			
			<xsl:when test="$subCom = 'powerbutton'">
			     <xsl:text>Power button control configured successfully.</xsl:text>
			</xsl:when>
			<xsl:when test="$subCom = 'leds'">
			     <xsl:text>LED configured successfully.</xsl:text>
			</xsl:when>
			<xsl:otherwise>
				<!--XLATESTART-->Command successful.<!--XLATESTOP-->			
                    </xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="CLIIndexRange">
		<xsl:param name="subCom"/>
		<xsl:param name="index"/>
		<xsl:choose>
			<xsl:when test="$subCom = 'fans'">
			     <xsl:text>Error! Index too large. Maximum fan probe index is: </xsl:text>
				<xsl:value-of select="$index"/>
			</xsl:when>
			<xsl:when test="$subCom = 'temps'">
			     <xsl:text>Error! Index too large. Maximum temperature probe index is: </xsl:text>
				<xsl:value-of select="$index"/>
			</xsl:when>
			<xsl:when test="$subCom = 'volts'">
			     <xsl:text>Error! Index too large. Maximum voltage probe index is: </xsl:text>
				<xsl:value-of select="$index"/>
			</xsl:when>
			<xsl:when test="$subCom = 'currents'">
			     <xsl:text>Error! Index too large. Maximum current probe index is: </xsl:text>
				<xsl:value-of select="$index"/>
			</xsl:when>
			<xsl:when test="$subCom = 'slots'">
			     <xsl:text>Error! Index too large. Maximum slots index is: </xsl:text>
				<xsl:value-of select="$index"/>
			</xsl:when>
			<xsl:when test="$subCom = 'memory'">
			     <xsl:text>Error! Index too large. Maximum memory index is: </xsl:text>
				<xsl:value-of select="$index"/>
			</xsl:when>
			<xsl:when test="$subCom = 'processors'">
			     <xsl:text>Error! Index too large. Maximum processor index is: </xsl:text>
				<xsl:value-of select="$index"/>
			</xsl:when>
			<xsl:when test="$subCom = 'info'">
			     <xsl:text>Error! Index too large. Maximum chassis index is: </xsl:text>
				<xsl:value-of select="$index"/>
			</xsl:when>
			<xsl:when test="$subCom = 'leds'">
			     <xsl:text>Error! Index too large. Maximum chassis index is: </xsl:text>
				<xsl:value-of select="$index"/>
			</xsl:when>
			<xsl:when test="$subCom = 'biossetup'">
			     <xsl:text>Error! biossetup attribute not found.</xsl:text>
			</xsl:when>
			<xsl:otherwise>
				<xsl:text>Error! Index too large. Maximum index for this command is: </xsl:text>
				<xsl:value-of select="$index"/>	
                    </xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="Spaces">
		<xsl:param name="num"/>
		<xsl:choose>
			<xsl:when test="$num = '15'">
				<xsl:text>               </xsl:text>
			</xsl:when>
			<xsl:when test="$num = '14'">
				<xsl:text>              </xsl:text>
			</xsl:when>
			<xsl:when test="$num = '13'">
				<xsl:text>             </xsl:text>
			</xsl:when>
			<xsl:when test="$num = '12'">
				<xsl:text>            </xsl:text>
			</xsl:when>
			<xsl:when test="$num = '11'">
				<xsl:text>           </xsl:text>
			</xsl:when>
			<xsl:when test="$num = '10'">
				<xsl:text>          </xsl:text>
			</xsl:when>
			<xsl:when test="$num = '9'">
				<xsl:text>         </xsl:text>
			</xsl:when>
			<xsl:when test="$num = '8'">
				<xsl:text>        </xsl:text>
			</xsl:when>
			<xsl:when test="$num = '7'">
				<xsl:text>       </xsl:text>
			</xsl:when>
			<xsl:when test="$num = '6'">
				<xsl:text>      </xsl:text>
			</xsl:when>
			<xsl:when test="$num = '5'">
				<xsl:text>     </xsl:text>
			</xsl:when>
			<xsl:when test="$num = '4'">
				<xsl:text>    </xsl:text>
			</xsl:when>
			<xsl:when test="$num = '3'">
				<xsl:text>   </xsl:text>
			</xsl:when>
			<xsl:when test="$num = '2'">
				<xsl:text>  </xsl:text>
			</xsl:when>
			<xsl:when test="$num = '1'">
				<xsl:text> </xsl:text>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="NewLine">
		<xsl:text>
</xsl:text>
	</xsl:template>
		<xsl:template name="prnTemp">
	<xsl:param name="temp"/>
	<xsl:value-of select="format-number($temp div 10,'###.0')"/>
	</xsl:template>
	<xsl:template name="prnCurrent">
	<xsl:param name="current"/>
	<xsl:value-of select="format-number($current div 1000,'###.000')"/>
      </xsl:template>
	<xsl:template name="prnVolt">
	<xsl:param name="volt"/>
	<xsl:value-of select="format-number($volt div 1000,'###.000')"/>
      </xsl:template>
</xsl:stylesheet>
