<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<xsl:output method="text" indent="no"/>
	<xsl:strip-space elements="*"/>
	<xsl:template match="/OMA">
		<xsl:call-template name="CLISubCommand">
			<xsl:with-param name="command"><xsl:value-of select="CLISubCommand"/></xsl:with-param>
		</xsl:call-template>
		<xsl:call-template name="CLIMsgID">
			<xsl:with-param name="id"><xsl:value-of select="CLIMsgID"/></xsl:with-param>
			<xsl:with-param name="shownvpairs"><xsl:value-of select="CLIShowNVPairs"/></xsl:with-param>
		</xsl:call-template>
	</xsl:template>
	<xsl:template name="CLIMsgID">
		<xsl:param name="id"/>
		<xsl:param name="shownvpairs"/>
		<xsl:choose>
			<xsl:when test="$id = '1'">
				<!--XLATESTART-->Perform the BIOS update.<!--XLATESTOP-->
				<xsl:if test="$shownvpairs = 'true'">
					<xsl:call-template name="NewLine"/>
					<!--XLATESTART-->Valid parameters are:<!--XLATESTOP-->
					<xsl:call-template name="NewLine"/>
					<xsl:text>path=&lt;file&gt;      </xsl:text><!--XLATESTART-->Enter the absolute path of the update package file.<!--XLATESTOP-->
				</xsl:if>
			</xsl:when>
			<xsl:when test="$id = '2'">
				<!--XLATESTART-->Perform the firmware update.<!--XLATESTOP-->
				<xsl:if test="$shownvpairs = 'true'">
					<xsl:call-template name="NewLine"/>
					<!--XLATESTART-->Valid parameters are:<!--XLATESTOP-->
					<xsl:call-template name="NewLine"/>
					<xsl:text>path=&lt;file&gt;      </xsl:text><!--XLATESTART-->Enter the absolute path of the update package file.<!--XLATESTOP-->
				</xsl:if>
			</xsl:when>
			<xsl:when test="$id = '3'">
				<!--XLATESTART-->This is Update Service summary information.<!--XLATESTOP-->
			</xsl:when>
			<xsl:when test="$id = '4'">
				<!--XLATESTART-->Show the version info for all update components.<!--XLATESTOP-->
			</xsl:when>
			<xsl:when test="$id = '5'">
				<!--XLATESTART-->Perform the RAC firmware update.<!--XLATESTOP-->
				<xsl:if test="$shownvpairs = 'true'">
					<xsl:call-template name="NewLine"/>
					<!--XLATESTART-->Valid parameters are:<!--XLATESTOP-->
					<xsl:call-template name="NewLine"/>
					<xsl:text>path=&lt;file&gt;      </xsl:text><!--XLATESTART-->Enter the absolute path of the update package file.<!--XLATESTOP-->
				</xsl:if>
			</xsl:when>
			<xsl:when test="$id = '6'">
				<!--XLATESTART-->Perform the PERC/CERC/ROMB firmware update.<!--XLATESTOP-->
				<xsl:if test="$shownvpairs = 'true'">
					<xsl:call-template name="NewLine"/>
					<!--XLATESTART-->Valid parameters are:<!--XLATESTOP-->
					<xsl:call-template name="NewLine"/>
					<xsl:text>path=&lt;file&gt;      </xsl:text><!--XLATESTART-->Enter the absolute path of the update package file.<!--XLATESTOP-->
					<xsl:call-template name="NewLine"/>
					<xsl:text>device=&lt;type&gt;    </xsl:text><!--XLATESTART-->Enter the device type. Valid type are PERC3, PERC2, CERC, PERC4, ROMB, SCSI.<!--XLATESTOP-->
				</xsl:if>
			</xsl:when>
			<xsl:when test="$id = '7'">
				<!--XLATESTART-->Perform the PERC/CERC/ROMB driver update.<!--XLATESTOP-->
				<xsl:if test="$shownvpairs = 'true'">
					<xsl:call-template name="NewLine"/>
					<!--XLATESTART-->Valid parameters are:<!--XLATESTOP-->
					<xsl:call-template name="NewLine"/>
					<xsl:text>path=&lt;file&gt;      </xsl:text><!--XLATESTART-->Enter the absolute path of the update package file.<!--XLATESTOP-->
					<xsl:call-template name="NewLine"/>
					<xsl:text>device=&lt;type&gt;    </xsl:text><!--XLATESTART-->Enter the device type. Valid type are PERC3, PERC2, CERC, PERC4, ROMB, SCSI.<!--XLATESTOP-->
				</xsl:if>
			</xsl:when>
			
			<!-- AB for NIC Updates>
			<xsl:when test="$id = '8'">
				<XLATESTART>Perform the Network driver update.<XLATESTOP>
				<xsl:if test="$shownvpairs = 'true'">
					<xsl:call-template name="NewLine"/>
					<XLATESTART>Valid parameters are:<XLATESTOP>
					<xsl:call-template name="NewLine"/>
					<xsl:text>path=&lt;file&gt;      </xsl:text><XLATESTART>Enter the absolute path of the update package file.<XLATESTOP>
				</xsl:if>
			</xsl:when>
			< End AB for NIC Updates-->
			<xsl:when test="$id = '9'">
				<!--XLATESTART-->Perform the DRAC II firmware update.<!--XLATESTOP-->
				<xsl:if test="$shownvpairs = 'true'">
					<xsl:call-template name="NewLine"/>
					<!--XLATESTART-->Valid parameters are:<!--XLATESTOP-->
					<xsl:call-template name="NewLine"/>
					<xsl:text>path=&lt;file&gt;      </xsl:text><!--XLATESTART-->Enter the absolute path of the update package file.<!--XLATESTOP-->
				</xsl:if>
			</xsl:when>
		</xsl:choose>
		<xsl:call-template name="NewLine"/>
	</xsl:template>
	<xsl:template name="CLISubCommand">
		<xsl:param name="command"/>
		<xsl:if test="$command != ''">
			<xsl:value-of select="$command"/>
			<xsl:call-template name="Spaces">
				<xsl:with-param name="num"><xsl:value-of select="(16) - string-length($command)"/></xsl:with-param>
			</xsl:call-template>
		</xsl:if>
	</xsl:template>
	<xsl:template name="Spaces">
		<xsl:param name="num"/>
		<xsl:text> </xsl:text>
		<xsl:if test="$num &gt; '0'">
			<xsl:call-template name="Spaces">
				<xsl:with-param name="num">
					<xsl:value-of select="($num) - 1"/>
				</xsl:with-param>
			</xsl:call-template>
		</xsl:if>
	</xsl:template>
	<xsl:template name="NewLine">
		<xsl:text>
</xsl:text>
	</xsl:template>
</xsl:stylesheet>
