<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format">

	<xsl:template xmlns:fo="http://www.w3.org/1999/XSL/Format" match="LogEntry">
		<Row>
			<Data align="center" type="status" name="severity">
				<xsl:attribute name="sevlevel">
					<xsl:call-template name="status2lev">
						<xsl:with-param name="Status">
							<xsl:value-of select="Type"/>
						</xsl:with-param>
					</xsl:call-template>
				</xsl:attribute>
				<xsl:attribute name="value">
					<xsl:call-template name="status2omsa">
						<xsl:with-param name="Status">
							<xsl:value-of select="Type"/>
						</xsl:with-param>
					</xsl:call-template>
				</xsl:attribute>
			</Data>
			<Data name="DateTime" width="175">
				<xsl:attribute name="display">
					<xsl:value-of select="TimeStamp"/>
				</xsl:attribute>
				<xsl:attribute name="value">
					<xsl:value-of select="DateTime"/>
				</xsl:attribute>
			</Data>
			<Data name="User">
				<xsl:attribute name="display">
					<xsl:value-of select="UserInfo"/>
				</xsl:attribute>
				<xsl:attribute name="value">
					<xsl:value-of select="UserInfo"/>
				</xsl:attribute>
			</Data>
			<Data name="DescriptionNoPre">
				<xsl:attribute name="display">
					<xsl:apply-templates select="Description">
						<xsl:with-param name="idd">
							<xsl:value-of select="ID"/>
						</xsl:with-param>
					</xsl:apply-templates>
				</xsl:attribute>
				<xsl:attribute name="value">
					<xsl:apply-templates select="Description">
						<xsl:with-param name="idd">
							<xsl:value-of select="ID"/>
						</xsl:with-param>
					</xsl:apply-templates>
				</xsl:attribute>
			</Data>
		</Row>
	</xsl:template>

	<xsl:template xmlns:fo="http://www.w3.org/1999/XSL/Format" match="Description">
		<xsl:param name="idd"/>
		<xsl:call-template name="descriptionString">
			<xsl:with-param name="id">
				<xsl:value-of select="$idd"/>
			</xsl:with-param>
		</xsl:call-template>
		<xsl:choose>
			<xsl:when test="SMStatus != '0'">
				<xsl:if test="SMStatus">
					<xsl:choose>
						<xsl:when test="$idd = '0'"/>
						<xsl:when test="$idd = '1'"/>
						<xsl:otherwise> 
							<xsl:value-of select="$strXsltextFailedxsltext"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:if>
			</xsl:when>
			<xsl:otherwise>
				<xsl:choose>
					<!--The following message Id's will not have 'successfully' appended at the end. -->
					<xsl:when test="$idd = '0'"/>
					<xsl:when test="$idd = '1'"/>
					<xsl:when test="$idd = '5062'"/>
					<xsl:when test="$idd = '5089'"/>
					<xsl:when test="$idd = '5200'"/>
					<xsl:when test="$idd = '5201'"/>
					<xsl:when test="$idd = '5202'"/>
					<xsl:when test="$idd = '5203'"/>
					<xsl:when test="$idd = '5204'"/>
					<xsl:when test="$idd = '5205'"/>
					<xsl:when test="$idd = '5206'"/>
					<xsl:when test="$idd = '5207'"/>
					<xsl:when test="$idd = '5208'"/>
					<xsl:when test="$idd = '5209'"/>
					<xsl:when test="$idd = '5210'"/>
					<xsl:when test="$idd = '5211'"/>
					<xsl:when test="$idd = '5212'"/>
					<xsl:when test="$idd = '5301'"/>
					<xsl:when test="$idd = '5302'"/>
					<xsl:when test="$idd = '5438'" />
					<xsl:when test="$idd = '5602'"/>
					<xsl:when test="$idd = '5603'"/>
					<xsl:when test="$idd = '5604'"/>
					<xsl:when test="$idd = '5605'"/>
					<xsl:when test="$idd = '5710'"/>
					<xsl:when test="$idd = '5719'"/>
					<xsl:when test="$idd = '5728'"/>
					<xsl:when test="$idd = '5737'"/>
					<xsl:when test="$idd = '5901'"/>
					<xsl:when test="$idd = '5902'"/>
					<xsl:when test="$idd = '5903'"/>
					<xsl:when test="$idd = '5910'"/>
					<xsl:when test="$idd = '6001'"/>
					<xsl:when test="$idd = '6002'"/>
					<xsl:when test="$idd = '6003'"/>
					<xsl:when test="$idd = '6004'"/>
					<xsl:when test="$idd = '6005'"/>
					<xsl:when test="$idd = '6006'"/>
					<xsl:when test="$idd = '6007'"/>
					<xsl:when test="$idd = '6008'"/>
					<xsl:otherwise> 
						<!-- Append 'succesfully' at the end of message.-->
						<xsl:value-of select="$strXsltextSuccessfullyxsltext"/>
						<xsl:if test="$displayparams = 1">
							<xsl:value-of select="$strXsltextParametersXsltext"/>
							<xsl:apply-templates select="Parameter" />
						</xsl:if>		
					</xsl:otherwise>
				</xsl:choose>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template xmlns:fo="http://www.w3.org/1999/XSL/Format" name="descriptionString">
		<xsl:param name="">id</xsl:param>
		<xsl:choose>
			<!-- ******************** RESERVED (0-999) ******************** -->
			<xsl:when test="$id = '0'"><xsl:value-of select="$strCommandLogCleared"/></xsl:when>
			<xsl:when test="$id = '1'"><xsl:value-of select="$strCommandLogBackup"/></xsl:when>

			<!-- ******************** HIPDA (5000-5299) ******************** -->
			<xsl:when test="$id = '5001'"><xsl:value-of select="$strHardwareESMLogCleared"/></xsl:when>
			<xsl:when test="$id = '5002'"><xsl:value-of select="$strAlertLogCleared"/></xsl:when>
			<xsl:when test="$id = '5003'"><xsl:value-of select="$strProbeThresholdModified"/></xsl:when>
			<xsl:when test="$id = '5004'"><xsl:value-of select="$strLRAResponseModified"/></xsl:when>
			<xsl:when test="$id = '5010'"><xsl:value-of select="$strAssetInfoObject"/></xsl:when>
			<xsl:when test="$id = '5011'"><xsl:value-of select="$strAssetInfoAcquisition"/></xsl:when>
			<xsl:when test="$id = '5012'"><xsl:value-of select="$strAssetInfoVendorexpensed"/></xsl:when>
			<xsl:when test="$id = '5013'"><xsl:value-of select="$strAssetInfoCost"/></xsl:when>
			<xsl:when test="$id = '5014'"><xsl:value-of select="$strAssetInfoUser"/></xsl:when>
			<xsl:when test="$id = '5015'"><xsl:value-of select="$strAssetInfoExtended"/></xsl:when>
			<xsl:when test="$id = '5016'"><xsl:value-of select="$strAssetInfoOwnership"/></xsl:when>
			<xsl:when test="$id = '5017'"><xsl:value-of select="$strAssetInfoCorporate"/></xsl:when>
			<xsl:when test="$id = '5018'"><xsl:value-of select="$strAssetInfoHazard"/></xsl:when>
			<xsl:when test="$id = '5019'"><xsl:value-of select="$strAssetInfoDeployment"/></xsl:when>
			<xsl:when test="$id = '5020'"><xsl:value-of select="$strAssetInfoTraining"/></xsl:when>
			<xsl:when test="$id = '5021'"><xsl:value-of select="$strAssetInfoOutsourcing"/></xsl:when>
			<xsl:when test="$id = '5022'"><xsl:value-of select="$strAssetInfoInsurance"/></xsl:when>
			<xsl:when test="$id = '5023'"><xsl:value-of select="$strAssetInfoDepreciation"/></xsl:when>
			<xsl:when test="$id = '5024'"><xsl:value-of select="$strAssetInfoBox"/></xsl:when>
			<xsl:when test="$id = '5025'"><xsl:value-of select="$strAssetInfoOS"/></xsl:when>
			<xsl:when test="$id = '5026'"><xsl:value-of select="$strAssetInfoCost1"/></xsl:when>
			<xsl:when test="$id = '5027'"><xsl:value-of select="$strAssetInfoWarranty"/></xsl:when>
			<xsl:when test="$id = '5028'"><xsl:value-of select="$strAssetInfoSchedule"/></xsl:when>
			<xsl:when test="$id = '5029'"><xsl:value-of select="$strAssetInfoOptions"/></xsl:when>
			<xsl:when test="$id = '5030'"><xsl:value-of select="$strAssetInfoMaintenance"/></xsl:when>
			<xsl:when test="$id = '5031'"><xsl:value-of select="$strAssetInfoRepairs"/></xsl:when>
			<xsl:when test="$id = '5032'"><xsl:value-of select="$strAssetInfoTrouble"/></xsl:when>
			<xsl:when test="$id = '5033'"><xsl:value-of select="$strAssetInfoRegister"/></xsl:when>
			<xsl:when test="$id = '5034'"><xsl:value-of select="$strAssetInfoService"/></xsl:when>
			<xsl:when test="$id = '5035'"><xsl:value-of select="$strAssetInfoLease"/></xsl:when>
			<xsl:when test="$id = '5036'"><xsl:value-of select="$strAssetInfoSupport"/></xsl:when>
			<xsl:when test="$id = '5050'"><xsl:value-of select="$strBIOSUpdatePackage"/></xsl:when>  
			<xsl:when test="$id = '5060'"><xsl:value-of select="$strXsltextAutoRecoveryAction"/>
				<xsl:variable name="child"><xsl:value-of select="count(Parameter[@newval='true'])"/></xsl:variable>
				<xsl:choose>
					<xsl:when test="$child='0'"><xsl:value-of select="$strNoAction"/></xsl:when>
					<xsl:otherwise>
					<xsl:variable name="mode"><xsl:value-of select="Parameter[@newval='true']/@name"/></xsl:variable>
					<xsl:choose>
						<xsl:when test="$mode='PwrCycle'"><xsl:value-of select="$strPowerCycle"/></xsl:when>
						<xsl:when test="$mode='PwrOff'"><xsl:value-of select="$strPowerOff"/></xsl:when>
						<xsl:when test="$mode='Reboot'"><xsl:value-of select="$strReboot"/></xsl:when>
					</xsl:choose>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:when test="$id = '5061'"><xsl:value-of select="$strAutoRecoveryTimer"/><xsl:value-of select="Parameter[1]/@newval"/><xsl:value-of select="$strSeconds"/></xsl:when>
			<xsl:when test="$id = '5062'"><xsl:value-of select="$strSystemShutdownInitiated"/></xsl:when>
			<xsl:when test="$id = '5070'">
				<xsl:value-of select="$strXsltextAlertActionsFor"/>
				<xsl:call-template name="objectType">
					<xsl:with-param name="type">
						<xsl:value-of select="Parameter[@name='ObjType']/@value"/>
					</xsl:with-param>
				</xsl:call-template>				
				<xsl:value-of select="$strXsltextModifiedxsltext"/>
			</xsl:when>
			<xsl:when test="$id = '5071'">
				<xsl:call-template name="objectType">
					<xsl:with-param name="type">
						<xsl:value-of select="Parameter[@name='ObjType']/@value"/>
					</xsl:with-param>
				</xsl:call-template>
				<xsl:value-of select="$strXsltextAlertActions"/>
			</xsl:when>
			<xsl:when test="$id = '5072'"><xsl:value-of select="$strXsltextThermalProtectShutdown"/>
				<xsl:choose>
					<xsl:when test="Parameter[1]/@newval = '0'"><xsl:value-of select="$strDisabled"/></xsl:when>
					<xsl:when test="Parameter[1]/@newval = '1'"><xsl:value-of select="$strWarning"/></xsl:when>
					<xsl:when test="Parameter[1]/@newval = '2'"><xsl:value-of select="$strFailure"/></xsl:when>
				</xsl:choose>
			</xsl:when>
			<xsl:when test="$id = '5080'"> 
				<xsl:call-template name="objectType">
					<xsl:with-param name="type">
						<xsl:value-of select="Parameter[@name='ObjType']/@value"/>
					</xsl:with-param>
				</xsl:call-template>
 				<xsl:value-of select="$strXsltextProbeFor"/>
				<xsl:value-of select="Parameter[@name='ProbeLocation']/@value"/>
				<xsl:value-of select="$strXsltextMaximumWarning"/>
			</xsl:when>
			<xsl:when test="$id = '5081'">
				<xsl:call-template name="objectType">
					<xsl:with-param name="type">
						<xsl:value-of select="Parameter[@name='ObjType']/@value"/>
					</xsl:with-param>
				</xsl:call-template>
				<xsl:value-of select="$strXsltextProbeFor1"/>
 				<xsl:value-of select="Parameter[@name='ProbeLocation']/@value"/> 
				<xsl:value-of select="$strXsltextMinimumWarning"/>
			</xsl:when>
			<xsl:when test="$id = '5085'"><xsl:value-of select="$strSecurityGroupUser"/></xsl:when>
			<xsl:when test="$id = '5086'"><xsl:value-of select="$strSecurityGroupUser1"/></xsl:when>
			<xsl:when test="$id = '5087'"><xsl:value-of select="$strSecurityGroupUser2"/></xsl:when>
			<xsl:when test="$id = '5088'"><xsl:value-of select="$strSecurityGroupRoot"/></xsl:when>
			<xsl:when test="$id = '5089'"><xsl:value-of select="$strSecurityGroupRoot1"/></xsl:when>
			<xsl:when test="$id = '5090'"><xsl:value-of select="$strSystemChassisName"/></xsl:when>
			<xsl:when test="$id = '5091'"><xsl:value-of select="$strXsltextChassisFanControl"/>
				<xsl:choose>
					<xsl:when test="Parameter[1]/@newval = '1'"><xsl:value-of select="$strQuietMode"/></xsl:when>
					<xsl:when test="Parameter[1]/@newval = '2'"><xsl:value-of select="$strFullSpeedMode"/></xsl:when>
				</xsl:choose>
			</xsl:when>
			<xsl:when test="$id = '5092'"><xsl:value-of select="$strChassisLEDControl"/></xsl:when>
			<xsl:when test="$id = '5093'"><xsl:value-of select="$strChassisLEDState"/></xsl:when>
			<xsl:when test="$id = '5094'"><xsl:value-of select="$strChassisPowerButton"/></xsl:when>
			<xsl:when test="$id = '5095'"><xsl:value-of select="$strXsltextChassisIdentifyxsltext"/>
				<xsl:choose>
					<xsl:when test="Parameter[1]/@value = '1'"><xsl:value-of select="$strTurnedOn"/></xsl:when>
					<xsl:when test="Parameter[1]/@value = '0'"><xsl:value-of select="$strTurnedOff"/></xsl:when>
				</xsl:choose>
			</xsl:when>
			<xsl:when test="$id = '5096'"><xsl:value-of select="$strChassisAssetTag"/>'<xsl:value-of select="Parameter[1]/@newval"/>'</xsl:when>
			<xsl:when test="$id = '5097'"><xsl:value-of select="$strChassisIdentifyTimeout"/></xsl:when>
			<xsl:when test="$id = '5098'"><xsl:value-of select="$strHarddriveFaultLED"/></xsl:when>
			<xsl:when test="$id = '5100'"><xsl:value-of select="$strSystemInfoLocation"/></xsl:when>
			<xsl:when test="$id = '5101'"><xsl:value-of select="$strSystemInfoPrimary"/></xsl:when>
			<xsl:when test="$id = '5102'"><xsl:value-of select="$strSystemInfoPrimary1"/></xsl:when>
			<xsl:when test="$id = '5105'"><xsl:value-of select="$strMemoryErrorCount"/></xsl:when>
			<xsl:when test="$id = '5106'"><xsl:value-of select="$strMemoryRedundancyConfiguration"/></xsl:when>
			<xsl:when test="$id = '5110'"><xsl:value-of select="$strACSwitchMode"/></xsl:when>
			<xsl:when test="$id = '5111'"><xsl:value-of select="$strACSwitchRedundancy"/></xsl:when>
			<xsl:when test="$id = '5115'"><xsl:value-of select="$strESMLogCleared"/></xsl:when>
			<xsl:when test="$id = '5120'"><xsl:value-of select="$strAlertLogCleared1"/></xsl:when>
			<xsl:when test="$id = '5125'"><xsl:value-of select="$strBIOSSetupState"/></xsl:when>
			<!-- ********************  HIPDA SNMP Traps ****************** -->
			<xsl:when test="$id = '5200'"><xsl:value-of select="$strSNMPTrapsFor"/></xsl:when>
			<xsl:when test="$id = '5201'"><xsl:value-of select="$strSNMPTrapsFor1"/></xsl:when>
			<xsl:when test="$id = '5202'"><xsl:value-of select="$strSNMPTrapsFor2"/></xsl:when>
			<xsl:when test="$id = '5203'"><xsl:value-of select="$strSNMPTrapsFor3"/></xsl:when>
			<xsl:when test="$id = '5204'"><xsl:value-of select="$strSNMPTrapsFor4"/></xsl:when>
			<xsl:when test="$id = '5205'"><xsl:value-of select="$strSNMPTrapsFor5"/></xsl:when>
			<xsl:when test="$id = '5206'"><xsl:value-of select="$strSNMPTrapsFor6"/></xsl:when>
			<xsl:when test="$id = '5207'"><xsl:value-of select="$strSNMPTrapsFor7"/></xsl:when>
			<xsl:when test="$id = '5208'"><xsl:value-of select="$strSNMPTrapsFor8"/></xsl:when>
			<xsl:when test="$id = '5209'"><xsl:value-of select="$strSNMPTrapsFor9"/></xsl:when>
			<xsl:when test="$id = '5210'"><xsl:value-of select="$strSNMPTrapsFor10"/></xsl:when>
			<xsl:when test="$id = '5211'"><xsl:value-of select="$strSNMPTrapsFor11"/></xsl:when>
			<xsl:when test="$id = '5212'"><xsl:value-of select="$strSNMPTrapsFor12"/><xsl:value-of select="Name"/></xsl:when>
			<!-- ******************** CSDA (5300-5399) ******************** -->
			<xsl:when test="$id = '5301'">
				<xsl:choose>
<xsl:when test="SMStatus != '0'"><xsl:value-of select="$strUserLoginAttempt"/><xsl:value-of select="Parameter[@name='ipaddr']/@value"/></xsl:when>
<xsl:otherwise><xsl:value-of select="$strUserLoggedIn"/><xsl:value-of select="Parameter[@name='ipaddr']/@value"/><xsl:value-of select="$strWith"/><xsl:value-of select="Parameter[@name='priviliges']/@value"/><xsl:value-of select="$strPrivileges"/></xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:when test="$id = '5302'"><xsl:value-of select="$strUserLoggedOut"/><xsl:value-of select="Parameter[@name='ipaddr']/@value"/><xsl:value-of select="$strWith"/><xsl:value-of select="Parameter[@name='priviliges']/@value"/><xsl:value-of select="$strPrivileges"/></xsl:when>

			<!-- ******************** ACCESS CONFIGURATION (5310 - 5315) ******************** -->
			<xsl:when test="$id = '5311'"><xsl:value-of select="$strUserAccessRights"/></xsl:when>
			<xsl:when test="$id = '5312'"><xsl:value-of select="$strUserAccessRights1"/></xsl:when>
			<xsl:when test="$id = '5313'"><xsl:value-of select="$strUserAccessRights2"/></xsl:when>

			<!-- ******************** DRSDA (5400-5499) ******************** -->
			<xsl:when test="$id = '5401'"><xsl:value-of select="$strRemoteAccessCard"/></xsl:when>
			<xsl:when test="$id = '5402'"><xsl:value-of select="$strRemoteAccessCard1"/></xsl:when>
			<xsl:when test="$id = '5403'"><xsl:value-of select="$strRemoteAccessCard2"/></xsl:when>
			<xsl:when test="$id = '5404'"><xsl:value-of select="$strRemoteAccessCard3"/></xsl:when>
			<xsl:when test="$id = '5405'"><xsl:value-of select="$strRemoteAccessCard4"/></xsl:when>
			<xsl:when test="$id = '5406'"><xsl:value-of select="$strRemoteAccessCard5"/></xsl:when>
			<xsl:when test="$id = '5407'"><xsl:value-of select="$strRemoteAccessCard6"/></xsl:when>
			<xsl:when test="$id = '5408'"><xsl:value-of select="$strRemoteAccessCard7"/></xsl:when>
			<xsl:when test="$id = '5409'"><xsl:value-of select="$strRemoteAccessCard8"/></xsl:when>
			<xsl:when test="$id = '5410'"><xsl:value-of select="$strRemoteAccessCard9"/></xsl:when>
			<xsl:when test="$id = '5411'"><xsl:value-of select="$strRemoteAccessCard10"/></xsl:when>
			<xsl:when test="$id = '5412'"><xsl:value-of select="$strRemoteAccessCard11"/></xsl:when>
			<xsl:when test="$id = '5413'"><xsl:value-of select="$strRemoteAccessCard12"/></xsl:when>
			<xsl:when test="$id = '5414'"><xsl:value-of select="$strRemoteAccessCard13"/></xsl:when>
			<xsl:when test="$id = '5415'"><xsl:value-of select="$strRemoteAccessCard14"/></xsl:when>
			<xsl:when test="$id = '5416'"><xsl:value-of select="$strRemoteAccessCard15"/></xsl:when>
			<xsl:when test="$id = '5417'"><xsl:value-of select="$strRemoteAccessCard16"/></xsl:when>
			<xsl:when test="$id = '5418'"><xsl:value-of select="$strRemoteAccessCard17"/></xsl:when>
			<xsl:when test="$id = '5419'"><xsl:value-of select="$strRemoteAccessCard18"/></xsl:when>
			<xsl:when test="$id = '5420'"><xsl:value-of select="$strRemoteAccessCard19"/></xsl:when>
			<xsl:when test="$id = '5421'"><xsl:value-of select="$strRemoteAccessCard20"/></xsl:when>
			<xsl:when test="$id = '5422'"><xsl:value-of select="$strRemoteAccessCard21"/></xsl:when>
			<xsl:when test="$id = '5423'"><xsl:value-of select="$strRemoteAccessCard22"/></xsl:when>
			<xsl:when test="$id = '5424'"><xsl:value-of select="$strRemoteAccessCard23"/></xsl:when>
			<xsl:when test="$id = '5425'"><xsl:value-of select="$strRemoteAccessCard24"/></xsl:when>
			<xsl:when test="$id = '5426'"><xsl:value-of select="$strRemoteAccessCard25"/></xsl:when>
			<xsl:when test="$id = '5427'"><xsl:value-of select="$strRemoteAccessCard26"/></xsl:when>
			<xsl:when test="$id = '5428'"><xsl:value-of select="$strRemoteAccessCard27"/></xsl:when>
			<xsl:when test="$id = '5429'"><xsl:value-of select="$strRemoteAccessCard28"/></xsl:when>
			<xsl:when test="$id = '5430'"><xsl:value-of select="$strRemoteAccessCard29"/></xsl:when>
			<xsl:when test="$id = '5431'"><xsl:value-of select="$strRemoteAccessCard30"/></xsl:when>
			<xsl:when test="$id = '5432'"><xsl:value-of select="$strRemoteAccessCard31"/></xsl:when>
			<xsl:when test="$id = '5433'"><xsl:value-of select="$strRemoteAccessCard32"/></xsl:when>
			<xsl:when test="$id = '5434'"><xsl:value-of select="$strRemoteAccessCard33"/></xsl:when>
			<xsl:when test="$id = '5435'"><xsl:value-of select="$strRemoteAccessCard34"/></xsl:when>
			<xsl:when test="$id = '5436'"><xsl:value-of select="$strRemoteAccessCard35"/></xsl:when>
			<xsl:when test="$id = '5437'"><xsl:value-of select="$strRemoteAccessCard36"/></xsl:when>
			<xsl:when test="$id = '5438'"><xsl:value-of select="$strUserLoginAttempt1"/><xsl:value-of select="Parameter[@name='IPADDR']/@value"/><xsl:value-of select="$strFailedAUTHMETHOD"/><xsl:value-of select="Parameter[@name='AUTHMETHOD']/@value"/>;<xsl:value-of select="$strREASON"/><xsl:value-of select="Parameter[@name='REASON']/@value"/></xsl:when>

			<!-- ******************** AMDA (5500-5599) ******************** -->

			<!-- ******************** LUDA (5600-5699) ******************** -->
			<xsl:when test="$id = '5601'"><xsl:value-of select="$strTheAdministratorDeleted"/><xsl:value-of select="Parameter/@value"/></xsl:when>
			<xsl:when test="$id = '5602'"><xsl:value-of select="$strTheAdministratorLoaded"/><xsl:value-of select="Parameter[@name='pkgname']/@value"/>.  <xsl:value-of select="$strPreviousVersion"/><xsl:value-of select="Parameter[@name='locver']/@value"/>.  <xsl:value-of select="$strUpdateVersion"/><xsl:value-of select="Parameter[@name='pkgver']/@value"/><xsl:value-of select="$strTheUpdateWill"/></xsl:when>
			<xsl:when test="$id = '5603'"><xsl:value-of select="$strTheAdministratorPerformed"/><xsl:value-of select="Parameter[@name='pkgname']/@value"/>.  <xsl:value-of select="$strPreviousVersion1"/><xsl:value-of select="Parameter[@name='locver']/@value"/>.  <xsl:value-of select="$strUpdatesVersion"/><xsl:value-of select="Parameter[@name='pkgver']/@value"/></xsl:when>
			<xsl:when test="$id = '5604'"><xsl:value-of select="$strTheAdministratorPerformed1"/><xsl:value-of select="Parameter[@name='pkgname']/@value"/>.  <xsl:value-of select="$strPreviousESMVersion"/><xsl:value-of select="Parameter[@name='locver']/@value"/><xsl:value-of select="$strUpdateESMVersion"/><xsl:value-of select="Parameter[@name='pkgver']/@value"/></xsl:when>
			<xsl:when test="$id = '5605'"><xsl:value-of select="$strTheAdministratorFailed"/><xsl:value-of select="Parameter[@name='pkgname']/@value"/>.  <xsl:value-of select="$strUpdateFailedLocal"/><xsl:value-of select="Parameter[@name='locver']/@value"/>.<xsl:value-of select="$strUpdateVersion1"/><xsl:value-of select="Parameter[@name='pkgver']/@value"/></xsl:when>

			<!-- ******************** OLDDA (5700-5799) ******************** -->
			<xsl:when test="$id = '5702'"><xsl:value-of select="$strDiagnosticsSummaryPage"/></xsl:when>
			<xsl:when test="$id = '5703'"><xsl:value-of select="$strDiagnosticsApplicationLevel"/></xsl:when>
			<xsl:when test="$id = '5704'"><xsl:value-of select="$strDiagnosticsApplicationLevel1"/></xsl:when>
			<xsl:when test="$id = '5705'"><xsl:value-of select="$strDiagnosticsAdvancedSettings"/></xsl:when>
			<xsl:when test="$id = '5706'"><xsl:value-of select="$strDiagnosticsGetAdvanced"/></xsl:when>
			<xsl:when test="$id = '5707'"><xsl:value-of select="$strDiagnosticsResultHistory"/></xsl:when>
			<xsl:when test="$id = '5708'"><xsl:value-of select="$strDiagnosticsGetDifference"/></xsl:when>
			<xsl:when test="$id = '5709'"><xsl:value-of select="$strDiagnosticsDifferenceView"/></xsl:when>
			<xsl:when test="$id = '5710'"><xsl:value-of select="$strDiagnosticsConfigurationDifference"/></xsl:when>
			<xsl:when test="$id = '5712'"><xsl:value-of select="$strDiagnosticsSessionLog"/></xsl:when>
			<xsl:when test="$id = '5713'"><xsl:value-of select="$strDiagnosticsOverallProgress"/></xsl:when>
			<xsl:when test="$id = '5714'"><xsl:value-of select="$strDiagnosticsProgressRequested"/></xsl:when>
			<xsl:when test="$id = '5715'"><xsl:value-of select="$strDiagnosticsSetOverall"/></xsl:when>
			<xsl:when test="$id = '5716'"><xsl:value-of select="$strDiagnosticsGetOverall"/></xsl:when>
			<xsl:when test="$id = '5717'"><xsl:value-of select="$strDiagnosticsAborted"/></xsl:when>
			<xsl:when test="$id = '5718'"><xsl:value-of select="$strDiagnosticsCompleted"/></xsl:when>
			<xsl:when test="$id = '5719'"><xsl:value-of select="$strDiagnosticsSelectedTo"/></xsl:when>
			<xsl:when test="$id = '5720'"><xsl:value-of select="$strNoDiagnosticTest"/></xsl:when>
			<xsl:when test="$id = '5721'"><xsl:value-of select="$strDiagnosticsAdvancedSettings1"/></xsl:when>
			<xsl:when test="$id = '5722'"><xsl:value-of select="$strDiagnosticsViewBy"/></xsl:when>
			<xsl:when test="$id = '5723'"><xsl:value-of select="$strDiagnosticsViewBy1"/></xsl:when>
			<xsl:when test="$id = '5724'"><xsl:value-of select="$strDiagnosticsSelectionPage"/></xsl:when>
			<xsl:when test="$id = '5725'"><xsl:value-of select="$strDiagnosticsSelectionPage1"/></xsl:when>
			<xsl:when test="$id = '5726'"><xsl:value-of select="$strDiagnosticsSchedulerPage"/></xsl:when>
			<xsl:when test="$id = '5727'"><xsl:value-of select="$strDiagnosticsScheduledTask"/></xsl:when>
			<xsl:when test="$id = '5728'"><xsl:value-of select="$strNoDiagnosticsTask"/></xsl:when>
			<xsl:when test="$id = '5729'"><xsl:value-of select="$strDiagnosticsTaskScheduled"/></xsl:when>
			<xsl:when test="$id = '5730'"><xsl:value-of select="$strDiagnosticsResultHistory1"/></xsl:when>
			<xsl:when test="$id = '5731'"><xsl:value-of select="$strDiagnosticsWelcomePage"/></xsl:when>
			<xsl:when test="$id = '5732'"><xsl:value-of select="$strDiagnosticsAboutInfo"/></xsl:when>
			<xsl:when test="$id = '5733'"><xsl:value-of select="$strOSScheduledRun"/></xsl:when>
			<xsl:when test="$id = '5734'"><xsl:value-of select="$strOSScheduledRun1"/></xsl:when>
			<xsl:when test="$id = '5735'"><xsl:value-of select="$strCommandLineDiagnostic"/></xsl:when>
			<xsl:when test="$id = '5736'"><xsl:value-of select="$strCommandLineDiagnostic1"/></xsl:when>
			<xsl:when test="$id = '5737'"><xsl:value-of select="$strOSScheduledDiagnostic"/></xsl:when>

			<!-- ******************** OMASERVER (5900-5999) ******************** -->
			<xsl:when test="$id = '5901'"><xsl:value-of select="Parameter[@name='Name']/@value"/><xsl:value-of select="$strStarted"/></xsl:when>
			<xsl:when test="$id = '5902'"><xsl:value-of select="Parameter[@name='Name']/@value"/><xsl:value-of select="$strShutdown"/></xsl:when>
			<xsl:when test="$id = '5903'"><xsl:value-of select="Parameter[@name='ProductName']/@value"/><xsl:value-of select="$strUserPreferencesModified"/></xsl:when>
			<xsl:when test="$id = '5910'"><xsl:value-of select="Parameter[@name='ProductName']/@value"/><xsl:value-of select="$strServerPreferencesModified"/></xsl:when>
			
			<!-- ******************** OMASERVER (6000-6010) ******************** -->
			<xsl:when test="$id = '6001'"><xsl:value-of select="$strX509Certificate"/><xsl:value-of select="Parameter[@name='certificate']/@value"/><xsl:value-of select="$strDeleted"/></xsl:when>
			<xsl:when test="$id = '6002'"><xsl:value-of select="$strX509Certificate1"/><xsl:value-of select="Parameter[@name='certificate']/@value"/><xsl:value-of select="$strDeleteFailed"/></xsl:when>
			<xsl:when test="$id = '6003'"><xsl:value-of select="$strX509Certificate2"/><xsl:value-of select="Parameter[@name='certificate']/@value"/><xsl:value-of select="$strGenerated"/></xsl:when>
			<xsl:when test="$id = '6004'"><xsl:value-of select="$strX509Certificate3"/><xsl:value-of select="Parameter[@name='certificate']/@value"/><xsl:value-of select="$strGenerateFailed"/></xsl:when>
			<xsl:when test="$id = '6005'"><xsl:value-of select="$strX509Certificate4"/><xsl:value-of select="Parameter[@name='certificate']/@value"/><xsl:value-of select="$strGeneratedAndMade"/></xsl:when>
			<xsl:when test="$id = '6006'"><xsl:value-of select="$strX509Certificate5"/><xsl:value-of select="Parameter[@name='certificate']/@value"/><xsl:value-of select="$strGeneratedButMake"/></xsl:when>
			<xsl:when test="$id = '6007'"><xsl:value-of select="$strX509Certificate6"/><xsl:value-of select="Parameter[@name='certificate']/@value"/><xsl:value-of select="$strImported"/></xsl:when>
			<xsl:when test="$id = '6008'"><xsl:value-of select="$strX509Certificate7"/><xsl:value-of select="Parameter[@name='certificate']/@value"/><xsl:value-of select="$strImportFailed"/></xsl:when>

			<!-- ******************** UNKNOWN ******************** -->
			<xsl:otherwise><xsl:value-of select="$strUnknownEntryID"/><xsl:value-of select="$id"/>) </xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template xmlns:fo="http://www.w3.org/1999/XSL/Format" name="status2omsa">
		<xsl:param name="Status"></xsl:param>
		<xsl:choose>
			<xsl:when test="$Status=0">2</xsl:when>
			<xsl:when test="$Status=1">5</xsl:when>
			<xsl:when test="$Status=2">3</xsl:when>
			<xsl:when test="$Status=4">2</xsl:when>
			<xsl:when test="$Status=8">2</xsl:when>
			<xsl:when test="$Status=16">5</xsl:when>
			<xsl:otherwise>0</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template xmlns:fo="http://www.w3.org/1999/XSL/Format" name="status2lev">
		<xsl:param name="">Status</xsl:param>
		<xsl:choose>
			<xsl:when test="$Status=0">1</xsl:when>
			<xsl:when test="$Status=1">3</xsl:when>
			<xsl:when test="$Status=2">2</xsl:when>
			<xsl:when test="$Status=4">1</xsl:when>
			<xsl:when test="$Status=8">0</xsl:when>
			<xsl:when test="$Status=10">0</xsl:when>
			<xsl:otherwise>0</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template xmlns:fo="http://www.w3.org/1999/XSL/Format" match="Parameter">
		<xsl:choose>
			<xsl:when test="@newval"><xsl:text> </xsl:text><xsl:value-of select="@name"/>(<xsl:value-of select="@newval"/>)</xsl:when>
			<xsl:when test="@value"><xsl:text> </xsl:text><xsl:value-of select="@name"/>(<xsl:value-of select="@value"/>)</xsl:when>
		</xsl:choose>
	</xsl:template>

	<xsl:template xmlns:fo="http://www.w3.org/1999/XSL/Format" name="objectType">
		<xsl:param name="type"></xsl:param>
		<xsl:choose>
			<xsl:when test="$type='177'"><xsl:value-of select="$strPowerSupplyCritical"/></xsl:when>
			<xsl:when test="$type='178'"><xsl:value-of select="$strTemperatureProbeWarning"/></xsl:when>
			<xsl:when test="$type='179'"><xsl:value-of select="$strTemperatureProbeDetects"/></xsl:when>
			<xsl:when test="$type='180'"><xsl:value-of select="$strFanProbeWarning"/></xsl:when>
			<xsl:when test="$type='181'"><xsl:value-of select="$strFanProbeDetects"/></xsl:when>
			<xsl:when test="$type='182'"><xsl:value-of select="$strVoltageProbeWarning"/></xsl:when>
			<xsl:when test="$type='183'"><xsl:value-of select="$strVoltageProbeDetects"/></xsl:when>
			<xsl:when test="$type='184'"><xsl:value-of select="$strCurrentProbeWarning"/></xsl:when>
			<xsl:when test="$type='185'"><xsl:value-of select="$strCurrentProbeDetects"/></xsl:when>
			<xsl:when test="$type='186'"><xsl:value-of select="$strChassisIntrusionDetection"/></xsl:when>
			<xsl:when test="$type='187'"><xsl:value-of select="$strPowerSystemRedundancy"/></xsl:when>
			<xsl:when test="$type='188'"><xsl:value-of select="$strPowerSystemRedundancy1"/></xsl:when>
			<xsl:when test="$type='189'"><xsl:value-of select="$strMemoryPrefailure"/></xsl:when>
			<xsl:when test="$type='190'"><xsl:value-of select="$strMemoryFailure"/></xsl:when>
			<xsl:when test="$type='21'"><xsl:value-of select="$strPowersupply"/></xsl:when>
			<xsl:when test="$type='22'"><xsl:value-of select="$strTemperature"/></xsl:when>
			<xsl:when test="$type='23'"><xsl:value-of select="$strFan"/></xsl:when>			
			<xsl:when test="$type='24'"><xsl:value-of select="$strVoltage"/></xsl:when>
			<xsl:when test="$type='25'"><xsl:value-of select="$strCurrent"/></xsl:when>
		</xsl:choose>
	</xsl:template>
		

</xsl:stylesheet>
